var NOMADY = NOMADY || {};

( function( $ ) {

    // USE STRICT
    "use strict";

    var $window = $( window );
    var $document = $( document );

    NOMADY.Utility = {

        getBackendVar: function( variableName ) {
            if ( typeof window[ 'nomadyVar' ] === 'undefined' ) {
                return '';
            }

            if ( arguments.length == 1 ) {
                return window[ 'nomadyVar' ][ variableName ];
            } else {
                var b = arguments[ 1 ]; // take second argument
                return window[ 'nomadyVar' ][ variableName ][ b ];
            }
        }

    };

    NOMADY.documentOnReady = {

        init: function() {
            NOMADY.documentOnReady.ajaxLoadPosts();
            NOMADY.documentOnReady.backToTop.init();
            NOMADY.documentOnReady.featureSlider();
            NOMADY.documentOnReady.galleryCarousel();
            NOMADY.documentOnReady.instagramFeed();
            NOMADY.documentOnReady.lightbox();
            NOMADY.documentOnReady.masonry();
            NOMADY.documentOnReady.searchModalAutoFocus();
            NOMADY.documentOnReady.navbarSubMenuToggle();
            NOMADY.documentOnReady.offCanvasMenu();
            NOMADY.documentOnReady.parallaxCarousel();
            NOMADY.documentOnReady.postCarousel();
            NOMADY.documentOnReady.smartAffix.init( {
                fixedHeader: '.js-sticky-header',
                headerPlaceHolder: '.js-sticky-header-holder',
            } );
            NOMADY.documentOnReady.stickySidebar();
            NOMADY.documentOnScroll.init();
        },

        /* ============================================================================
         * AJAX load posts
         * ==========================================================================*/
        ajaxLoadPosts: function() {

            var $blocks = $( '.js-mnmd-ajax-load-more' );
            var ajaxURL = NOMADY.Utility.getBackendVar( 'ajaxURL' );
            var loadMoreText = NOMADY.Utility.getBackendVar( 'ajaxLoadPost', 'loadMoreText' );
            var loadingText = NOMADY.Utility.getBackendVar( 'ajaxLoadPost', 'loadingText' );
            var noMoreText = NOMADY.Utility.getBackendVar( 'ajaxLoadPost', 'noMoreText' );

            $blocks.each( function() {
                var $block = $( this );
                var $postsContainer = $block.find( '.js-mnmd-ajax-content' );
                var $ajaxLoadBtn = $block.find( '.js-ajax-load-posts-btn' );
                var query = $block.data( 'query' ); // get query string data
                var offset = ( $block.data( 'offset' ) !== undefined ) ? $block.data( 'offset' ) : null;
                var postsPerPage = ( $block.data( 'posts-per-page' ) !== undefined ) ? $block.data( 'posts-per-page' ) : null;
                var currentPage = $block.data( 'currentPage' );
                var maxPages = ( $block.data( 'max-pages' ) !== undefined ) ? $block.data( 'max-pages' ) : null;
                var ignoreStickyPosts = ( $block.data( 'ignore-sticky-posts' ) !== undefined ) ? $block.data( 'ignore-sticky-posts' ) : null;
                var layout = ( $block.data( 'layout' ) !== undefined ) ? $block.data( 'layout' ) : null;
                var columns = ( $block.data( 'columns' ) !== undefined ) ? $block.data( 'columns' ) : null;
                var postTemplate = ( $block.data( 'post-template' ) !== undefined ) ? $block.data( 'post-template' ) : null;
                var postHeroTemplate = ( $block.data( 'hero-post-template' ) !== undefined ) ? $block.data( 'hero-post-template' ) : null;
                var heroCycle = ( $block.data( 'hero-cycle' ) !== undefined ) ? $block.data( 'hero-cycle' ) : null;
                var heroFirst = ( $block.data( 'hero-post-first' ) !== undefined ) ? $block.data( 'hero-post-first' ) : null;
                var thumbReverse = ( $block.data( 'thumb-reverse' ) !== undefined ) ? $block.data( 'thumb-reverse' ) : null;
                var thumbOriginalRatio = ( $block.data( 'thumb-original-ratio' ) !== undefined ) ? $block.data( 'thumb-original-ratio' ) : null;
                var postFormatIcon = ( $block.data( 'post-format-icon' ) !== undefined ) ? $block.data( 'post-format-icon' ) : null;
                var excerptLength = ( $block.data( 'excerpt-length' ) !== undefined ) ? $block.data( 'excerpt-length' ) : null;
                var excerptLengthHero = ( $block.data( 'excerpt-length-hero' ) !== undefined ) ? $block.data( 'excerpt-length-hero' ) : null;
                var postMetaAuthor = ( $block.data( 'post-meta-author' ) !== undefined ) ? $block.data( 'post-meta-author' ) : null;
                var postMetaDate = ( $block.data( 'post-meta-date' ) !== undefined ) ? $block.data( 'post-meta-date' ) : null;

                var args = {
                    block: $block,
                    postsContainer: $postsContainer,
                    ajaxLoadBtn: $ajaxLoadBtn,
                    query: query,
                    offset: offset,
                    postsPerPage: postsPerPage,
                    currentPage: currentPage,
                    maxPages: maxPages,
                    ignoreStickyPosts: ignoreStickyPosts,
                    layout: layout,
                    columns: columns,
                    postTemplate: postTemplate,
                    postHeroTemplate: postHeroTemplate,
                    heroFirst: heroFirst,
                    heroCycle: heroCycle,
                    thumbReverse: thumbReverse,
                    thumbOriginalRatio: thumbOriginalRatio,
                    postFormatIcon: postFormatIcon,
                    excerptLength: excerptLength,
                    excerptLengthHero: excerptLengthHero,
                    postMetaAuthor: postMetaAuthor,
                    postMetaDate: postMetaDate,
                };

                args = newArgs( args );

                $ajaxLoadBtn.on( 'click', function() {
                    if ( $ajaxLoadBtn.hasClass( 'is-active' ) ) {
                        btnState( $ajaxLoadBtn, 'loading' );
                        ajaxLoad( args );
                    }
                } );
            } );

            // Calculate new query args
            function newArgs( args ) {
                args.currentPage++;
                args.offset += args.postsPerPage;
                args.query = args.query.replace( /\boffset=(\d+)/, 'offset=' + args.offset );

                return args;
            };

            // Change button state
            function btnState( $btn, state ) {
                switch ( state ) {
                    case 'nomore':
                        $btn.removeClass( 'is-active' );
                        $btn.addClass( 'disabled' );
                        $btn.find( '.load-more-btn-text' ).text( noMoreText );
                        break;

                    case 'loading':
                        $btn.removeClass( 'is-active' );
                        $btn.addClass( 'is-loading' );
                        $btn.find( '.load-more-btn-text' ).text( loadingText );
                        break;

                    case 'ready':
                    default:
                        $btn.removeClass( 'is-loading' );
                        $btn.addClass( 'is-active' );
                        $btn.find( '.load-more-btn-text' ).text( loadMoreText );
                        break;
                }
            };

            // Update new data attributes for block.
            function updateState( args ) {
                args.block.attr( 'data-current-page', args.currentPage - 1 );
            };

            // Append loaded posts to existing list
            function appendRespond( respond, args ) {
                var $loadedPosts = $( respond );
                var $postsContainer = args.postsContainer;
                var $ajaxLoadBtn = args.ajaxLoadBtn;

                if ( $loadedPosts ) {
                    if ( args.layout.indexOf( 'masonry-' ) >= 0 ) {
                        $postsContainer.append( $loadedPosts ).imagesLoaded( function() {
                            $postsContainer.masonry( 'appended', $loadedPosts, true );
                        } );
                    } else {
                        $loadedPosts.appendTo( $postsContainer ).css( 'opacity', 0 ).animate( { opacity: 1 }, 500 );
                    }

                    btnState( $ajaxLoadBtn, 'ready' );
                }
            };

            // Call AJAX request
            function ajaxLoad( args ) {
                var $ajaxLoadBtn = args.ajaxLoadBtn;
                var ajaxCall = $.ajax( {
                        url: ajaxURL,
                        type: 'post',
                        dataType: 'text',
                        data: {
                            action: 'ajax_load_post',
                            query: args.query,
                            postsPerPage: args.postsPerPage,
                            currentPage: args.currentPage,
                            ignoreStickyPosts: args.ignoreStickyPosts,
                            layout: args.layout,
                            columns: args.columns,
                            postTemplate: args.postTemplate,
                            postHeroTemplate: args.postHeroTemplate,
                            heroCycle: args.heroCycle,
                            heroFirst: args.heroFirst,
                            thumbReverse: args.thumbReverse,
                            thumbOriginalRatio: args.thumbOriginalRatio,
                            postFormatIcon: args.postFormatIcon,
                            excerptLength: args.excerptLength,
                            excerptLengthHero: args.excerptLengthHero,
                            postMetaAuthor: args.postMetaAuthor,
                            postMetaDate: args.postMetaDate,
                        },
                    } );

                ajaxCall.done( function( respond ) {
                    appendRespond( respond, args );
                    args = newArgs( args );
                    updateState( args );
                    if ( args.currentPage > args.maxPages ) {
                        btnState( $ajaxLoadBtn, 'nomore' );
                        $ajaxLoadBtn.off( 'click' );
                    }
                } );

                ajaxCall.fail( function() {
                    console.log( 'AJAX failed' );
                } );
            };
        },

        /* ============================================================================
         * Back to top btn
         * ==========================================================================*/
        backToTop: {
            backTopBtn: null,

            init: function() {
                this.backTopBtn = $( '.js-mnmd-back-top-btn' );
                if ( this.backTopBtn.length ) {
                    this.backTopBtn.on( 'click', function() {
                        $( 'html, body' ).animate(
                            {
                                scrollTop: 0,
                            },
                            {
                                duration: 200,
                                easing: 'swing',
                            }
                        );
                    } );
                }
            },

            eventScroll: function eventScroll( scrollTop ) {
                if ( scrollTop > $window.height() ) {
                    this.backTopBtn.addClass( 'is-shown' );
                } else {
                    this.backTopBtn.removeClass( 'is-shown' );
                }
            },
        },

        /* ============================================================================
         * Feature silder
         * ==========================================================================*/
        featureSlider: function() {
            if ( $.isFunction( $.fn.slick ) ) { // check if Slick script is loaded
                var $featureSliders = $( '.js-feature-slider' );
                $featureSliders.each( function( i, featureSlider ) {
                    var $featureSlider = $( featureSlider );
                    var $featureSliderNav = $featureSlider.siblings( '.js-feature-slider-nav' )
                    var $featureSliderNavItems = $featureSlider.siblings( '.js-feature-slider-nav' ).find( '.slider-navigation-item' );
                    var navItemsCount = $featureSliderNavItems.length - 1;
                    var autoplay = ( $featureSlider.data( 'autoplay' ) == true );
                    var speed = parseInt( $featureSlider.data( 'speed' ) );
                    if ( !speed ) {
                        speed = 6000;
                    }

                    // Slick settings.
                    $featureSlider.slick( {
                        slidesToShow: 1,
                        arrows: false,
                        autoplay: autoplay,
                        autoplaySpeed: speed,
                        pauseOnHover: false,
                        fade: true,
                        speed: 400,
                        cssEase: 'ease-in',
                        waitForAnimate: true,
                        adaptiveHeight: true,
                    } );

                    // Change active slider on click.
                    $featureSliderNav.on( 'click', '.slider-navigation-item', function() {
                        var index = $( this ).index();
                        $featureSlider.slick( 'slickGoTo', index );
                    } );

                    // Change active slider nav on change.
                    $featureSlider.on( 'beforeChange', function( event, slick, currentSlide, nextSlide ) {
                        var $currentNavItem = $featureSliderNavItems.eq( currentSlide );
                        var $nextNavItem = $featureSliderNavItems.eq( nextSlide );
                        $featureSliderNavItems.removeClass( 'is-active' );
                        $nextNavItem.addClass( 'is-active' );
                    } );
                } );
            }
        },

        /* ============================================================================
         * Gallery Carousel
         * ==========================================================================*/
        galleryCarousel: function() {
            var mySwiper = new Swiper ('.js-mnmd-gallery-carousel', {
                slidesPerView: 'auto',
                spaceBetween: 32,
                freeMode: true,
                scrollbar: {
                    el: '.swiper-scrollbar',
                },
            });
        },

        /* ============================================================================
         * Instagram Feed
         * ==========================================================================*/
        instagramFeed: function() {
            var instagramToken = NOMADY.Utility.getBackendVar( 'instagramToken' );
            var $instagramFeedSections = $( '.js-mnmd-instagram-feed' );
            $instagramFeedSections.each( function(index, el) {
                var feed = new Instafeed( {
                    accessToken: instagramToken,
                    target: el,
                    limit: 6,
                    template: '<li><a href="{{link}}"><img title="{{caption}}" src="{{image}}" /></a></li>',
                } );
                feed.run();
            } );
        },

        /* ============================================================================
         * Image Lightbox
         * ==========================================================================*/
        lightbox: function() {
            if ( !$( '.pswp' ).length ) {
                var pswpMarkup = '<div class="pswp" tabindex="-1" role="dialog" aria-hidden="true"> <div class="pswp__bg"></div><div class="pswp__scroll-wrap"> <div class="pswp__container"> <div class="pswp__item"></div><div class="pswp__item"></div><div class="pswp__item"></div></div><div class="pswp__ui pswp__ui--hidden"> <div class="pswp__top-bar"> <div class="pswp__counter"></div><button class="pswp__button pswp__button--close" title="Close (Esc)"></button> <button class="pswp__button pswp__button--share" title="Share"></button> <button class="pswp__button pswp__button--fs" title="Toggle fullscreen"></button> <button class="pswp__button pswp__button--zoom" title="Zoom in/out"></button> <div class="pswp__preloader"> <div class="pswp__preloader__icn"> <div class="pswp__preloader__cut"> <div class="pswp__preloader__donut"></div></div></div></div></div><div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap"> <div class="pswp__share-tooltip"></div></div><button class="pswp__button pswp__button--arrow--left" title="Previous (arrow left)"> </button> <button class="pswp__button pswp__button--arrow--right" title="Next (arrow right)"> </button> <div class="pswp__caption"> <div class="pswp__caption__center"></div></div></div></div></div>';
                $( 'body' ).append( pswpMarkup );
                var pswpElement = document.querySelectorAll('.pswp')[0];
            } else {
                var pswpElement = document.querySelectorAll('.pswp')[0];
            }

            // define options (if needed)
            var options = {
                // optionName: 'option value'
                // for example:
                index: 0 // start at first slide
            };

            var initPhotoSwipeFromDOM = function(gallerySelector) {

                // parse slide data (url, title, size ...) from DOM elements 
                // (children of gallerySelector)
                var parseThumbnailElements = function(el) {
                    var thumbElements = el.childNodes,
                        numNodes = thumbElements.length,
                        items = [],
                        figureEl,
                        linkEl,
                        size,
                        item;

                    for(var i = 0; i < numNodes; i++) {

                        figureEl = thumbElements[i]; // <figure> element

                        // include only element nodes 
                        if(figureEl.nodeType !== 1) {
                            continue;
                        }

                        linkEl = figureEl.children[0]; // <a> element

                        size = linkEl.getAttribute('data-size').split('x');

                        // create slide object
                        item = {
                            src: linkEl.getAttribute('href'),
                            w: parseInt(size[0], 10),
                            h: parseInt(size[1], 10)
                        };



                        if(figureEl.children.length > 1) {
                            // <figcaption> content
                            item.title = figureEl.children[1].innerHTML; 
                        }

                        if(linkEl.children.length > 0) {
                            // <img> thumbnail element, retrieving thumbnail url
                            item.msrc = linkEl.children[0].getAttribute('src');
                        } 

                        item.el = figureEl; // save link to element for getThumbBoundsFn
                        items.push(item);
                    }

                    return items;
                };

                // find nearest parent element
                var closest = function closest(el, fn) {
                    return el && ( fn(el) ? el : closest(el.parentNode, fn) );
                };

                // triggers when user clicks on thumbnail
                var onThumbnailsClick = function(e) {
                    e = e || window.event;
                    e.preventDefault ? e.preventDefault() : e.returnValue = false;

                    var eTarget = e.target || e.srcElement;

                    // find root element of slide
                    var clickedListItem = closest(eTarget, function(el) {
                        return (el.tagName && el.tagName.toUpperCase() === 'FIGURE');
                    });

                    if(!clickedListItem) {
                        return;
                    }

                    // find index of clicked item by looping through all child nodes
                    // alternatively, you may define index via data- attribute
                    var clickedGallery = clickedListItem.parentNode,
                        childNodes = clickedListItem.parentNode.childNodes,
                        numChildNodes = childNodes.length,
                        nodeIndex = 0,
                        index;

                    for (var i = 0; i < numChildNodes; i++) {
                        if(childNodes[i].nodeType !== 1) { 
                            continue; 
                        }

                        if(childNodes[i] === clickedListItem) {
                            index = nodeIndex;
                            break;
                        }
                        nodeIndex++;
                    }



                    if(index >= 0) {
                        // open PhotoSwipe if valid index found
                        openPhotoSwipe( index, clickedGallery );
                    }
                    return false;
                };

                // parse picture index and gallery index from URL (#&pid=1&gid=2)
                var photoswipeParseHash = function() {
                    var hash = window.location.hash.substring(1),
                    params = {};

                    if(hash.length < 5) {
                        return params;
                    }

                    var vars = hash.split('&');
                    for (var i = 0; i < vars.length; i++) {
                        if(!vars[i]) {
                            continue;
                        }
                        var pair = vars[i].split('=');  
                        if(pair.length < 2) {
                            continue;
                        }           
                        params[pair[0]] = pair[1];
                    }

                    if(params.gid) {
                        params.gid = parseInt(params.gid, 10);
                    }

                    return params;
                };

                var openPhotoSwipe = function(index, galleryElement, disableAnimation, fromURL) {
                    var pswpElement = document.querySelectorAll('.pswp')[0],
                        gallery,
                        options,
                        items;

                    items = parseThumbnailElements(galleryElement);

                    // define options (if needed)
                    options = {

                        // define gallery index (for URL)
                        galleryUID: galleryElement.getAttribute('data-pswp-uid'),

                        getThumbBoundsFn: function(index) {
                            // See Options -> getThumbBoundsFn section of documentation for more info
                            var thumbnail = items[index].el.getElementsByTagName('img')[0], // find thumbnail
                                pageYScroll = window.pageYOffset || document.documentElement.scrollTop,
                                rect = thumbnail.getBoundingClientRect(); 

                            return {x:rect.left, y:rect.top + pageYScroll, w:rect.width};
                        },

                        showHideOpacity: true,

                    };

                    // PhotoSwipe opened from URL
                    if(fromURL) {
                        if(options.galleryPIDs) {
                            // parse real index when custom PIDs are used
                            for(var j = 0; j < items.length; j++) {
                                if(items[j].pid == index) {
                                    options.index = j;
                                    break;
                                }
                            }
                        } else {
                            // in URL indexes start from 1
                            options.index = parseInt(index, 10) - 1;
                        }
                    } else {
                        options.index = parseInt(index, 10);
                    }

                    // exit if index not found
                    if( isNaN(options.index) ) {
                        return;
                    }

                    if(disableAnimation) {
                        options.showAnimationDuration = 0;
                    }

                    // Pass data to PhotoSwipe and initialize it
                    gallery = new PhotoSwipe( pswpElement, PhotoSwipeUI_Default, items, options);
                    gallery.init();
                };

                // loop through all gallery elements and bind events
                var galleryElements = document.querySelectorAll( gallerySelector );

                for(var i = 0, l = galleryElements.length; i < l; i++) {
                    galleryElements[i].setAttribute('data-pswp-uid', i+1);
                    galleryElements[i].onclick = onThumbnailsClick;
                }

                // Parse URL and open gallery if it contains #&pid=3&gid=1
                var hashData = photoswipeParseHash();
                if(hashData.pid && hashData.gid) {
                    openPhotoSwipe( hashData.pid ,  galleryElements[ hashData.gid - 1 ], true, true );
                }
            };

            // execute above function
            initPhotoSwipeFromDOM('.js-mnmd-lightbox-gallery');
        },

        /* ============================================================================
         * Parallax Carousel
         * ==========================================================================*/
        parallaxCarousel: function() {
            if ( $.isFunction( $.fn.flickity ) ) { // check if Flickity script is loaded
                var $parallaxCarousels = $( '.js-parallax-carousel' );
                $parallaxCarousels.each( function( i, parallaxCarousel ) {
                    var $parallaxCarousel = $( parallaxCarousel );
                    var $nextBtn = $parallaxCarousel.siblings( '.parallax-carousel-navigation' ).find( '.parallax-carousel-next-btn' );
                    var $prevBtn = $parallaxCarousel.siblings( '.parallax-carousel-navigation' ).find( '.parallax-carousel-prev-btn' );

                    // Flickity settings.
                    $parallaxCarousel.flickity( {
                        wrapAround: true,
                        percentPosition: true,
                        cellSelector: '.parallax-carousel-item',
                        pageDots: false,
                        prevNextButtons: false,
                        selectedAttraction: 0.018,
                    } );

                    parallax( $parallaxCarousel );

                    $parallaxCarousel.on( 'scroll.flickity', function() {
                        parallax( $parallaxCarousel );
                    } );

                    // Update index progress
                    $parallaxCarousel.on( 'change.flickity', function() {
                        updateIndex( $parallaxCarousel );
                    } );

                    // Previous button
                    $prevBtn.on( 'click', function() {
                        $parallaxCarousel.flickity('previous');
                    } );

                    // Next button
                    $nextBtn.on( 'click', function() {
                        $parallaxCarousel.flickity('next');
                    } );
                } );

                function parallax( $parallaxCarousel ) {
                    var $backgrounds = $parallaxCarousel.find( '.parallax-carousel-item .background-object');
                    // get transform property
                    var docStyle = document.documentElement.style;
                    var transformProp = typeof docStyle.transform == 'string' ?
                      'transform' : 'WebkitTransform';
                    // get Flickity instance
                    var flkty = $parallaxCarousel.data('flickity');
                    var slideWidth = flkty.slideableWidth / flkty.slides.length;
                    var translateX = 0;
                    var delta = 0;

                    flkty.slides.forEach( function( slide, i ) {
                        var background = $backgrounds[i];
                        delta = slide.target + flkty.x;
                        if ( delta < ( -( flkty.slides.length / 2 ) * slideWidth ) ) {
                            delta = ( flkty.slides.length * slideWidth ) + delta;
                        } else if ( delta > ( ( flkty.slides.length / 2 ) * slideWidth ) ) {
                            delta = delta - ( flkty.slides.length * slideWidth );
                        }
                        translateX = delta * -1/3;
                        background.style[ transformProp ] = 'translateX(' + translateX  + 'px)';
                    } );
                }

                function updateIndex( $parallaxCarousel ) {
                    // get Flickity instance
                    var flkty = $parallaxCarousel.data( 'flickity' );
                    var currentIndex = flkty.selectedIndex + 1;
                    var $carouselIndex = $parallaxCarousel.siblings( '.parallax-carousel-navigation' ).find( '.parallax-carousel-current-index' );
                    $carouselIndex.text( currentIndex );
                }
            }
        },

        /* ============================================================================
         * Post Carousel
         * ==========================================================================*/
        postCarousel: function() {
            if ( typeof Swiper === 'function' ) { // check if Swiper script is loaded
                var $carousels = $( '.js-mnmd-post-carousel' );
                $carousels.each( function( i, carousel ) {
                    var $carousel = $( carousel );
                    var spaceBetween = 32;
                    var slidesPerView = 3;
                    if ( $carousel.hasClass( 'mnmd-carousel-auto-width' ) ) {
                        slidesPerView = 'auto';
                    } else if ( $carousel.hasClass( 'mnmd-carousel-4i' ) ) {
                        slidesPerView = 4;
                    }
                    var $paginationCurrent = $carousel.siblings( '.mnmd-section-heading' ).find( '.mnmd-carousel-pagination-current' );
                    var $paginationTotal = $carousel.siblings( '.mnmd-section-heading' ).find( '.mnmd-carousel-pagination-total' );
                    var $paginationCurrentHidden;
                    var $paginationTotalHidden;
                    var $prevBtn = $carousel.siblings( '.mnmd-section-heading' ).find( '.mnmd-carousel-prev-btn' );
                    var $nextBtn = $carousel.siblings( '.mnmd-section-heading' ).find( '.mnmd-carousel-next-btn' );
                    var $prevBtn = $carousel.siblings( '.mnmd-section-heading' ).find( '.mnmd-carousel-prev-btn' );
                    var carouselConfigs = {
                        init: false,
                        slidesPerView: 'auto',
                        spaceBetween: spaceBetween,
                        watchOverflow: true,
                        grabCursor: true,
                        pagination: {
                            el: '.mnmd-carousel-hidden-pagination',
                            type: 'fraction',
                        },
                    }

                    if ( !$carousel.hasClass( 'mnmd-carousel-auto-width' ) ) {
                        carouselConfigs.slidesPerView = 1;
                        carouselConfigs.breakpoints = {
                            576: {
                                slidesPerView: 2,
                            },
                            992: {
                                slidesPerView: 3,
                            },
                            1200: {
                                slidesPerView: slidesPerView,
                            }
                        };
                    }

                    var swiper = new Swiper( carousel, carouselConfigs );

                    swiper.once( 'init', function () {
                        $paginationCurrentHidden = $carousel.find( '.mnmd-carousel-hidden-pagination .swiper-pagination-current' );
                        $paginationTotalHidden = $carousel.find( '.mnmd-carousel-hidden-pagination .swiper-pagination-total' );
                        $paginationTotal.text( $paginationTotalHidden.text() );
                    } );

                    swiper.init();

                    swiper.on( 'slideChange', function () {
                        $paginationCurrent.text( $paginationCurrentHidden.text() );
                    } );

                    swiper.on( 'resize', function () {
                        $paginationCurrentHidden = $carousel.find( '.mnmd-carousel-hidden-pagination .swiper-pagination-current' );
                        $paginationTotalHidden = $carousel.find( '.mnmd-carousel-hidden-pagination .swiper-pagination-total' );
                        $paginationCurrent.text( $paginationCurrentHidden.text() );
                        $paginationTotal.text( $paginationTotalHidden.text() );
                    } );

                    // Previous button
                    $prevBtn.on( 'click', function( e ) {
                        swiper.slidePrev();
                    } );

                    // Next button
                    $nextBtn.on( 'click', function( e ) {
                        swiper.slideNext();
                    } );
                } );
            }
        },

        /* ============================================================================
         * Masonry
         * ==========================================================================*/
        masonry: function() {
            if ( $.isFunction( $.fn.masonry ) ) { // check if masonry script is loaded
                var $masonryContainer = $('.js-masonry');
                $masonryContainer.masonry( {
                    itemSelector: '.masonry-item'
                } );

                if ( $.isFunction( $.fn.imagesLoaded ) ) { // check if imagesLoaded script is loaded
                    $masonryContainer.imagesLoaded().progress( function() {
                        $masonryContainer.masonry( 'layout' );
                    } );
                }

                $window.on( 'load', function() {
                   $masonryContainer.masonry( 'layout' );
                } );
            }
        },

        /* ============================================================================
         * Offcanvas Menu
         * ==========================================================================*/
        offCanvasMenu: function() {
            var $backdrop = $('<div class="mnmd-offcanvas-backdrop"></div>');
            var $offcanvas = $('.js-mnmd-offcanvas');
            var $offcanvasToggle = $('.js-mnmd-offcanvas-toggle');
            var $offcanvasClose = $('.js-mnmd-offcanvas-close');
            var $menuItemsHasChildren = $( '.mnmd-offcanvas .offcanvas-navigation li.menu-item-has-children' );

            function closeOffcanvas() {
                $offcanvas.removeClass( 'is-active' );
                $backdrop.removeClass( 'is-shown' );
                setTimeout( function() {
                    $backdrop.detach();
                }, 300 );
            }

            $backdrop.on( 'click', function() {
                closeOffcanvas();
            } );

            $offcanvasToggle.on( 'click', function( e ) {
                e.preventDefault();
                var targetID = $( this ).attr( 'href' );
                var $target = $( targetID );
                $target.toggleClass( 'is-active' );
                $backdrop.appendTo( document.body );
                setTimeout( function() {
                    $backdrop.addClass( 'is-shown' );
                }, 1 );
            } );

            $offcanvasClose.on( 'click', function( e ) {
                e.preventDefault();
                closeOffcanvas();
            } );

            // Toggle submenu on click
            $menuItemsHasChildren.each( function() {
                var $menuItemHasChildren = $( this );

                $menuItemHasChildren.on( 'click', 'a, li', function( e ) {
                    if ( $( e.target ).attr( 'href' ) === '#' ) {
                        e.preventDefault(); // Menu item is just a placeholder link
                    } else {
                        e.stopPropagation();
                    }
                } );

                $menuItemHasChildren.on( 'click', function() {
                    $menuItemHasChildren.toggleClass( 'is-sub-menu-opened' );
                } );
            } );
        },

        /* ============================================================================
         * Navbar Search Toggle
         * ==========================================================================*/
        searchModalAutoFocus: function() {
            var $searchModal = $( '#mnmd-search-modal' );

            $searchModal.on( 'shown.bs.modal', function() {
                $searchModal.find( '.search-field' ).focus();
            } );
        },

        /* ============================================================================
         * Navbar Sub Menu Toggle
         * ==========================================================================*/
        navbarSubMenuToggle: function() {
            var $navbarMenuItem = $( '.site-header-navigation li.menu-item-has-children' );
            $navbarMenuItem.on( 'click', function() {
                $( this ).children( '.sub-menu' ).slideToggle( 200 );
            } );
            $navbarMenuItem.on( 'click', 'a, li', function( e ) {
                e.stopPropagation();
            } );
        },

        /* ============================================================================
         * Sticky Header
         * ==========================================================================*/
        smartAffix: {
            // settings, obtained from ext
            headerPlaceHolder: '', // static header navbar.
            fixedHeader: '', // fixed header object.
            isDisabled: false,
            isFixed: false,
            isShown: false,
            windowScrollTop: 0,
            lastWindowScrollTop: 0, // last scrollTop position, used to calculate the scroll direction
            offCheckpoint: 0, // distance from top where fixed header will be hidden.
            onCheckpoint: 0, // distance from top where fixed header can show up.

            init : function init( options ) {

                // Read the settings
                this.fixedHeader = $( options.fixedHeader );
                this.headerPlaceHolder = $( options.headerPlaceHolder );

                // Check if selectors exist
                if( !this.fixedHeader.length ) {
                    return;
                }

                $document.ready( function() {
                    // Unhide header
                    NOMADY.documentOnReady.smartAffix.fixedHeader.css( 'display', 'block' );
                    // Compute on semi dom ready
                    NOMADY.documentOnReady.smartAffix.compute();
                } );

                // Recompute when all the page + logos are loaded
                $window.load( function() {
                    NOMADY.documentOnReady.smartAffix.compute();
                    NOMADY.documentOnReady.smartAffix.updateState();
                } );

            },// End init

            compute: function compute() {
                // Set where from top fixed header starts showing up
                if( !this.headerPlaceHolder.length ) {
                    this.offCheckpoint = 500;
                } else {
                    this.offCheckpoint = $( this.headerPlaceHolder ).offset().top + $( this.headerPlaceHolder ).outerHeight( true ) + 400;
                }

                this.onCheckpoint = this.offCheckpoint + 500;

                // Compute affixed state
                if ( $window.width() < 992 ) {  // Disable on small screen
                    this.isDisabled = true;
                } else {
                    this.windowScrollTop = $window.scrollTop();
                    if ( this.offCheckpoint < this.windowScrollTop ) {
                        this.isFixed = true;
                    }
                }
            },

            updateState: function updateState(){
                // Update affixed state
                if ( this.isFixed ) {
                    this.fixedHeader.addClass( 'is-fixed' );
                } else {
                    this.fixedHeader.removeClass( 'is-fixed' );
                }

                if ( this.isShown ) {
                    this.fixedHeader.addClass( 'is-shown' );
                } else {
                    this.fixedHeader.removeClass( 'is-shown' );
                }
            },

            /**
             * Called by events on scroll
             */

            eventScroll: function eventScroll( scrollTop ) {
                var scrollDirection = '';
                var scrollDelta = 0;

                // check if disabled
                if ( this.isDisabled ) {
                    return;
                }

                // check the direction
                if ( scrollTop != this.lastWindowScrollTop ) { //compute direction only if we have different last scroll top

                    // compute the direction of the scroll
                    if ( scrollTop > this.lastWindowScrollTop ) {
                        scrollDirection = 'down';
                    } else {
                        scrollDirection = 'up';
                    }

                    //calculate the scroll delta
                    scrollDelta = Math.abs( scrollTop - this.lastWindowScrollTop );
                    this.lastWindowScrollTop = scrollTop;

                    // update affix state
                    if ( this.offCheckpoint < scrollTop ) {
                        this.isFixed = true;
                    } else {
                        this.isFixed = false;
                    }

                    // check affix state
                    if ( this.isFixed ) {
                        // We're in affixed state, let's do some check
                        if ( ( scrollDirection == 'down' ) && ( scrollDelta > 14 ) ) {
                            if ( this.isShown ) {
                                this.isShown = false; // hide menu
                            }
                        } else {
                            if ( ( !this.isShown ) && ( scrollDelta > 14 ) && ( this.onCheckpoint < scrollTop ) ) {
                                this.isShown = true; // show menu
                            }
                        }
                    } else {
                        this.isShown = false;
                    }

                    this.updateState(); // update state
                }
            }, // end eventScroll function

            /**
             * Called by events on resize
             */

            eventResize: function eventResize( windowWidth ) {
                if ( windowWidth >= 992 ) {
                    this.isDisabled = false;
                    this.fixedHeader.addClass( 'is-shown' );
                } else {
                    this.isDisabled = true;
                    this.fixedHeader.removeClass( 'is-shown' );
                }
            },
        },

        /* ============================================================================
         * Sticky sidebar
         * ==========================================================================*/
        stickySidebar: function() {
            if ( $.isFunction( $.fn.theiaStickySidebar ) ) { // check if function exists
                var stickySidebarMarginTop = NOMADY.Utility.getBackendVar( 'stickySidebarMarginTop' );
                jQuery( '.js-mnmd-sticky-sidebar' ).theiaStickySidebar( {
                    additionalMarginTop: stickySidebarMarginTop,
                    additionalMarginBottom: 20,
                } );
            }
        },
    };

    NOMADY.documentOnLoad = {

        init: function() {
            NOMADY.documentOnLoad.ScrollingGalleryVertical();
        },

        /* ============================================================================
         * Scrolling Gallery
         * ==========================================================================*/
        ScrollingGalleryVertical: function() {
            if ( $.isFunction( $.fn.marquee ) ) { // check if marquee script is loaded
                var $ScrollingGalleryVerticals = $( '.js-scrolling-gallery-vertical' );
                $ScrollingGalleryVerticals.each( function( i, gallery ) {
                    var $gallery = $( gallery );
                    $gallery.marquee( {
                        gap: 20,
                        delayBeforeStart: 0,
                        direction: 'up',
                        duplicated: true,
                        startVisible: true,
                    } );
                } );
            }

            if ( $.isFunction( $.fn.marquee ) ) { // check if marquee script is loaded
                var $ScrollingGalleryHorizontals = $( '.js-scrolling-gallery-horizontal' );
                $ScrollingGalleryHorizontals.each( function( i, gallery ) {
                    var $gallery = $( gallery );
                    $gallery.marquee( {
                        gap: 0,
                        delayBeforeStart: 0,
                        direction: 'left',
                        duplicated: true,
                        startVisible: true,
                    } );
                } );
            }
        },
    }; // NOMADY.documentOnLoad

    NOMADY.documentOnScroll = {
        ticking: false,
        windowScrollTop: 0, // used to store the scrollTop

        init: function() {
            window.addEventListener( 'scroll', function( e ) {
                if ( !NOMADY.documentOnScroll.ticking ) {
                    window.requestAnimationFrame( function() {
                        NOMADY.documentOnScroll.windowScrollTop = $window.scrollTop();

                        // Functions to call here
                        NOMADY.documentOnReady.backToTop.eventScroll( NOMADY.documentOnScroll.windowScrollTop );
                        NOMADY.documentOnReady.smartAffix.eventScroll( NOMADY.documentOnScroll.windowScrollTop );

                        NOMADY.documentOnScroll.ticking = false;
                    } );
                }
                NOMADY.documentOnScroll.ticking = true;
            } );
        },
    }; // NOMADY.documentOnScroll

    NOMADY.documentOnResize = {
        ticking: false,
        windowWidth: 0, // used to store window's width

        init: function() {
            window.addEventListener('resize', function(e) {
                if (!NOMADY.documentOnResize.ticking) {
                    window.requestAnimationFrame(function() {
                        NOMADY.documentOnResize.windowWidth = $window.width();

                        // Functions to call here
                        NOMADY.documentOnReady.smartAffix.eventResize( NOMADY.documentOnResize.windowWidth );

                        NOMADY.documentOnResize.ticking = false;
                    });
                }
                NOMADY.documentOnResize.ticking = true;
            });
        },
    }; // NOMADY.documentOnResize


    $document.ready( NOMADY.documentOnReady.init );
    $window.on( 'load', NOMADY.documentOnLoad.init );
    $window.on( 'resize', NOMADY.documentOnResize.init );

} )( jQuery );