<?php
/**
 * The template for displaying category pages
 */

// Get theme options.
$post_listing_args = nomady_get_post_listing_args();
$sidebar = nomady_get_option( 'category_sidebar', 'mnmd-default' );

// Setting up variables
$section_class = 'mnmd-section mnmd-section-main-section post-listing-section post-listing-section-' . $post_listing_args['post_layout'];
$category = get_category( get_query_var( 'cat' ) );
$child_categories_query_args = array(
	'taxonomy'				=> 'category',
	'parent' 				=> $category->cat_ID,
	'orderby'   			=> 'name',
	'order'   				=> 'ASC',
);
$child_categories = get_categories( $child_categories_query_args );

get_header();
?>
<header class="page-header">
	<div class="container">
		<?php
		echo '<h1 class="page-title display-5">' . single_cat_title( '',  false ) . '</h1>';
		the_archive_description( '<div class="taxonomy-description mnmd-lead">', '</div>' );
		?>

		<?php
		if ( $child_categories ) {
		?>
			<ul class="child-categories-list">
			<?php
				foreach ( $child_categories as $cat ) {
					?>
					<li>
						<a class="h4 st-link" href="<?php echo esc_url( get_category_link( $cat->cat_ID ) ); ?>">
							<span><?php echo esc_html( $cat->name ); ?></span><?php
							if ( $cat->count !== 0 ) {
								echo '<sup>' . esc_html( $cat->count ) . '</sup>';
							}
							?>
						</a>
					</li>
					<?php
				}
			?>
			</ul>
		<?php
		}
		?>
	</div>
</header><!-- .page-header -->

<div id="primary" class="content-area">
	<?php
    if ( in_array( $post_listing_args['post_layout'], array( 'list-landscape', 'list-portrait', 'list-mixed-1', 'list-mixed-2', 'grid-portrait', 'grid-mixed-1', 'grid-mixed-2', 'masonry-portrait' ) ) ) {
	?>
	    <section class="mnmd-section mnmn-section-fullwidth mnmd-section-main-n-sidebar has-right-sidebar clearfix">
	        <div class="container">
	            <div class="mnmd-section-inner d-lg-flex">
	                <main class="mnmd-section mnmd-section-main">
	                    <section class="<?php echo esc_attr( $section_class ); ?>">
							<?php
							if ( have_posts() ) {
								nomady_post_listing( $post_listing_args );
							} else {
								echo esc_html__( 'Nothing Found', 'nomady' );
							}
							?>
                        </section>
                    </main><!-- #main -->

	                <aside class="mnmd-section-sidebar sidebar">
	                    <?php
	                    if ( is_active_sidebar( $sidebar ) ) {
	                        dynamic_sidebar( $sidebar );
	                    }
	                    ?>
	                </aside>
                </div>
            </div>
        </section>
    <?php
	} else {
	?>
		<section class="<?php echo esc_attr( $section_class ); ?>">
			<div class="container">
				<?php
				if ( have_posts() ) {
					nomady_post_listing( $post_listing_args );
				} else {
					echo esc_html__( 'Nothing Found', 'nomady' );
				}
				?>
	        </div>
        </section>
    <?php
	}
	?>

</div><!-- #primary -->

<?php
get_footer();