<?php
/**
 * Functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage Nomady
 * @since 1.0.0
 */

/**
 * Theme set up
 */
if ( !function_exists( 'nomady_setup' ) ) {
	function nomady_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 */
		load_theme_textdomain( 'nomady', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Set content-width.
		global $content_width;
		if ( !isset( $content_width ) ) {
			$content_width = 1200;
		}

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 1200, 9999 );

		// Add custom image sizes.
		add_image_size( 'nomady_org', 2560, 9999, false );
		add_image_size( 'nomady_4_3', 2560, 1920, true );
		add_image_size( 'nomady_2_1', 2560, 1280, true );
		add_image_size( 'nomady_5_2', 2560, 1024, true );

		add_image_size( 'nomady_lg', 1600, 9999, false );
		add_image_size( 'nomady_lg_1_1', 1600, 1600, true );
		add_image_size( 'nomady_lg_4_3', 1600, 1200, true );
		add_image_size( 'nomady_lg_3_2', 1600, 1067, true );
		add_image_size( 'nomady_lg_16_9', 1600, 900, true );
		add_image_size( 'nomady_lg_2_1', 1600, 800, true );
		add_image_size( 'nomady_lg_5_2', 1600, 640, true );

		add_image_size( 'nomady_md', 900, 9999, false );
		add_image_size( 'nomady_md_4_5', 900, 1125, true );
		add_image_size( 'nomady_md_1_1', 900, 900, true );
		add_image_size( 'nomady_md_4_3', 900, 675, true );
		add_image_size( 'nomady_md_3_2', 900, 600, true );
		add_image_size( 'nomady_md_16_9', 900, 506, true );
		add_image_size( 'nomady_md_2_1', 900, 450, true );

		add_image_size( 'nomady_sm', 600, 9999, false );
		add_image_size( 'nomady_sm_4_5', 600, 750, true );
		add_image_size( 'nomady_sm_1_1', 600, 600, true );
		add_image_size( 'nomady_sm_4_3', 600, 450, true );
		add_image_size( 'nomady_sm_3_2', 600, 400, true );
		add_image_size( 'nomady_sm_16_9', 600, 338, true );

		add_image_size( 'nomady_xs_4_5', 300, 375, true );
		add_image_size( 'nomady_xs_1_1', 300, 300, true );

		add_image_size( 'nomady_xxs_1_1', 150, 150, true );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
				'navigation-widgets',
			)
		);

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'audio',
			'gallery',
			'image',
			'video',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add custom editor font sizes.
		$post_body_typography = nomady_get_option( 'post_body_typography', [ 'font-size' => '18px' ] );
		$post_body_font_size = preg_replace( '/[^0-9]/', '', $post_body_typography['font-size'] );
		$small_font_size = round( $post_body_font_size * 0.8 );
		$normal_font_size = $post_body_font_size;
		$large_font_size = round( $post_body_font_size * 1.25 );
		$huge_font_size = round( $post_body_font_size * 1.953 );
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => esc_html__( 'Small', 'nomady' ),
					'shortName' => esc_html__( 'S', 'nomady' ),
					'size'      => $small_font_size,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__( 'Normal', 'nomady' ),
					'shortName' => esc_html__( 'M', 'nomady' ),
					'size'      => $normal_font_size,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__( 'Large', 'nomady' ),
					'shortName' => esc_html__( 'L', 'nomady' ),
					'size'      => $large_font_size,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__( 'Huge', 'nomady' ),
					'shortName' => esc_html__( 'XL', 'nomady' ),
					'size'      => $huge_font_size,
					'slug'      => 'huge',
				),
			)
		);
	}
	add_action( 'after_setup_theme', 'nomady_setup' );
}

/**
 * Register navigation menus uses wp_nav_menu.
 */
if ( !function_exists( 'nomady_menus' ) ) {
	function nomady_menus() {
		$locations = array(
			'site-header'  => esc_html__( 'Header', 'nomady' ),
			'mobile'   => esc_html__( 'Mobile', 'nomady' ),
			'footer'   => esc_html__( 'Footer', 'nomady' ),
		);

		register_nav_menus( $locations );
	}
	add_action( 'init', 'nomady_menus' );
}

/**
 * Include a skip to content link at the top of the page so that users can bypass the menu.
 */
if ( !function_exists( 'nomady_skip_link' ) ) {
	function nomady_skip_link() {
		echo '<a class="skip-link sr-only" href="#site-content">' . esc_html__( 'Skip to the content', 'nomady' ) . '</a>';
	}
	add_action( 'wp_body_open', 'nomady_skip_link', 5 );
}

/**
 * Register widget areas.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if ( !function_exists( 'nomady_sidebar_registration' ) ) {
	function nomady_sidebar_registration() {

		// Arguments used in all register_sidebar() calls.
		$shared_args = array(
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'          => esc_html__( 'Default Sidebar', 'nomady' ),
					'id'          => 'mnmd-default',
					'description'   => esc_html__( 'Add widgets here to display them in your sidebar on blog posts and archive pages.', 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( "After post's content", 'nomady' ),
					'id'          => 'mnmd-after-post-content',
					'description' => esc_html__( "Add widgets here to display them after post's content.", 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( 'Footer 1', 'nomady' ),
					'id'          => 'mnmd-footer-1',
					'description' => esc_html__( 'Add widgets here to display them in site footer.', 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( 'Footer 2', 'nomady' ),
					'id'          => 'mnmd-footer-2',
					'description' => esc_html__( 'Add widgets here to display them in site footer.', 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( 'Footer 3', 'nomady' ),
					'id'          => 'mnmd-footer-3',
					'description' => esc_html__( 'Add widgets here to display them in site footer.', 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( 'Footer 4', 'nomady' ),
					'id'          => 'mnmd-footer-4',
					'description' => esc_html__( 'Add widgets here to display them in site footer.', 'nomady' ),
				)
			)
		);

		register_sidebar(
			array_merge(
				$shared_args,
				array(
					'name'        => esc_html__( 'Off-canvas', 'nomady' ),
					'id'          => 'mnmd-offcanvas',
					'description' => esc_html__( 'Add widgets here to display them in off-canvas menu.', 'nomady' ),
				)
			)
		);
	}
	add_action( 'widgets_init', 'nomady_sidebar_registration' );
}

/**
 * Enqueue scripts and styles.
 */
if ( !function_exists( 'nomady_scripts' ) ) {
	function nomady_scripts() {
    	$theme_version = wp_get_theme()->get( 'Version' );

		// Bootstrap stylesheet.
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/vendors/bootstrap/bootstrap.min.css', array(), '4.5.3' );

		// Flickity stylesheet.
		wp_enqueue_style( 'flickity', get_template_directory_uri() . '/vendors/flickity/flickity.min.css', array(), '2.1.2' );

		// PhotoSwipe stylesheet.
		wp_enqueue_style( 'photoswipe', get_template_directory_uri() . '/vendors/photoswipe/photoswipe.css', array(), '4.1.3' );
		wp_enqueue_style( 'photoswipe-skin', get_template_directory_uri() . '/vendors/photoswipe/default-skin/default-skin.css', array(), '4.1.3' );

		// Slick stylesheet.
		wp_enqueue_style( 'slick', get_template_directory_uri() . '/vendors/slick/slick.css', array(), '1.8.0' );

		// Swiper stylesheet.
		wp_enqueue_style( 'swiper', get_template_directory_uri() . '/vendors/swiper/swiper-bundle.min.css', array(), '6.5.9' );

    	// Theme stylesheet.
    	wp_enqueue_style( 'nomady', get_template_directory_uri() . '/style.css', array(), $theme_version );

    	// Bootstrap scripts.
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/vendors/bootstrap/bootstrap.min.js', array('jquery'), '4.5.3', true );

		// Flickity scripts.
		wp_enqueue_script( 'flickity', get_template_directory_uri() . '/vendors/flickity/flickity.pkgd.min.js', array('jquery'), '2.1.2', true );

		// Instafeed scripts.
		wp_enqueue_script( 'instafeed', get_template_directory_uri() . '/vendors/instafeed/instafeed.min.js', array('jquery'), '2.0.0', true );

		// jQuery.Marquee scripts.
		wp_enqueue_script( 'jquery-marquee', get_template_directory_uri() . '/vendors/jquery-marquee/jquery.marquee.min.js', array('jquery'), '2.2.1', true );

		// Masonry scripts.
		wp_enqueue_script( 'masonry', '', array('jquery'), '', true );

		// PhotoSwipe scripts.
		wp_enqueue_script( 'photoswipe', get_template_directory_uri() . '/vendors/photoswipe/photoswipe.js', array(), '4.1.3', true );
		wp_enqueue_script( 'photoswipe-ui', get_template_directory_uri() . '/vendors/photoswipe/photoswipe-ui-default.min.js', array(), '4.1.3', true );

		// Slick scripts.
		wp_enqueue_script( 'slick', get_template_directory_uri() . '/vendors/slick/slick.min.js', array('jquery'), '1.8.0', true );

		// Swiper scripts.
		wp_enqueue_script( 'swiper', get_template_directory_uri() . '/vendors/swiper/swiper-bundle.min.js', array('jquery'), '6.5.9', true );

		// Theia sticky sidebar scripts.
		wp_enqueue_script( 'theia-sticky-sidebar', get_template_directory_uri() . '/vendors/theia-sticky-sidebar/theia-sticky-sidebar.min.js', array('jquery'), '1.7.0', true );

		// Theme scripts.
		wp_enqueue_script( 'mnmd-nomady', get_template_directory_uri() . '/assets/js/nomady-scripts.js', array('jquery'), $theme_version, true );

		// Comment reply scripts.
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'nomady_scripts' );
}

/**
 * Enqueue block editor styles.
 */
if ( !function_exists( 'nomady_block_editor_styles' ) ) {
	function nomady_block_editor_styles() {
		wp_enqueue_style( 'nomady-editor-style-block', get_template_directory_uri() . '/assets/css/editor-style-block.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
	}
	add_action( 'enqueue_block_editor_assets', 'nomady_block_editor_styles', 1, 1 );
}

/**
 * Enqueue classic editor styles.
 */
if ( !function_exists( 'nomady_classic_editor_styles' ) ) {
	function nomady_classic_editor_styles() {
		if ( !is_gutenberg_active() ) {
			// Enqueue editor styles.
			add_editor_style( 'assets/css/editor-style-classic.css' );
		}
	}
	add_action( 'init', 'nomady_classic_editor_styles' );
}

/**
 * Enqueue admin styles.
 */
if ( !function_exists( 'nomady_admin_styles' ) ) {
	function nomady_admin_styles() {
		wp_enqueue_style( 'nomady-editor-style-block', get_template_directory_uri() . '/assets/css/admin.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
	}
	add_action( 'admin_enqueue_scripts', 'nomady_admin_styles' );
}

/**
 * Register theme's frontend variable
 */
if ( !function_exists( 'nomady_frontend_variable' ) ) {
	function nomady_frontend_variable() {
		$ajaxloadpost = array(
			'failText' => esc_html__( 'Error loading posts', 'nomady' ),
			'loadingText' => esc_html__( 'Loading', 'nomady' ),
			'noMoreText' => esc_html__( 'There are no posts left', 'nomady' ),
			'loadMoreText' => esc_html__( 'Load more', 'nomady' ),
		);

		$sticky_header = nomady_get_option( 'sticky_header', 'yes' );
		$sticky_sidebar = nomady_get_option( 'sticky_sidebar', 'yes' );
		$sticky_sidebar_margin_top = 20;
		$instagram_token = nomady_get_option( 'footer_instagram_token', '' );

		if ( is_admin_bar_showing() ) {
			$sticky_sidebar_margin_top += 32;
		}

		if ( $sticky_sidebar === 'yes' ) {
			$sticky_sidebar_margin_top += 64;
		}

		$nomady_var = array(
			'ajaxURL' => admin_url( 'admin-ajax.php' ),
			'ajaxLoadPost' => $ajaxloadpost,
			'stickyHeader' => $sticky_header,
			'stickySidebar' => $sticky_sidebar,
			'stickySidebarMarginTop' => $sticky_sidebar_margin_top,
			'instagramToken' => $instagram_token,
		);

		wp_localize_script( 'mnmd-nomady', 'nomadyVar', $nomady_var );
	}
	add_action( 'wp_enqueue_scripts', 'nomady_frontend_variable' );
}

/**
 * Include the TGM plugin activation configuration file.
 */
if ( !function_exists( 'nomady_tgmpa_plugin_implement' ) ) {
	function nomady_tgmpa_plugin_implement() {
		if ( file_exists( get_template_directory() . '/inc/tgmpa-configs.php' ) ) {
		    require_once get_template_directory() . '/inc/tgmpa-configs.php';
		}
	}
	add_action( 'after_setup_theme', 'nomady_tgmpa_plugin_implement' );
}

/**
 * Include the One Click Demo Import plugin configuration file.
 */
if ( class_exists( 'OCDI_Plugin' ) && file_exists( get_template_directory() . '/inc/ocdi-configs.php' ) ) {
	require_once get_template_directory() . '/inc/ocdi-configs.php';
}

/**
 * Implement Theme Options panel.
 */
if ( !function_exists( 'nomady_customizer' ) ) {
	function nomady_customizer() {
		if ( class_exists( 'Kirki' ) && file_exists( get_template_directory() . '/inc/theme-customizer.php' ) ) {
			require_once get_template_directory() . '/inc/theme-customizer.php';
		}
	}
	add_action( 'after_setup_theme', 'nomady_customizer' );
}

/**
 * Add theme's inline CSS to site's head tag
 */
if ( !function_exists( 'nomady_inline_style' ) ) {
    function nomady_inline_style() {

    	if ( ! is_admin() ) {
    		$inline_css = '';

    		// Get options.
    		$post_body_typography = nomady_get_option( 'post_body_typography', [ 'line-height' => '1.7' ] );
    		$post_body_typography_mobile = nomady_get_option( 'post_body_typography_mobile', [ 'line-height' => '1.6' ] );

    		// Setting up variables.
    		$post_body_line_height = $post_body_typography['line-height'];
    		$post_body_line_height_mobile = $post_body_typography_mobile['line-height'];
			$dropcap_rows = 3;
			$dropcap_letter_ratio = 0.75;
			$dropcap_font_size = ( ( $post_body_line_height * $dropcap_rows ) - ( $post_body_line_height - 1 ) ) / $dropcap_letter_ratio;
			$dropcap_font_size_mobile = ( ( $post_body_line_height_mobile * $dropcap_rows ) - ( $post_body_line_height_mobile - 1 ) ) / $dropcap_letter_ratio;

    		$inline_css .= '
    			.post-body-copy .has-drop-cap:first-letter {
    				font-size: ' . $dropcap_font_size_mobile . 'em;
    				line-height: ' . $dropcap_letter_ratio . ';
    				margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size_mobile ) ) / 2 ) . 'em;
    			}';

    		$inline_css .= '
    			@media (min-width: 576px) {
    				.post-body-copy .has-drop-cap:first-letter {
    					font-size: ' . $dropcap_font_size . 'em;
    					line-height: ' . $dropcap_letter_ratio . ';
    					margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size ) ) / 2 ) . 'em;
    				}
    			}';

    		$inline_css .= '.post-navigation .nav-previous a:before { background-image: url("' . get_template_directory_uri() . '/assets/svg-icons/arrow-left.svg"); }';
    		$inline_css .= '.post-navigation .nav-next a:before { background-image: url("' . get_template_directory_uri() . '/assets/svg-icons/arrow-right.svg"); }';
    		$inline_css .= '.comments-area .comment-body .comment-reply-link:before { background-image: url("' . get_template_directory_uri() . '/assets/svg-icons/reply.svg"); }';
    		$inline_css .= '.comments-area .comment.bypostauthor .comment-author .fn:after { content: "' . esc_html__( 'Author', 'nomady' ) . '"; }';

    		if ( strlen( trim( $inline_css ) ) !== 0 ) {
    			echo '<style id="nomady-inline-css">';
		    	echo strip_tags( $inline_css );
		    	echo '</style>';
			}
		}
    }
    add_action( 'wp_head', 'nomady_inline_style', 999 );
}

/**
 * Remove WordPress' inine styling of editor-style.css.
 */
if ( ! function_exists( 'nomady_remove_inline_editor_style' ) ) {
	function nomady_remove_inline_editor_style( $editor_settings ) {
		unset( $editor_settings['styles'][0] );
		return $editor_settings;
	}
	// add_filter( 'block_editor_settings_all', 'nomady_remove_inline_editor_style' );
}

/**
 * Add inline CSS in backend.
 */
if ( ! function_exists( 'nomady_editor_style' ) ) {
	function nomady_editor_style( $hook ) {

		if ( $hook === 'post-new.php' || $hook === 'post.php' ) {
			$inline_css = '';

			// Get options.
			$primary_color = nomady_get_option( 'primary_color', '#000' );
    		$secondary_color = nomady_get_option( 'secondary_color', '#f5f5f5' );
    		$body_typography = nomady_get_option( 'body_typography', [ 'font-family' => '', 'font-weight' => '' ] );
	    	$heading_typography = nomady_get_option( 'heading_typography', [ 'font-family' => '', 'font-weight' => '' ] );
	    	$post_body_typography = nomady_get_option( 'post_body_typography', [ 'font-family' => '', 'font-size' => '18px', 'line-height' => '1.7' ] );
	    	$post_body_typography_mobile = nomady_get_option( 'post_body_typography_mobile', [ 'font-size' => '16px', 'line-height' => '1.6' ] );
	    	$meta_typography = nomady_get_option( 'meta_typography', [ 'font-family' => '' ] );

	    	// Setting up variables.
	    	$post_body_line_height = $post_body_typography['line-height'];
    		$post_body_line_height_mobile = $post_body_typography_mobile['line-height'];
    		$post_body_font_size = $post_body_typography['font-size'];
			$post_body_font_size_mobile = $post_body_typography_mobile['font-size'];
			$post_body_line_height = $post_body_typography['line-height'];
	    	$post_body_line_height_sm = $post_body_typography_mobile['line-height'];
	    	$dropcap_rows = 3;
			$dropcap_letter_ratio = 0.75;
			$dropcap_font_size = ( ( $post_body_line_height * $dropcap_rows ) - ( $post_body_line_height - 1 ) ) / $dropcap_letter_ratio;
			$dropcap_font_size_mobile = ( ( $post_body_line_height_mobile * $dropcap_rows ) - ( $post_body_line_height_mobile - 1 ) ) / $dropcap_letter_ratio;

    		$primary_color_bg_selectors = '
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-primary:visited,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .btn.st-btn-outline:before';

    		$primary_color_border_selectors = '
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:disabled,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary.disabled,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.btn.st-btn-secondary.disabled';

    		$secondary_color_bg_selectors = '
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary,
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary,
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:visited,
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar table caption,
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar #today:before,
	    		.editor-styles-wrapper.editor-styles-wrapper .wp-block-search .wp-block-search__button.wp-block-search__button.wp-block-search__button';

	    	$body_typography_selectors = '
				.editor-styles-wrapper.editor-styles-wrapper,
				.editor-styles-wrapper.editor-styles-wrapper .widget-calendar,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-tag-cloud a';

			$post_body_typography_selectors = '
				.editor-styles-wrapper.editor-styles-wrapper';

		    $heading_typography_selectors = '
		    	.editor-post-title__block.editor-post-title__block .editor-post-title__input,
		    	.editor-styles-wrapper.editor-styles-wrapper h1,
		    	.editor-styles-wrapper.editor-styles-wrapper h2,
		    	.editor-styles-wrapper.editor-styles-wrapper h3,
		    	.editor-styles-wrapper.editor-styles-wrapper h4,
		    	.editor-styles-wrapper.editor-styles-wrapper h5,
		    	.editor-styles-wrapper.editor-styles-wrapper h6,
		    	.editor-styles-wrapper.editor-styles-wrapper .widget_calendar caption,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar table caption,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-comments__comment-meta,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts li a,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-title';

		    $meta_typography_selectors = '
			    .editor-styles-wrapper.editor-styles-wrapper label,
			    .editor-styles-wrapper.editor-styles-wrapper button,
			    .editor-styles-wrapper.editor-styles-wrapper input[type=submit],
			    .editor-styles-wrapper.editor-styles-wrapper figcaption,
			    .editor-styles-wrapper.editor-styles-wrapper .metaText,
			    .editor-styles-wrapper.editor-styles-wrapper .metaFont,
			    .editor-styles-wrapper.editor-styles-wrapper .metaBtn,
			    .editor-styles-wrapper.editor-styles-wrapper .postMeta,
			    .editor-styles-wrapper.editor-styles-wrapper .postCategory,
			    .editor-styles-wrapper.editor-styles-wrapper .blockHeading,
			    .editor-styles-wrapper.editor-styles-wrapper .comment-reply-title,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-caption,
			    .editor-styles-wrapper.editor-styles-wrapper .gallery-caption,
			    .editor-styles-wrapper.editor-styles-wrapper .widget-title,
			    .editor-styles-wrapper.editor-styles-wrapper .btn,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-archives,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-archives select,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-button__link,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-categories,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-categories select,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-file__button,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote__citation,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote cite,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote footer,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote p,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote__citation,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote cite,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote footer,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-comments__comment-date,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_recent_entries .post-date,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts__post-author,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts__post-date,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-author,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-publish-date,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-search .wp-block-search__button.wp-block-search__button.wp-block-search__button,
			    .editor-styles-wrapper.editor-styles-wrapper .navigation,
			    .editor-styles-wrapper.editor-styles-wrapper .logged-in-as,
			    .editor-styles-wrapper.editor-styles-wrapper .tagcloud a,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_nav_menu .menu,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_categories li,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_meta li > a,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_pages li,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_archive a,
			    .editor-styles-wrapper.editor-styles-wrapper .comment-reply-title small,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-meta,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-list-with-thumbnails > li > a:first-child:after,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-list:not(.wpp-list-with-thumbnails) > li:before';

			$inline_css .= $primary_color_bg_selectors.'{ background-color:' . $primary_color . '; }';
    		$inline_css .= $primary_color_border_selectors . '{ border-color:' . $primary_color . '; }';
    		$inline_css .= $secondary_color_bg_selectors.'{ background-color:' . $secondary_color . '; }';

			if ( $body_typography['font-family'] ) {
				$inline_css .= $body_typography_selectors . '{font-family:' . $body_typography['font-family'] . '; font-weight:' . $body_typography['font-weight'] . ';}';
			}

			if ( $post_body_typography['font-family'] ) {
				$inline_css .= $post_body_typography_selectors . '{font-family:' . $post_body_typography['font-family'] . '; font-weight:' . $post_body_typography['font-weight'] . ';}';
			}

			if ( $heading_typography['font-family'] ) {
				$inline_css .= $heading_typography_selectors . '{font-family:' . $heading_typography['font-family'] . ';font-weight:' . $heading_typography['font-weight'] . ';}';
			}

			if ( $meta_typography['font-family'] ) {
				$inline_css .= $meta_typography_selectors . '{font-family:' . $meta_typography['font-family'] . '; font-weight:' . $meta_typography['font-weight'] . ';}';
			}

	    	$inline_css .= '
	    		.editor-styles-wrapper.editor-styles-wrapper > *,
				.editor-styles-wrapper.editor-styles-wrapper p,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
					font-size: ' . $post_body_font_size_mobile . ';
				}';

	    	$inline_css .= '
	    		@media (min-width: 576px) {
		    		.editor-styles-wrapper.editor-styles-wrapper > *,
					.editor-styles-wrapper.editor-styles-wrapper p,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
						font-size: ' . $post_body_font_size . ';
					}
				}';

			$inline_css .= '
	    		.editor-styles-wrapper.editor-styles-wrapper > *,
				.editor-styles-wrapper.editor-styles-wrapper p,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
					line-height: ' . $post_body_line_height_mobile . ';
				}';

	    	$inline_css .= '
	    		@media (min-width: 576px) {
		    		.editor-styles-wrapper.editor-styles-wrapper > *,
					.editor-styles-wrapper.editor-styles-wrapper p,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
						line-height: ' . $post_body_line_height . ';
					}
				}';

			$inline_css .= '
    			.block-editor-writing-flow .block-editor-block-list__block[data-type="core/paragraph"].has-drop-cap:not(:focus):first-letter {
    				font-size: ' . $dropcap_font_size_mobile . 'em;
    				line-height: ' . $dropcap_letter_ratio . ';
    				margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size_mobile ) ) / 2 ) . 'em;
    			}';

    		$inline_css .= '
    			@media (min-width: 576px) {
    				.block-editor-writing-flow .block-editor-block-list__block[data-type="core/paragraph"].has-drop-cap:not(:focus):first-letter {
    					font-size: ' . $dropcap_font_size . 'em;
    					line-height: ' . $dropcap_letter_ratio . ';
    					margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size ) ) / 2 ) . 'em;
    				}
    			}';

			echo '<style id="nomady-editor-css" type="text/css">';
			echo strip_tags( $inline_css );
			echo '</style>';
		}
	}
	add_action( 'admin_enqueue_scripts', 'nomady_editor_style' );
}

/**
 * Generate inline CSS for background image.
 */
if ( !function_exists( 'nomady_css_background_img' ) ) {
	function nomady_css_background_img( $thumb_size = '' ) {
		$thumb_url = '';
		if ( has_post_thumbnail() ) {
			$thumb_id = get_post_thumbnail_id();
			$thumb_url_array = wp_get_attachment_image_src( $thumb_id, $thumb_size, true );
			$thumb_url = $thumb_url_array[0];
		}
		return ' style="background-image: url(' . esc_url( $thumb_url ) . ');"';
	}
}

/**
 * Add addtional classes for posts.
 */
if ( !function_exists( 'nomady_additional_post_class' ) ) {
	function nomady_additional_post_class( $classes ) {
		global $post;

		// Class for post with no featured image.
		if ( !has_post_thumbnail( $post->ID ) ) {
			$classes[] = 'has-no-thumb';
		}

		// Class for post with vertical featured image.

		if ( nomady_img_orientation_check() === 'vertical' ) {
			$classes[] = 'has-vertical-featured-img';
		}

		return $classes;
	}
	add_filter( 'post_class', 'nomady_additional_post_class' );
}

/**
 * Create query args for featured block.
 */
if ( ! function_exists( 'nomady_featured_query_args' ) ) {
	function nomady_featured_query_args() {
		$args = array();
		$posts_per_page = 1;
		if ( current_user_can( 'read_private_posts' ) ) {
			$post_status = array( 'publish', 'private' );
		} else {
			$post_status = 'publish';
		}

		// create args base on method
		$args = array(
			'post_status' => $post_status,
			'posts_per_page'      => $posts_per_page,
			'ignore_sticky_posts' => 1,
			'orderby'   => 'date',
		);

		return $args;
	}
}

/**
 * Custom post excerpt words limit, must be used inside loop.
 */
if ( !function_exists( 'nomady_excerpt' ) ) {
	function nomady_excerpt( $limit = 20, $echo = true ) {
		if ( $echo ) {
			echo wp_trim_words( get_the_excerpt(), $limit );
		} else {
			return wp_trim_words( get_the_excerpt(), $limit );
		}
	}
}

/**
 * Display post featured image.
 */
if ( !function_exists( 'nomady_featured_img' ) ){
	function nomady_featured_img( $args ) {
		extract( $args );
		// Setting default values if variables not set.
		( isset( $size ) ) || $size = 'nomady_medium';
		( isset( $barebone ) ) || $barebone = false;
		( isset( $class ) ) || $class = '';
		( isset( $link ) ) || $link = true;
		( isset( $icon ) ) || $icon = 'no';
		( isset( $lazyload ) ) || $lazyload = true;

		if ( $lazyload ) {
			$lazyload = 'lazy';
		}

		$attr = array(
			'loading' => $lazyload,
		);

		if ( has_post_thumbnail() ) {
			if ( !$barebone ) {
				$post_link = get_permalink();
				$post_format = get_post_format();

				if ( ( $icon === 'yes' ) && ( $post_format !== '' ) ) {
					$class .= ' post-image-has-format-icon';
				}

				if ( $class !== '' ) {
					echo '<div class="' . esc_attr( $class ) . '">';
				}
					the_post_thumbnail( $size, $attr );

					if ( $icon === 'yes' ) {
						nomady_post_format_icon();
					}

					if ( $link ) {
						echo '<a href="' . esc_url( $post_link ) . '" class="link-overlay"></a>';
					}
				if ( $class !== '' ) {
					echo '</div>';
				}
			} else {
				the_post_thumbnail( $size, $attr );
				if ( $icon === 'yes' ) {
					nomady_post_format_icon();
				}
			}
		}
	}
}

/**
 * Check if featured image's orientation is horizontal or vertical.
 */
if ( !function_exists( 'nomady_img_orientation_check' ) ) {
	function nomady_img_orientation_check( $thumb_id = NULL, $thumb_size = '' ) {
		if ( $thumb_id === NULL ) {
			$thumb_id = get_post_thumbnail_id();
		}
		$image_data = wp_get_attachment_image_src( $thumb_id , $thumb_size );
		if ( $image_data ) {
			$width  = $image_data[1];
			$height = $image_data[2];
			if ( $width > $height ) {
				return 'horizontal';
			} else {
				return 'vertical';
			}
		}

		return '';
	}
}

/**
 * Return image's width to height aspect ratio.
 */
if ( !function_exists( 'nomady_img_aspect_ratio' ) ) {
	function nomady_img_aspect_ratio( $thumb_id = NULL, $thumb_size = '' ) {
		if ( $thumb_id === NULL ) {
			$thumb_id = get_post_thumbnail_id();
		}
		$image_data = wp_get_attachment_image_src( $thumb_id , $thumb_size );
		if ($image_data) {
			return ( $image_data[2] !== 0 ) ? $image_data[1] / $image_data[2] : 0;
		}
		else {
			return 0;
		}
	}
}

/**
 * Display post format icon
 */
if ( !function_exists( 'nomady_post_format_icon' ) ) {
	function nomady_post_format_icon() {
		$format = get_post_format();
		switch ( $format ) {
			case 'audio':
				echo '<div class="post-format-icon post-format-icon-audio">' . nomady_svg_icon( array( 'icon' => 'microphone', 'class' => 'mnmd-icon-lg', 'echo' => false ) ) . '</div>';
				break;

			case 'gallery':
				echo '<div class="post-format-icon post-format-icon-gallery">' . nomady_svg_icon( array( 'icon' => 'filter', 'class' => 'mnmd-icon-lg', 'echo' => false ) ) . '</div>';
				break;

			case 'image':
				echo '<div class="post-format-icon post-format-icon-image">' . nomady_svg_icon( array( 'icon' => 'image', 'class' => 'mnmd-icon-lg', 'echo' => false ) ) . '</div>';
				break;

			case 'video':
				echo '<div class="post-format-icon post-format-icon-video">' . nomady_svg_icon( array( 'icon' => 'play', 'class' => 'mnmd-icon-lg', 'echo' => false ) ) . '</div>';
				break;
		}
	}
}

/**
 * Display SVG icon
 */
if ( !function_exists( 'nomady_svg_icon' ) ) {
	function nomady_svg_icon( $args ) {
		extract( $args );
		// Setting default values if variables not set.
		( isset( $icon ) ) || $icon = '';
		( isset( $class ) ) || $class = '';
		$output ='';
		ob_start();

		if ( $class ) {
		?><span class="mnmd-icon <?php echo esc_attr( $class ); ?>" aria-hidden="true" ><?php
		} else {
		?><span class="mnmd-icon" aria-hidden="true"><?php
		}
			include( get_template_directory() . '/assets/svg-icons/' . $icon . '.svg' );
		?></span><?php

		$output = ob_get_clean();
		return $output;
	}
}

/**
 * Display date time in human readable format.
 */
if ( !function_exists( 'nomady_human_datetime' ) ) {
	function nomady_human_datetime( $day_limit = 7 ) {
		$post_time = get_the_time( 'U' );
		$human_time = '';
		$time_now = date( 'U' );

		// use human time if less than $day_limit days ago (7 days by default)
		// 60 seconds * 60 minutes * 24 hours * $day_limit days
		if ( $post_time > $time_now - ( 60 * 60 * 24 * $day_limit ) ) {
			$human_time = sprintf( esc_html__( '%s ago', 'nomady'), human_time_diff( $post_time, current_time( 'timestamp' ) ) );
		} else {
			$human_time = get_the_date();
		}

		return esc_html( $human_time );
	}
}

/**
 * Display updated date time in human readable format.
 */
if ( !function_exists( 'nomady_human_modified_datetime' ) ) {
	function nomady_human_modified_datetime( $day_limit = 7 ) {
		$post_time = get_the_modified_time( 'U' );
		$human_time = '';
		$time_now = date( 'U' );

		// use human time if less than $day_limit days ago (7 days by default)
		// 60 seconds * 60 minutes * 24 hours * $day_limit days
		if ( $post_time > $time_now - ( 60 * 60 * 24 * $day_limit ) ) {
			$human_time = esc_html__( 'Updated', 'nomady' ) . ' ' . sprintf( esc_html__( '%s ago', 'nomady'), human_time_diff( $post_time, current_time( 'timestamp' ) ) );
		} else {
			$human_time = esc_html__( 'Updated on', 'nomady' ) . ' ' . get_the_modified_date();
		}

		return esc_html( $human_time );
	}
}

/**
 * Display post meta
 */
if ( !function_exists( 'nomady_post_meta' ) ) {
	function nomady_post_meta( $args = array() ) {
		// Default values
		$args = wp_parse_args( $args, array(
			'meta_author' => 'yes',
			'meta_date' => 'yes',
		) );

		if ( $args['meta_author'] === 'yes' ) {
			echo '<span class="post-author">' . esc_html__( 'By', 'nomady' ) . '&#8287;' . get_the_author_posts_link() . '</span>';
		}

		if ( ( $args['meta_author'] === 'yes' ) && ( $args['meta_date'] === 'yes' ) ) {
			echo '<span class="meta-separator"></span>';
		}

		if ( $args['meta_date'] === 'yes' ) {
			$post_time_attr = get_the_time( 'c' );
			$post_time = get_the_time( get_option( 'date_format' ) );

			echo '<time class="published" datetime="' . esc_attr( $post_time_attr ) . '"  title="' . esc_attr( $post_time ) . '">' . nomady_human_datetime() . '</time>';
		}
	}
}

/**
 * Display first post category
 */
if ( !function_exists( 'nomady_post_category' ) ) {
	function nomady_post_category( $post_id = NULL ) {
		$category_array = get_the_category( $post_id );
		$category_link = NULL;
		if ( !empty( $category_array ) ) {
			$category_id = $category_array[0]->term_id;
			$category_name = esc_html( $category_array[0]->name );
			$category_link = esc_url( get_category_link( $category_id ) );
		}

		if ( $category_link ) {
			echo '<a href="' . $category_link . '" title="' . esc_html__( 'View all posts in', 'nomady' ).' ' . $category_name . '" rel="tag" class="post-category font-meta">' . $category_name . '</a>';
		}
	}
}

/**
 * Display post categories
 */
if ( !function_exists('nomady_post_categories') ) {
	function nomady_post_categories( $post_id = NULL ) {
		$categories = get_the_category( $post_id );
		if ( $categories ) {
			$categories = array_slice( $categories, 0, 3 ); // Display maximum 3 categories.
			?>
			<ul class="mnmd-post-categories">
			<?php
			foreach ( $categories as $category ) {
			?><li><a class="post-category font-meta" href="<?php echo esc_url( get_category_link( $category->term_id ) ); ?>" title="<?php echo esc_attr( sprintf( esc_html__( 'View all posts in %s', 'nomady' ), $category->name ) ) ?>" rel="tag"><?php echo esc_html( $category->name ); ?></a></li><?php
			}
			?>
			</ul>
			<?php
		}
	}
}

/**
 * Display post categories with posts count
 */
if ( !function_exists( 'nomady_post_categories_with_count' ) ) {
	function nomady_post_categories_with_count( $post_id = NULL ) {
		$categories = get_the_category( $post_id );
		if ( $categories ) {
			$number_category = count( $categories );
			$i = 0;
			?>
			<ul class="mnmd-post-categories">
			<?php
			foreach ( $categories as $category ) {
			?>
				<li>
					<a class="st-link post-category font-meta" href="<?php echo esc_url( get_category_link( $category->term_id ) ); ?>" title="<?php echo esc_attr( sprintf( esc_html__( 'View all posts in %s', 'nomady' ), $category->name ) ) ?>" rel="tag"><?php echo esc_html( $category->name ); ?><?php
					if ( $category->count !== 0 ) {
						echo '<sup>' . esc_html( $category->count ) . '</sup>';
					}
					?></a>
				</li>
			<?php
			}
			?>
			</ul>
			<?php
		}
	}
}

/**
 * Display post tags
 */
if ( !function_exists( 'nomady_post_tags' ) ) {
	function nomady_post_tags( $post_id = NULL ) {
		$tags = get_the_tags( $post_id );
		if ( $tags ) {
			?>
			<ul class="mnmd-post-tags">
			<?php
			foreach ( $tags as $tag ) {
			?>
				<li>
					<a class="post-tag" href="<?php echo esc_url( get_tag_link( $tag->term_id ) ); ?>" title="<?php echo esc_attr( sprintf( esc_html__( 'View all posts in %s', 'nomady' ), $tag->name ) ) ?>" rel="tag"><?php echo esc_html( $tag->name ); ?></a>
				</li>
			<?php
			}
			?>
			</ul>
			<?php
		}
	}
}

/**
 * Display author box.
 */
if ( !function_exists( 'nomady_author_box' ) ) {
	function nomady_author_box() {
		$author_bio = get_the_author_meta( 'description' );
		if ( ($author_bio === '' ) && is_single() ) {
			return; // do not display author box on single page if there's no bio set.
		}
		$author_id = get_the_author_meta( 'ID' );
		$author_name = get_the_author_meta( 'display_name', $author_id );
		$author_website = get_the_author_meta( 'url', $author_id );
		$author_post_counts = count_user_posts( $author_id );
		ob_start();
		?>
		<div class="mnmd-author-box">
			<div class="mnmd-author-box-avatar"><?php echo get_avatar( $author_id, 100, '', esc_html__( 'avatar', 'nomady' ) ); ?></div>
			<div class="mnmd-author-box-text">
				<div class="mnmd-author-box-name">
					<h4><?php the_author_posts_link(); ?></h4>
				</div>
				<div class="mnmd-author-box-bio"><?php echo esc_html( $author_bio ); ?></div>

				<div class="mnmd-author-box-meta">
					<?php
					if ( $author_website ) { ?>
					<div class="mnmd-author-box-website font-meta">
						<span><?php echo esc_html__( 'Website: ', 'nomady' ) ?></span><a href="<?php echo esc_url( $author_website ); ?>" target="_blank" rel="noopener noreferrer" title="Website"><?php echo esc_url( $author_website ); ?></a>
					</div>
					<?php
					}
					?>

					<?php
					if ( $author_post_counts > 0 ) {
					?>
					<div class="mnmd-author-box-posts-count font-meta">
						<span><?php echo esc_html__( 'Posts created: ', 'nomady' ) ?><strong><?php echo esc_html( $author_post_counts ); ?></strong></span>
					</div>
					<?php
					}
					?>
				</div>
			</div>
		</div>
		<?php
		$output = ob_get_clean();
		return $output;
	}
}

if ( !function_exists( 'nomady_get_post_listing_args' ) ) {
	function nomady_get_post_listing_args() {
		// Check what archive page current page is.
		if ( is_search() ) {
			$prefix = 'search_';
		} elseif ( is_category() ) {
			$prefix = 'category_';
		} elseif ( is_tag() ) {
			$prefix = 'tag_';
		} else {
			$prefix = 'blog_';
		}

		// Get theme options.
		$post_listing_args = array(
			'ignore_sticky_posts' => 'no',
			'post_layout' => nomady_get_option( $prefix . 'layout', 'list-portrait-no-sidebar' ),
			'thumb_reverse' => nomady_get_option( $prefix . 'reverse_thumb', 'yes' ),
			'thumb_original_ratio' => nomady_get_option( $prefix . 'original_ratio_thumb', 'no' ),
			'post_format_icon' => nomady_get_option( $prefix . 'post_format_icon_toggle', 'no' ),
			'hero_post_first' => nomady_get_option( $prefix . 'hero_post_first', 'yes' ),
			'hero_cycle' => nomady_get_option( $prefix . 'hero_cycle', 4 ),
			'hero_cycle_grid_no_sidebar' => nomady_get_option( $prefix . 'hero_cycle_grid_no_sidebar', 5 ),
			'grid_columns' => nomady_get_option( $prefix . 'grid_columns', '3' ),
			'flow_columns' => nomady_get_option( $prefix . 'flow_columns', '3' ),
			'excerpt_length' => NULL,
			'excerpt_length_hero' => NULL,
			'pagination' => nomady_get_option( $prefix . 'pagination', 'default' ),
		);

		if ( nomady_get_option( $prefix . 'excerpt_length_toggle' ) === 'yes' ) {
			$post_listing_args['excerpt_length'] = nomady_get_option( $prefix . 'excerpt_length', NULL );
			$post_listing_args['excerpt_length_hero'] = nomady_get_option( $prefix . 'excerpt_length_hero', NULL );
		}

		return $post_listing_args;
	}
}

/**
 * Post Listing.
 */
if ( !function_exists( 'nomady_post_listing' ) ) {
	function nomady_post_listing( $post_listing_args = array() ) {

		// Merge with default value.
		$post_listing_args = wp_parse_args( $post_listing_args, array(
			'post_query' => NULL,
			'query' => [
				'offset' => 0,
				'posts_per_page' => get_option( 'posts_per_page' ),
			],
			'ignore_sticky_posts' => 'yes',
			'post_layout' => 'list-landscape',
			'grid_columns' => '3',
			'flow_columns' => '3',
			'thumb_reverse' => 'no',
			'thumb_original_ratio' => 'no',
			'post_format_icon' => 'no',
			'hero_cycle' => NULL,
			'hero_post_first' => 'yes',
		    'excerpt_length' => NULL,
		    'excerpt_length_hero' => NULL,
		    'post_meta_author' => nomady_get_option( 'meta_author_toggle' ),
		    'post_meta_date' => nomady_get_option( 'meta_date_toggle' ),
		    'pagination' => 'default',
			'view_more_url' => '',
			'view_more_url_title' => '',
		) );

		// Setting up variables
		$section_class = 'mnmd-section mnmd-section-main-section post-listing-section post-listing-section-' . $post_listing_args['post_layout'];
		$section_wrapper_class = 'post-listing-wrapper';
		$section_content_class = 'post-listing-content';
		if ( $post_listing_args['pagination'] === 'ajax-load-more' ) {
		    $section_wrapper_class .= ' js-mnmd-ajax-load-more';
		    $section_content_class .= ' js-mnmd-ajax-content';
		}

		$is_mixed = false;
		$template_args = array();
		$template_args_hero = array();

		$template_args['thumb_reverse'] = $template_args_hero['thumb_reverse'] = $post_listing_args['thumb_reverse'];
		$template_args['post_format_icon'] = $template_args_hero['post_format_icon'] = $post_listing_args['post_format_icon'];
		$template_args['excerpt_length'] = $post_listing_args['excerpt_length'];
		$template_args_hero['excerpt_length'] = $post_listing_args['excerpt_length_hero'];

		switch ( $post_listing_args['post_layout'] ) {
		    case 'list-landscape':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'landscape';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'list-landscape-no-sidebar':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'landscape-wide';
		        break;

		    case 'list-portrait':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'portrait-xl';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_md';
		        }
		        break;

		    case 'list-portrait-no-sidebar':
		    	$section_content_class .= ' stream-list-lg';
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'portrait-xl';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_lg';
		        } else {
		        	$template_args['thumb_size'] = 'nomady_lg_2_1';
		        }
		        break;

		    case 'list-mixed-1':
		    	$post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape';
        		$post_hero_template = 'portrait-cutout';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        	$template_args_hero['thumb_size'] = 'nomady_md';
		        }
        		$is_mixed = true;
		        break;

		    case 'list-mixed-2':
		        $post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape';
        		$post_hero_template = 'card-background-lg';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
        		$is_mixed = true;
				break;

		    case 'list-mixed-no-sidebar':
		        $post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape-wide';
        		$post_hero_template = 'landscape-lg';
        		$is_mixed = true;
		        break;

		    case 'grid-portrait':
		    	$section_content_class .= ' row row-space-around';
		        $post_item_wrapper_class = 'grid-item col-sm-6';
		        $post_template = 'portrait';
		        break;

		    case 'grid-portrait-no-sidebar':
		    	$section_content_class .= ' row row-space-around';
		        if ( $post_listing_args['grid_columns'] === '3' ) {
		            $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		            $post_template = 'portrait';
		        } else {
		            $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-3';
		            $post_template = 'portrait-sm';
		        }
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'grid-flow':
		    	$section_content_class .= ' row row-space-around';
		    	if ( $post_listing_args['flow_columns'] === '3' ) {
		    		$post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		            $post_template = 'portrait-sm';
		            $template_args['thumb_size'] = 'nomady_sm';
		    	} else {
		    		$post_item_wrapper_class = 'grid-item col-md-6';
		            $post_template = 'portrait-lg';
		            $template_args['thumb_size'] = 'nomady_md';
		    	}
				$min_post_padding = 0; // in percentage.
				$max_post_padding = 15; // in percentage.
		        break;

		    case 'grid-mixed-1':
		    	$section_content_class .= ' row row-space-around';
        		$post_item_wrapper_class = 'grid-item col-sm-6';
        		$post_item_hero_wrapper_class = 'grid-item col-sm-12';
        		$post_template = 'portrait';
        		$post_hero_template = 'portrait-cutout';
        		$template_args_hero['thumb_reverse'] = 'yes';
        		$is_mixed = true;
		        break;

		    case 'grid-mixed-2':
		    	$section_content_class .= ' row row-space-around';
                $post_item_wrapper_class = 'grid-item col-sm-6';
        		$post_item_hero_wrapper_class = 'grid-item col-sm-12';
        		$post_template = 'portrait';
        		$post_hero_template = 'card-background-lg';
        		$is_mixed = true;
		        break;

		    case 'grid-mixed-no-sidebar':
		    	$section_content_class .= ' row row-space-around';
		        $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		        $post_item_hero_wrapper_class = 'grid-item col-sm-12';
		        $post_template = 'portrait';
		        $post_hero_template = 'landscape-lg';
		        $post_listing_args['hero_cycle'] = 7;
		        $is_mixed = true;
		        break;

		    case 'masonry-portrait':
		    	$section_content_class .= ' js-masonry row row-space-around';
		        $post_item_wrapper_class = 'masonry-item col-sm-6';
		        $post_template = 'portrait';
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'masonry-portrait-no-sidebar':
		    	$section_content_class .= ' js-masonry row row-space-around';
		        if ( $post_listing_args['grid_columns'] === '3' ) {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-4';
		            $post_template = 'portrait';
		        } else {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-3';
		            $post_template = 'portrait-sm';
		        }
		        if ( $post_listing_args['thumb_original_ratio'] === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'masonry-flow':
		    	$section_content_class .= ' js-masonry row row-space-around';
		    	if ( $post_listing_args['flow_columns'] === '3' ) {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-4';
		            $post_template = 'portrait-sm';
		            $template_args['thumb_size'] = 'nomady_sm';
		        } else {
		        	$post_item_wrapper_class = 'masonry-item col-md-6';
		            $post_template = 'portrait-lg';
		            $template_args['thumb_size'] = 'nomady_md';
		        }
				$min_post_padding = 0; // in percentage.
				$max_post_padding = 15; // in percentage.
		        break;
		}

		// Setting up query.
		if ( !$post_listing_args['post_query'] ) {
			$post_query = $GLOBALS['wp_query'];

			// Get current page.
			if ( get_query_var( 'paged' ) ) {
			    $paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
			    $paged = get_query_var( 'page' );
			} else {
			    $paged = 1;
			}
		} else {
			$post_query = $post_listing_args['post_query'];

			// Get current page.
			$paged = max( 1, $post_query->query_vars['paged'] );
		}

		$max_pages = $post_query->max_num_pages;
		$query_string = http_build_query( $post_query->query ); // Create query string for AJAX load post.

		$section_wrapper_attrs = array();
		$section_wrapper_attrs['layout'] = $post_listing_args['post_layout'];
		$section_wrapper_attrs['query'] = $query_string;
		$section_wrapper_attrs['current-page'] = $paged;
		$section_wrapper_attrs['max-pages'] = $max_pages;
		$section_wrapper_attrs['posts-per-page'] = $post_listing_args['query']['posts_per_page'];
		$section_wrapper_attrs['offset'] = $post_listing_args['query']['offset'];
		$section_wrapper_attrs['ignore-sticky-posts'] = $post_listing_args['ignore_sticky_posts'];

		if ( ( $post_listing_args['post_layout'] === 'grid-flow' ) || ( $post_listing_args['post_layout'] === 'masonry-flow' ) ) {
			$section_wrapper_attrs['columns'] = $post_listing_args['flow_columns'];
		} else {
			$section_wrapper_attrs['columns'] = $post_listing_args['grid_columns'];
		}

		$section_wrapper_attrs['post-template'] = $post_template;
		$section_wrapper_attrs['thumb-reverse'] = $post_listing_args['thumb_reverse'];
		$section_wrapper_attrs['thumb-original-ratio'] = $post_listing_args['thumb_original_ratio'];
		$section_wrapper_attrs['post-format-icon'] = $post_listing_args['post_format_icon'];
		$section_wrapper_attrs['post-meta-author'] = $post_listing_args['post_meta_author'];
		$section_wrapper_attrs['post-meta-date'] = $post_listing_args['post_meta_date'];

		if ( $post_listing_args['excerpt_length'] !== NULL ) {
			$section_wrapper_attrs['excerpt-length'] = $post_listing_args['excerpt_length'];
		}

		if ( $is_mixed ) {
			$section_wrapper_attrs['hero-post-templat'] = $post_hero_template;
			$section_wrapper_attrs['hero-cycle'] = $post_listing_args['hero_cycle'];
			$section_wrapper_attrs['hero-post-first'] = $post_listing_args['hero_post_first'];
			$section_wrapper_attrs['hero-cycle'] = $post_listing_args['hero_cycle'];

			if ( $post_listing_args['excerpt_length_hero'] !== NULL ) {
				$section_wrapper_attrs['excerpt-length-hero'] = $post_listing_args['excerpt_length_hero'];
			}
		}

		?>
        <div class="<?php echo esc_attr( $section_wrapper_class ); ?>"<?php
        	foreach ( $section_wrapper_attrs as $data_attr => $value ) {
        		echo ' data-' . esc_attr( $data_attr) . '="' . esc_attr( $value ) . '"';
        	}
        	?>>
            <div class="<?php echo esc_attr( $section_content_class ); ?>">
                <?php
                while ( $post_query->have_posts() ) {
                    $post_query->the_post();

                    if ( $is_mixed ) {
                    	if ( $post_listing_args['hero_post_first'] === 'yes' ) {
		                	if ( !( $post_query->current_post % $post_listing_args['hero_cycle'] ) ) {
		                		// Toggle thumb_reverse for hero post of grid-mixed-no-sidebar post layout.
		                		if ( ( $post_query->current_post > 0 ) && ( $post_listing_args['post_layout'] === 'grid-mixed-no-sidebar' ) ) {
		                			if ( $template_args_hero['thumb_reverse'] === 'yes' ) {
		                				$template_args_hero['thumb_reverse'] = 'no';
		                			} else {
		                				$template_args_hero['thumb_reverse'] = 'yes';
		                			}
		                		}

		                		echo '<div class="' . esc_attr( $post_item_hero_wrapper_class ) . '">';
		                		if ( ( $post_hero_template === 'card-background-lg' ) && !has_post_thumbnail() ) {
		                			nomady_get_template_part( 'template-parts/posts/post-portrait-cutout', NULL, $template_args_hero );
		                		} else {
		                			nomady_get_template_part( 'template-parts/posts/post-' . $post_hero_template, NULL, $template_args_hero );
		                		}
			                    echo '</div>';
			                } else {
			                    echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
			                    nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
			                    echo '</div>';
			                }
		                } else {
		                	if ( !( ( $post_query->current_post + 1 ) % $post_listing_args['hero_cycle'] ) ) {
		                		// Toggle thumb_reverse for hero post of grid-mixed-no-sidebar post layout.
		                		if ( ( $post_query->current_post > 0 ) && ( $post_listing_args['post_layout'] === 'grid-mixed-no-sidebar' ) ) {
		                			if ( $template_args_hero['thumb_reverse'] === 'yes' ) {
		                				$template_args_hero['thumb_reverse'] = 'no';
		                			} else {
		                				$template_args_hero['thumb_reverse'] = 'yes';
		                			}
		                		}

		                		echo '<div class="' . esc_attr( $post_item_hero_wrapper_class ) . '">';
		                		if ( ( $post_hero_template === 'card-background-lg' ) && !has_post_thumbnail() ) {
		                			nomady_get_template_part( 'template-parts/posts/post-portrait-cutout', $template_args_hero );
		                		} else {
		                			nomady_get_template_part( 'template-parts/posts/post-' . $post_hero_template, NULL, $template_args_hero );
		                		}
			                    echo '</div>';
			                } else {
			                    echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
			                    nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
			                    echo '</div>';
			                }
		                }
					} else {
						if ( ( ( $post_listing_args['post_layout'] === 'grid-flow' ) || ( $post_listing_args['post_layout'] === 'masonry-flow' ) ) && has_post_thumbnail() ) {
							$thumb_id   = get_post_thumbnail_id();
							$thumb_data = wp_get_attachment_image_src( $thumb_id , $template_args['thumb_size'] );

							// calculate new width by width - height relation.
							$padding_x = ( ( $thumb_data[2] / $thumb_data[1] ) * 12 ) - 4;

							// limit min and max padding.
							if ( $padding_x < $min_post_padding ) $padding_x = $min_post_padding;
							if ( $padding_x > $max_post_padding ) $padding_x = $max_post_padding;

							$template_args['inline_style'] = 'padding-left: ' . $padding_x . '%; padding-right: ' . $padding_x . '%;';

							if ( ( nomady_img_orientation_check() === 'horizontal' ) && ( $post_listing_args['post_layout'] === 'masonry-flow' ) ) {
								$padding_y = rand( $min_post_padding * .75, $max_post_padding * .75 );
								$template_args['inline_style'] .= 'padding-top: ' . $padding_y . '%; padding-bottom: ' . $padding_y . '%;';
							}
	                    }

						echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
	                    nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
	                    echo '</div>';
					}
                }
                ?>
            </div>

            <?php
            // Reset postdata
            wp_reset_postdata();
            ?>

            <?php
            if ( $post_listing_args['pagination'] !== 'none' ) {
            ?>
                <div class="post-listing-pagination">
                <?php
                if ( $post_listing_args['pagination'] !== 'view-more-url' ) {
                    nomady_pagination( array(
                    	'type' => $post_listing_args['pagination'],
                    	'max_pages' => $max_pages,
                    ) );
                } elseif ( $post_listing_args['view_more_url'] || $post_listing_args['view_more_url_title'] ) {
                ?>
                    <div class="text-center">
                        <a class="btn st-btn-secondary st-btn-icon-animation-on-hover view-more-btn" href="<?php echo esc_url( $post_listing_args['view_more_url']['url'] ); ?>"<?php if ( $post_listing_args['view_more_url']['is_external'] ) { echo ' target="_blank"'; } ?> rel="noopener noreferrer<?php if ( $post_listing_args['view_more_url']['nofollow'] ) { echo ' nofollow'; } ?>"><span><?php
                            echo esc_html( $post_listing_args['view_more_url_title'] );
                            ?></span><?php
                            echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                        ?></a>
                    </div>
                <?php
                }
                ?>
                </div>
            <?php
            }
            ?>
        </div>
    <?php
	}
}

/**
 * AJAX function to load posts
 */
if ( !function_exists( 'nomady_ajax_load_post' ) ){
	function nomady_ajax_load_post() {
		$query_args = isset( $_POST['query'] ) ? $_POST['query'] : ''; // Query string.
		$ignore_sticky_posts = isset( $_POST['ignoreStickyPosts'] ) ? $_POST['ignoreStickyPosts'] : 'yes';
		$posts_per_page = isset( $_POST['postsPerPage'] ) ? $_POST['postsPerPage'] : get_option( 'posts_per_page' );
		$current_page = isset( $_POST['currentPage'] ) ? $_POST['currentPage'] : 1;
		$layout = isset( $_POST['layout'] ) ? $_POST['layout'] : 'list-portrait';
		$columns = isset( $_POST['columns'] ) ? $_POST['columns'] : '3';
		$hero_cycle = isset( $_POST['heroCycle'] ) ? $_POST['heroCycle'] : 9999;
		$hero_post_first = isset( $_POST['heroFirst'] ) ? $_POST['heroFirst'] : true;
		$post_template = isset( $_POST['postTemplate'] ) ? $_POST['postTemplate'] : NULL;
		$post_hero_template = isset( $_POST['postHeroTemplate'] ) ? $_POST['postHeroTemplate'] : NULL;
		$thumb_reverse = isset( $_POST['thumbReverse'] ) ? $_POST['thumbReverse'] : 'no';
		$thumb_original_ratio = isset( $_POST['thumbOriginalRatio'] ) ? $_POST['thumbOriginalRatio'] : 'no';
		$post_format_icon = isset( $_POST['postFormatIcon'] ) ? $_POST['postFormatIcon'] : 'no';
		$excerpt_length = isset( $_POST['excerptLength'] ) ? $_POST['excerptLength'] : NULL;
		$excerpt_length_hero = isset( $_POST['excerptLengthHero'] ) ? $_POST['excerptLengthHero'] : NULL;

		// Convert empty value to PHP NULL.
		if ( $excerpt_length === '' ) {
			$excerpt_length = NULL;
		}
		if ( $excerpt_length_hero === '' ) {
			$excerpt_length_hero = NULL;
		}

		$is_mixed = false;
		$template_args = array();
		$template_args_hero = array();

		$template_args['thumb_reverse'] = $template_args_hero['thumb_reverse'] = $thumb_reverse;
		$template_args['post_format_icon'] = $post_format_icon;
		$template_args['excerpt_length'] = $excerpt_length;
		$template_args_hero['excerpt_length'] = $excerpt_length_hero;
		$template_args['lazyload'] = false;

		switch ( $layout ) {
		    case 'list-landscape':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'landscape';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'list-landscape-no-sidebar':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'landscape-wide';
		        break;

		    case 'list-portrait':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'portrait-xl';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_md';
		        }
		        break;

		    case 'list-portrait-no-sidebar':
		        $post_item_wrapper_class = 'stream-list-item';
		        $post_template = 'portrait-xl';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_lg';
		        } else {
		        	$template_args['thumb_size'] = 'nomady_lg_16_9';
		        }
		        break;

		    case 'list-mixed-1':
		    	$post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape';
        		$post_hero_template = 'portrait-cutout';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        	$template_args_hero['thumb_size'] = 'nomady_md';
		        }
        		$is_mixed = true;
		        break;

		    case 'list-mixed-2':
		        $post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape';
        		$post_hero_template = 'card-background-lg';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_md';
		        }
        		$is_mixed = true;
		        break;

		    case 'list-mixed-no-sidebar':
		        $post_item_wrapper_class = $post_item_hero_wrapper_class = 'stream-list-item';
        		$post_template = 'landscape-wide';
        		$post_hero_template = 'landscape-lg';
        		$is_mixed = true;
		        break;

		    case 'grid-portrait':
		    	$section_content_class .= ' row row-space-around';
		        $post_item_wrapper_class = 'grid-item col-sm-6';
		        $post_template = 'portrait';
		        break;

		    case 'grid-portrait-no-sidebar':
		    	$section_content_class .= ' row row-space-around';
		        if ( $columns === '3' ) {
		            $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		            $post_template = 'portrait';
		        } else {
		            $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-3';
		            $post_template = 'portrait-sm';
		        }
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'grid-flow':
		    	$section_content_class .= ' row row-space-around';
		        if ( $columns === '3' ) {
		    		$post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		            $post_template = 'portrait-sm';
		            $template_args['thumb_size'] = 'nomady_sm';
		    	} else {
		    		$post_item_wrapper_class = 'grid-item col-md-6';
		            $post_template = 'portrait-lg';
		            $template_args['thumb_size'] = 'nomady_md';
		    	}
				$min_post_padding = 0; // in percentage.
				$max_post_padding = 15; // in percentage.
		        break;

		    case 'grid-mixed-1':
		    	$section_content_class .= ' row row-space-around';
        		$post_item_wrapper_class = 'grid-item col-sm-6';
        		$post_item_hero_wrapper_class = 'grid-item col-sm-12';
        		$post_template = 'portrait';
        		$post_hero_template = 'portrait-cutout';
        		$template_args_hero['thumb_reverse'] = 'yes';
        		$is_mixed = true;

		        break;

		    case 'grid-mixed-2':
		    	$section_content_class .= ' row row-space-around';
                $post_item_wrapper_class = 'grid-item col-sm-6';
        		$post_item_hero_wrapper_class = 'grid-item col-sm-12';
        		$post_template = 'portrait';
        		$post_hero_template = 'card-background-lg';
        		$is_mixed = true;
		        break;

		    case 'grid-mixed-no-sidebar':
		    	$section_content_class .= ' row row-space-around';
		        $post_item_wrapper_class = 'grid-item col-sm-6 col-lg-4';
		        $post_item_hero_wrapper_class = 'grid-item col-sm-12';
		        $post_template = 'portrait';
		        $post_hero_template = 'landscape-lg';
		        $is_mixed = true;
		        break;

		    case 'masonry-portrait':
		    	$section_content_class .= ' js-masonry row row-space-around';
		        $post_item_wrapper_class = 'masonry-item col-sm-6';
		        $post_template = 'portrait';
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'masonry-portrait-no-sidebar':
		    	$section_content_class .= ' js-masonry row row-space-around';
		        if ( $columns === '3' ) {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-4';
		            $post_template = 'portrait';
		        } else {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-3';
		            $post_template = 'portrait-sm';
		        }
		        if ( $thumb_original_ratio === 'yes' ) {
		        	$template_args['thumb_size'] = 'nomady_sm';
		        }
		        break;

		    case 'masonry-flow':
		    	$section_content_class .= ' js-masonry row row-space-around';
		    	if ( $columns === '3' ) {
		            $post_item_wrapper_class = 'masonry-item col-sm-6 col-lg-4';
		            $post_template = 'portrait-sm';
		            $template_args['thumb_size'] = 'nomady_sm';
		        } else {
		        	$post_item_wrapper_class = 'masonry-item col-md-6';
		            $post_template = 'portrait-lg';
		            $template_args['thumb_size'] = 'nomady_md';
		        }
				$min_post_padding = 0; // in percentage.
				$max_post_padding = 15; // in percentage.
		        break;
		}

		parse_str( $query_args, $query_args ); // Convert query string into array.

		if ( empty( $query_args ) || !array_key_exists( 'paged', $query_args ) ) {
			$query_args['paged'] = $current_page;
		}

		if ( !array_key_exists( 'post_status', $query_args ) ) {
			if ( is_user_logged_in() ) {
				$query_args['post_status'] = array( 'publish', 'private' );
			} else {
				$query_args['post_status'] = 'publish';
			}
		}

		$post_query = new WP_Query( $query_args );

	    if( $post_query->have_posts() ) {
	        while ( $post_query->have_posts() ) {
				$post_query->the_post();
				if ( $ignore_sticky_posts === 'yes' ) {
					$loaded_post_count = ( $current_page - 1 ) * $posts_per_page;
				} else {
					$loaded_post_count = ( $current_page - 1 ) * $posts_per_page + count( get_option( 'sticky_posts' ) );
				}
				$overall_post_index = $post_query->current_post + $loaded_post_count;

				if ( $is_mixed ) {
		            	if ( $hero_post_first === 'yes' ) {
		                	if ( !( $overall_post_index % $hero_cycle ) ) {
		                		// Toggle thumb_reverse for hero post of grid-mixed-no-sidebar post layout.
		                		if ( ( $overall_post_index > $loaded_post_count ) && ( $layout === 'grid-mixed-no-sidebar' ) ) {
		                			if ( $template_args_hero['thumb_reverse'] === 'yes' ) {
		                				$template_args_hero['thumb_reverse'] = 'no';
		                			} else {
		                				$template_args_hero['thumb_reverse'] = 'yes';
		                			}
		                		}

		                		echo '<div class="' . esc_attr( $post_item_hero_wrapper_class ) . '">';
		                		if ( ( $post_hero_template === 'card-background-lg' ) && !has_post_thumbnail() ) {
		                			nomady_get_template_part( 'template-parts/posts/post-portrait-cutout', NULL, $template_args_hero );
		                		} else {
		                			nomady_get_template_part( 'template-parts/posts/post-' . $post_hero_template, NULL, $template_args_hero );
		                		}
			                    echo '</div>';
			                } else {
			                    echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
			                    nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
			                    echo '</div>';
			                }
		                } else {
		                	if ( !( ( $overall_post_index + 1 ) % $hero_cycle ) ) {
		                		// Toggle thumb_reverse for hero post of grid-mixed-no-sidebar post layout.
		                		if ( ( $overall_post_index > $loaded_post_count ) && ( $layout === 'grid-mixed-no-sidebar' ) ) {
		                			if ( $template_args_hero['thumb_reverse'] === 'yes' ) {
		                				$template_args_hero['thumb_reverse'] = 'no';
		                			} else {
		                				$template_args_hero['thumb_reverse'] = 'yes';
		                			}
		                		}

		                		echo '<div class="' . esc_attr( $post_item_hero_wrapper_class ) . '">';
		                		if ( ( $post_hero_template === 'card-background-lg' ) && !has_post_thumbnail() ) {
		                			nomady_get_template_part( 'template-parts/posts/post-portrait-cutout', NULL, $template_args_hero );
		                		} else {
		                			nomady_get_template_part( 'template-parts/posts/post-' . $post_hero_template, NULL, $template_args_hero );
		                		}
			                    echo '</div>';
			                } else {
			                    echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
			                    nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
			                    echo '</div>';
			                }
		                }
					} else {
						if ( ( ( $layout === 'grid-flow' ) || ( $layout === 'masonry-flow' ) ) && has_post_thumbnail() ) {
							$thumb_id   = get_post_thumbnail_id();
							$thumb_data = wp_get_attachment_image_src( $thumb_id , $template_args['thumb_size'] );

							// calculate new width by width - height relation.
							$padding_x = ( ( $thumb_data[2] / $thumb_data[1] ) * 12 ) - 4;

							// limit min and max padding.
							if ( $padding_x < $min_post_padding ) $padding_x = $min_post_padding;
							if ( $padding_x > $max_post_padding ) $padding_x = $max_post_padding;

							$template_args['inline_style'] = 'padding-left: ' . $padding_x . '%; padding-right: ' . $padding_x . '%;';

							if ( ( nomady_img_orientation_check() === 'horizontal' ) && ( $layout === 'masonry-flow' ) ) {
								$padding_y = rand( $min_post_padding * .75, $max_post_padding * .75 );
								$template_args['inline_style'] .= 'padding-top: ' . $padding_y . '%; padding-bottom: ' . $padding_y . '%;';
							}
		                }

						echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
		                nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $template_args );
		                echo '</div>';
					}
	        }
	    }

	    die();
	}
	add_action( 'wp_ajax_nopriv_ajax_load_post', 'nomady_ajax_load_post' );
	add_action( 'wp_ajax_ajax_load_post', 'nomady_ajax_load_post' );
}

/**
 * Display post comments number bubble.
 */
if ( !function_exists('nomady_post_comments_bubble') ) {
	function nomady_post_comments_bubble( $post_id = NULL ) {
		$link_title = '';
		$comments_number = get_comments_number( $post_id );
		$comments_link = get_comments_link( $post_id );
		if ( $comments_number != '0' ) {
			$link_title = sprintf( _nx( '%1$s comment', '%1$s comments', $comments_number, 'comments title', 'nomady' ), number_format_i18n( $comments_number ) );
		} else {
			$link_title = esc_html__('Comment', 'nomady');
		} ?>
		<a href="<?php echo esc_url( $comments_link ); ?>" title="<?php echo esc_attr( $link_title ); ?>" class="comments-number-bubble navigation-font">
			<?php echo esc_html( $comments_number ); ?>
		</a>
		<?php
	}
}

/**
 * Theme's pagination.
 */
if ( ! function_exists( 'nomady_pagination' ) ) {
	function nomady_pagination( $args = array() ) {
		// Merge with default value.
		$args = wp_parse_args( $args, array(
			'type' => 'default',
		    'max_pages' => 1,
		) );

		switch ( $args['type'] ) {
			case 'default':
			default:
				if ( $args['max_pages'] > 1 ) {
					// Get current page.
					if ( get_query_var( 'paged' ) ) {
					    $current = get_query_var( 'paged' );
					} elseif ( get_query_var( 'page' ) ) {
					    $current = get_query_var( 'page' );
					} else {
					    $current = 1;
					}

					$big = 999999999;

					$pagination = array(
						'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	            		'format' => '?paged=%#%',
						'total' => $args['max_pages'],
						'current' => $current,
						'mid_size' 	=> 1,
						'prev_text' => '<span class="sr-only">' . esc_html__( 'Previous page', 'nomady' ) . '</span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span>' . nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md', 'echo' => false ) ),
				    	'next_text' => '<span class="sr-only">' . esc_html__( 'Next page', 'nomady' ) . '</span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span>' . nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md', 'echo' => false ) ),
					);

					?>
					<nav class="navigation pagination mnmd-pagination mnmd-pagination-default">
						<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'nomady' ); ?></h2>
						<div class="nav-links d-flex align-items-center justify-content-center<?php if ( $current == 1 ) { echo ' is-on-first-page'; } if ( $current == $args['max_pages'] ) { echo ' is-on-last-page'; } ?>">
							<?php echo paginate_links( $pagination ); ?>
						</div>
					</nav>
					<?php
				}

				break;

			case 'next-and-previous':
				if ( $args['max_pages'] > 1 ) {
					// Get current page.
					if ( get_query_var( 'paged' ) ) {
					    $current = get_query_var( 'paged' );
					} elseif ( get_query_var( 'page' ) ) {
					    $current = get_query_var( 'page' );
					} else {
					    $current = 1;
					}
					?>
					<nav class="navigation pagination mnmd-pagination mnmd-pagination-next-n-prev">
						<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'nomady' ); ?></h2>
						<div class="nav-links d-flex align-items-center justify-content-center">
							<?php
							if ( get_previous_posts_link( '' ) ) {
							?>
								<a href="<?php previous_posts(); ?>" class="pagination-prev-link mr-auto"><span class="sr-only"><?php echo esc_html__( 'Newer posts', 'nomady' ); ?></span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span><?php echo nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md' ) ); ?></a>
							<?php
							} else {
							?>
								<span class="pagination-prev-link mr-auto"><span class="sr-only"><?php echo esc_html__( 'Newer posts', 'nomady' ); ?></span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span><?php echo nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md' ) ); ?></span>
							<?php
							}
							?>

							<div class="pagination-info">
								<?php printf( esc_html__( 'Page %1$s of %2$s', 'nomady' ), $current, $args['max_pages'] ); ?>
							</div>

							<?php
							if ( get_next_posts_link( '', $args['max_pages'] ) ) {
							?>
								<a href="<?php next_posts(); ?>" class="pagination-next-link ml-auto"><span class="sr-only"><?php echo esc_html__( 'Older posts', 'nomady' ); ?></span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span><?php echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md' ) ); ?></a>
							<?php
							} else {
							?>
								<span class="pagination-prev-link ml-auto"><span class="sr-only"><?php echo esc_html__( 'Older posts', 'nomady' ); ?></span><span class="mnmd-pagination-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle class="anicircle" cx="50" cy="50" r="48"/></svg></span><?php echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md' ) ); ?></span>
							<?php
							}
							?>
						</div>
					</nav>
					<?php
				}

				break;

			case 'ajax-load-more':
				echo '<div class="text-center">';
				echo '<button class="btn st-btn-secondary load-more-btn js-ajax-load-posts-btn is-active"><span class="load-more-btn-text">'.esc_html__( 'Load more', 'nomady' ).'</span><span class="spinner-ellipsis ml-1">.</span></button>';
				echo '</div>';

				break;
		}
	}
}

/**
 * Add an option to use both next and number for paginated post's pagination.
 */
if ( ! function_exists( 'mnmd_wp_link_pages_next_and_number' ) ) {
	function mnmd_wp_link_pages_next_and_number( $args ){
	    if ( $args['next_or_number'] === 'next_and_number' ) {
	        global $page, $numpages, $multipage, $more, $pagenow;
	        $args['next_or_number'] = 'number';
	        $prev = '';
	        $next = '';
	        if ( $multipage ) {
	            if ( $more ) {
	                $i = $page - 1;
	                if ( $i && $more ) {
	                	$prev .= '<span class="mnmd-post-pagination-prev">';
	                    $prev .= _wp_link_page( $i );
	                    $prev .=  nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-sm', 'echo' => false ) ) . $args['link_before'] . $args['previouspagelink'] . $args['link_after'] . '</a></span>';
	                }
	                $i = $page + 1;
	                if ( $i <= $numpages && $more ) {
	                	$next .= '<span class="mnmd-post-pagination-next">';
	                    $next .= _wp_link_page( $i );
	                    $next .= $args['link_before'] . $args['nextpagelink'] . $args['link_after'] . nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-sm', 'echo' => false ) ) . '</a></span>';
	                }
	            }
	        }
	        $args['before'] = $args['before'].$prev;
	        $args['after'] = $next.$args['after'];
	    }
	    return $args;
	}
	add_filter('wp_link_pages_args','mnmd_wp_link_pages_next_and_number');
}

/**
 * Enqueue the stylesheet for Customizer.
 */
if ( ! function_exists( 'nomady_customizer_styles' ) ) {
	function nomady_customizer_styles() {
		wp_register_style( 'mnmd-customizer-css', get_template_directory_uri() . '/assets/css/customizer.css', NULL, NULL, 'all' );
		wp_enqueue_style( 'mnmd-customizer-css' );
	}
	add_action( 'customize_controls_print_styles', 'nomady_customizer_styles' );
}

/**
 * Get sidebar list as choices for sidebar select control.
 */
if ( ! function_exists( 'nomady_sidebar_list' ) ) {
	function nomady_sidebar_list() {
	    do_action('widgets_init');
	 	$sidebars = array();
	 	if ( isset( $GLOBALS['wp_registered_sidebars'] ) ) {
	 		$sidebars = $GLOBALS['wp_registered_sidebars'];
	 	}
	 	$sidebars_choices = array();
	 	foreach ( $sidebars as $sidebar ) {
	 		$sidebars_choices[ $sidebar['id'] ] = $sidebar['name'];
	 	}
	    return $sidebars_choices;
	}
}

/**
 * Get theme option value.
 */
if ( ! function_exists( 'nomady_get_option' ) ) {
	function nomady_get_option( $opt, $default = NULL ) {
		$prefix = 'mnmd_nomady_';
		return get_theme_mod( $prefix . $opt, $default );
	}
}

/**
 * Get meta box value.
 */
if ( ! function_exists( 'nomady_get_meta_box' ) ) {
	function nomady_get_meta_box( $selector, $id = NULL, $default = NULL ) {
		if ( function_exists( 'get_field' ) ) {
			$prefix = 'field_mnmd_';
			if ( $id ) {
				return get_field( $prefix . $selector, $id );
			} else {
				return get_field( $prefix . $selector );
			}
		} else {
			return $default;
		}
	}
}

/**
 * Register ACF fields.
 */
if ( ! function_exists( 'mnmd_register_acf_fields' ) ) {
	function mnmd_register_acf_fields() {

		// Post format
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_format_audio',
			'title' => esc_html__( 'Post format: Audio', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_post_format_audio_url',
					'label' => esc_html__( 'Audio URL to embed. You can find all the supported sites here:', 'nomady' ) . ' <a href="https://wordpress.org/support/article/embeds/">https://wordpress.org/support/article/embeds/</a>',
					'name' => 'audio_url',
					'type' => 'oembed',
					'width' => '1920',
					'height' => '1080',
				),
				array(
					'key' => 'field_mnmd_post_format_audio_file',
					'label' => esc_html__( 'Or you can upload your own audio file:', 'nomady' ),
					'name' => 'audio_file',
					'type' => 'file',
					'return_format' => 'array',
					'library' => 'all',
					'max_size' => 64,
					'mime_types' => 'aac, mid, midi, mp3, oga, opus, wav, weba',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'audio',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_format_video',
			'title' => esc_html__( 'Post format: Video', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_post_format_video_url',
					'label' => esc_html__( 'Video URL', 'nomady' ),
					'name' => 'video_url',
					'type' => 'oembed',
					'width' => '1920',
					'height' => '1080',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'video',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_format_gallery',
			'title' => esc_html__( 'Post format: Gallery', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_post_format_gallery_files',
					'label' => esc_html__( 'Gallery', 'nomady' ),
					'name' => 'gallery_files',
					'type' => 'gallery',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'gallery',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_format_image',
			'title' => esc_html__( 'Post format: Image', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_post_format_image_file',
					'label' => esc_html__( 'Image', 'nomady' ),
					'name' => 'image_file',
					'type' => 'image',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'image',
					),
				),
			),
		) );

		// Post options
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_options',
			'title' => esc_html__( 'Nomady\'s settings', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_post_header_layout',
					'label' => esc_html__( 'Post header layout', 'nomady' ),
					'name' => 'post_header_layout',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'default'   => esc_html__( 'Image top', 'nomady' ),
						'title-top' => esc_html__( 'Title top', 'nomady' ),
				        'overlay'  => esc_html__( 'Overlay', 'nomady' ),
				        'split'  => esc_html__( 'Split', 'nomady' ),
				        'no-featured-image'  => esc_html__( 'No featured image', 'nomady' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_post_header_background_toggle',
					'label' => esc_html__( 'Post header\'s background', 'nomady' ),
					'name' => 'post_header_background_toggle',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_layout',
								'operator' => '==',
								'value' => 'title-top',
							),
						),
						array(
							array(
								'field' => 'field_mnmd_post_header_layout',
								'operator' => '==',
								'value' => 'split',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_color',
					'label' => esc_html__( 'Background color', 'nomady' ),
					'name' => 'post_header_background_color',
					'type' => 'color_picker',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_image',
					'label' => esc_html__( 'Background image', 'nomady' ),
					'name' => 'post_header_background_image',
					'type' => 'image',
					'return_format' => 'url',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_repeat',
					'label' => esc_html__( 'Background repeat', 'nomady' ),
					'name' => 'post_header_background_repeat',
					'type' => 'select',
					'choices' => array(
						'no-repeat'   => esc_html__( 'No Repeat', 'nomady' ),
						'repeat'   => esc_html__( 'Repeat All', 'nomady' ),
						'repeat-x' => esc_html__( 'Repeat Horizontally', 'nomady' ),
				        'repeat-y'  => esc_html__( 'Repeat Vertically', 'nomady' ),
					),
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_post_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_position',
					'label' => esc_html__( 'Background position', 'nomady' ),
					'name' => 'post_header_background_position',
					'type' => 'select',
					'choices' => array(
						'left top'   => esc_html__( 'Left Top', 'nomady' ),
						'left center'   => esc_html__( 'Left Center', 'nomady' ),
						'left bottom' => esc_html__( 'Left Bottom', 'nomady' ),
				        'right top'  => esc_html__( 'Right Top', 'nomady' ),
				        'right center'  => esc_html__( 'Right Center', 'nomady' ),
				        'right bottom'  => esc_html__( 'Right Bottom', 'nomady' ),
				        'center top'  => esc_html__( 'Center Top', 'nomady' ),
				        'center center'  => esc_html__( 'Center Center', 'nomady' ),
				        'center bottom'  => esc_html__( 'Center Bottom', 'nomady' ),
					),
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_post_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_size',
					'label' => esc_html__( 'Background Size', 'nomady' ),
					'name' => 'post_header_background_size',
					'type' => 'button_group',
					'choices' => array(
						'cover'   => esc_html__( 'Cover', 'nomady' ),
						'contain'   => esc_html__( 'Contain', 'nomady' ),
						'auto' => esc_html__( 'Auto', 'nomady' ),
					),
					'default_value' => 'cover',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_post_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_background_attachment',
					'label' => esc_html__( 'Background Attachment', 'nomady' ),
					'name' => 'post_header_background_attachment',
					'type' => 'button_group',
					'choices' => array(
						'scroll'   => esc_html__( 'Scroll', 'nomady' ),
						'fixed'   => esc_html__( 'Fixed', 'nomady' ),
					),
					'default_value' => 'scroll',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_post_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_width',
					'label' => esc_html__( 'Post header\'s width', 'nomady' ),
					'name' => 'post_header_width',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'default'   => esc_html__( 'Default', 'nomady' ),
						'wide'   => esc_html__( 'Wide', 'nomady' ),
						'fullwidth' => esc_html__( 'Full width', 'nomady' ),
				        'fullbleed'  => esc_html__( 'Full bleed', 'nomady' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_post_header_center',
					'label' => esc_html__( 'Center header', 'nomady' ),
					'name' => 'post_header_center',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_post_header_layout',
								'operator' => '!=',
								'value' => 'split',
							),
							array(
								'field' => 'field_mnmd_post_header_layout',
								'operator' => '!=',
								'value' => 'no-featured-image',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_post_header_excerpt_as_lead',
					'label' => esc_html__( "Display excerpt as article's lead", 'nomady' ),
					'name' => 'post_header_excerpt_as_lead',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_post_header_overlay_excerpt_inside',
					'label' => esc_html__( 'Show excerpt inside featured image', 'nomady' ),
					'name' => 'post_header_overlay_excerpt_inside',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							'field' => 'field_mnmd_post_header_layout',
							'operator' => '==',
							'value' => 'overlay',
						),
					),
				),
			),
			'location' => array(
				array(
					array(
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'post',
					),
				),
			),
			'position' => 'side',
		) );

		// Page options
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_page_options',
			'title' => esc_html__( 'Nomady\'s settings', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_page_header_layout',
					'label' => esc_html__( 'Page header layout', 'nomady' ),
					'name' => 'page_header_layout',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'default'   => esc_html__( 'Image top', 'nomady' ),
						'title-top' => esc_html__( 'Title top', 'nomady' ),
				        'overlay'  => esc_html__( 'Overlay', 'nomady' ),
				        'split'  => esc_html__( 'Split', 'nomady' ),
				        'no-ft-img'  => esc_html__( 'No featured image', 'nomady' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_page_header_background_toggle',
					'label' => esc_html__( 'Page header\'s background', 'nomady' ),
					'name' => 'page_header_background_toggle',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_layout',
								'operator' => '==',
								'value' => 'title-top',
							),
						),
						array(
							array(
								'field' => 'field_mnmd_page_header_layout',
								'operator' => '==',
								'value' => 'split',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_color',
					'label' => esc_html__( 'Background color', 'nomady' ),
					'name' => 'page_header_background_color',
					'type' => 'color_picker',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_image',
					'label' => esc_html__( 'Background image', 'nomady' ),
					'name' => 'page_header_background_image',
					'type' => 'image',
					'return_format' => 'url',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_repeat',
					'label' => esc_html__( 'Background repeat', 'nomady' ),
					'name' => 'page_header_background_repeat',
					'type' => 'select',
					'choices' => array(
						'no-repeat'   => esc_html__( 'No Repeat', 'nomady' ),
						'repeat'   => esc_html__( 'Repeat All', 'nomady' ),
						'repeat-x' => esc_html__( 'Repeat Horizontally', 'nomady' ),
				        'repeat-y'  => esc_html__( 'Repeat Vertically', 'nomady' ),
					),
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_page_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_position',
					'label' => esc_html__( 'Background position', 'nomady' ),
					'name' => 'page_header_background_position',
					'type' => 'select',
					'choices' => array(
						'left top'   => esc_html__( 'Left Top', 'nomady' ),
						'left center'   => esc_html__( 'Left Center', 'nomady' ),
						'left bottom' => esc_html__( 'Left Bottom', 'nomady' ),
				        'right top'  => esc_html__( 'Right Top', 'nomady' ),
				        'right center'  => esc_html__( 'Right Center', 'nomady' ),
				        'right bottom'  => esc_html__( 'Right Bottom', 'nomady' ),
				        'center top'  => esc_html__( 'Center Top', 'nomady' ),
				        'center center'  => esc_html__( 'Center Center', 'nomady' ),
				        'center bottom'  => esc_html__( 'Center Bottom', 'nomady' ),
					),
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_page_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_size',
					'label' => esc_html__( 'Background Size', 'nomady' ),
					'name' => 'page_header_background_size',
					'type' => 'button_group',
					'choices' => array(
						'cover'   => esc_html__( 'Cover', 'nomady' ),
						'contain'   => esc_html__( 'Contain', 'nomady' ),
						'auto' => esc_html__( 'Auto', 'nomady' ),
					),
					'default_value' => 'cover',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_page_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_background_attachment',
					'label' => esc_html__( 'Background Attachment', 'nomady' ),
					'name' => 'page_header_background_attachment',
					'type' => 'button_group',
					'choices' => array(
						'scroll'   => esc_html__( 'Scroll', 'nomady' ),
						'fixed'   => esc_html__( 'Fixed', 'nomady' ),
					),
					'default_value' => 'scroll',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_background_toggle',
								'operator' => '==',
								'value' => 'yes',
							),
							array(
								'field' => 'field_mnmd_page_header_background_image',
								'operator' => '!=empty',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_width',
					'label' => esc_html__( 'Post header\'s width', 'nomady' ),
					'name' => 'page_header_width',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'default'   => esc_html__( 'Default', 'nomady' ),
						'wide'   => esc_html__( 'Wide', 'nomady' ),
						'fullwidth' => esc_html__( 'Full width', 'nomady' ),
				        'fullbleed'  => esc_html__( 'Full bleed', 'nomady' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_page_header_center',
					'label' => esc_html__( 'Center header', 'nomady' ),
					'name' => 'page_header_center',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_page_header_layout',
								'operator' => '!=',
								'value' => 'split',
							),
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_overlay_excerpt_inside',
					'label' => esc_html__( 'Show excerpt inside featured image', 'nomady' ),
					'name' => 'page_header_overlay_excerpt_inside',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'nomady' ),
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							'field' => 'field_mnmd_page_header_layout',
							'operator' => '==',
							'value' => 'overlay',
						),
					),
				),
				array(
					'key' => 'field_mnmd_page_header_hide',
					'label' => esc_html__( 'Hide page header', 'nomady' ),
					'name' => 'page_header_hide',
					'type' => 'button_group',
					'choices' => array(
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'no',
				),
			),
			'location' => array(
				array(
					array(
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'page',
					),
				),
			),
			'position' => 'side',
		) );

		// Page template: Category Listing
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_page_category_listing_options',
			'title' => esc_html__( 'Page: Category Listing', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_page_category_listing_categories',
					'label' => esc_html__( 'Select categories', 'nomady' ),
					'name' => 'page_category_listing_categories',
					'type' => 'taxonomy',
					'instructions' => esc_html__( 'Select categories to be displayed alphabetically (leave empty to display all categories)', 'nomady' ),
					'taxonomy' => 'category',
					'field_type' => 'multi_select',
					'return_format' => 'id',
					'add_term' => 0,
					'save_terms' => 0,
					'load_terms' => 0,
				),
				array(
					'key' => 'field_mnmd_page_category_listing_layout',
					'label' => esc_html__( 'Layout', 'nomady' ),
					'name' => 'page_category_listing_layout',
					'type' => 'select',
					'choices' => array(
						'a'   => esc_html__( 'Layout 1', 'nomady' ),
						'b'   => esc_html__( 'Layout 2', 'nomady' ),
						'c'   => esc_html__( 'Layout 3', 'nomady' ),
					),
					'default_value' => 'b',
				),
				array(
					'key' => 'field_mnmd_page_category_listing_group_by_initial',
					'label' => esc_html__( 'Group categories alphabetically', 'nomady' ),
					'name' => 'page_category_listing_group_by_initial',
					'type' => 'button_group',
					'choices' => array(
						'yes'   => esc_html__( 'Yes', 'nomady' ),
						'no'   => esc_html__( 'No', 'nomady' ),
					),
					'default_value' => 'yes',
					'conditional_logic' => array(
						array(
							'field' => 'field_mnmd_page_category_listing_layout',
							'operator' => '!=',
							'value' => 'b',
						),
					),
				),
			),
			'location' => array(
				array(
					array(
						'param' => 'page_template',
						'operator' => '==',
						'value' => 'page-category-listing.php',
					),
				),
			),
			'position' => 'side',
		) );

		// Category
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_category',
			'title' => esc_html__( 'Nomady\'s setting', 'nomady' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_category_image',
					'label' => esc_html__( 'Featured image', 'nomady' ),
					'name' => 'image_file',
					'type' => 'image',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'taxonomy',
						'operator' => '==',
						'value' => 'category',
					),
				),
			),
		) );
	}
	add_action('acf/init', 'mnmd_register_acf_fields');
}

/**
 * Convert background array into string.
 */
if ( ! function_exists( 'nomady_background_style_convert' ) ) {
	function nomady_background_style_convert( $array = array() ) {
		extract( $array );
		$output = '';
		$output .= ( isset( $color ) && $color ) ? 'background-color:' . $color . ';' : '';
		$output .= ( isset( $color ) && $image ) ? 'background-image:url(' . $image . ');' : '';
		$output .= ( isset( $color ) && $position ) ? 'background-position:' . $position . ';' : '';
		$output .= ( isset( $color ) && $attachment ) ? 'background-attachment:' . $attachment . ';' : '';
		$output .= ( isset( $color ) && $size ) ? 'background-size:' . $size . ';' : '';
		$output .= ( isset( $color ) && $repeat ) ? 'background-repeat:' . $repeat . ';' : '';

		return $output;
	}
}

/**
 * Backwards compability for get_template_part()
 */
if ( ! function_exists( 'nomady_get_template_part' ) ) {
	function nomady_get_template_part( $slug, $name = NULL, $args = array() ) {
		// Check if current version of WordPress is later than 5.5
		if ( get_bloginfo( 'version' ) >= '5.5' ) {
			get_template_part( $slug, $name, $args );
		} else {
			set_query_var( 'args', $args );
			get_template_part( $slug, $name, $args );
			set_query_var( 'args', false );
		}
	}
}

/**
 * Lightens/darkens a given colour (hex format), returning the altered colour in hex format.7
 * @param str $hex Colour as hexadecimal (with or without hash);
 * @percent float $percent Decimal ( 0.2 = lighten by 20%(), -0.4 = darken by 40%() )
 * @return str Lightened/Darkend colour as hexadecimal (with hash);
 */

if ( !function_exists('nomady_color_luminance') ) {
	function nomady_color_luminance( $hexcolor, $percent ) {
		if ( strlen( $hexcolor ) < 6 ) {
			$hexcolor = $hexcolor[0] . $hexcolor[0] . $hexcolor[1] . $hexcolor[1] . $hexcolor[2] . $hexcolor[2];
		}
		$hexcolor = array_map( 'hexdec', str_split( str_pad( str_replace( '#', '', $hexcolor ), 6, '0' ), 2 ) );

		foreach ( $hexcolor as $i => $color ) {
			$from = $percent < 0 ? 0 : $color;
			$to = $percent < 0 ? $color : 255;
			$pvalue = ceil( ( $to - $from ) * $percent );
			$hexcolor[ $i ] = str_pad( dechex( $color + $pvalue ), 2, '0', STR_PAD_LEFT);
		}

		return '#' . implode( $hexcolor );
	}
}

/*
 * Have WPP track only 'post' post types page views, ignore the rest
 */

if ( ! function_exists( 'nomady_trackable_post_types' ) ) {
	function nomady_trackable_post_types( $post_types ) {
		return array( 'post' );
	}
}

add_filter( 'wpp_trackable_post_types', 'nomady_trackable_post_types', 10, 1 );

/*
 * Implements Yoast plugin's breadcrumb.
 */

if ( ! function_exists( 'nomady_breadcrumb' ) ) {
	function nomady_breadcrumb( $style = 'default' ) {
		if ( function_exists('yoast_breadcrumb') ) {
			if ( !is_home() || !is_front_page() ) {
				if ( $style === 'default' ) {
					yoast_breadcrumb( '<div class="st-breadcrumbs st-breadcrumbs-default">', '</div>' );
				} else {
					yoast_breadcrumb( '<div class="st-breadcrumbs st-breadcrumbs-masthead"><div class="container">', '</div></div>' );
				}

			}
		}
	}
}

/**
 * Limit number of tags in widget tag cloud
 */
if ( !function_exists( 'nomady_tag_widget_limit' ) ) {
	function nomady_tag_widget_limit( $args ) {
		$args['number'] = 16; //Limit number of tags
		$args['smallest'] = 1; //Size of lowest count tags
		$args['largest'] = 1; //Size of largest count tags
		$args['unit'] = 'em'; //Unit of font size
		$args['orderby'] = 'count'; //Order by counts
		$args['order'] = 'DESC';

		return $args;
	}
}

add_filter( 'widget_tag_cloud_args', 'nomady_tag_widget_limit' );

/**
 * Add SVG to wp_kses_post ruleset.
 */
if ( !function_exists( 'mnmd_wp_kses_post' ) ) {
	function mnmd_wp_kses_post( $html ) {
	    $kses_defaults = wp_kses_allowed_html( 'post' );
	    $svg_args = array(
	        'svg'   => array(
	            'class'           => true,
	            'aria-hidden'     => true,
	            'aria-labelledby' => true,
	            'role'            => true,
	            'xmlns'           => true,
	            'width'           => true,
	            'height'          => true,
	            'viewbox'         => true,
	            'fill'			  => true,
	        ),
	        'g'     => array( 'fill' => true ),
	        'title' => array( 'title' => true ),
	        'path'  => array(
	            'd'    => true,
	            'fill' => true,
	        ),
	    );
	    $allowed_tags = array_merge( $kses_defaults, $svg_args );
	    return wp_kses( $html, $allowed_tags );
	}
}

/**
 * Determine whether a hex color is light.
 *
 * @param mixed $color Color.
 * @return bool True if a light color.
 */
if ( ! function_exists( 'mnmd_hex_is_light' ) ) {
	function mnmd_hex_is_light( $color ) {
		$hex = str_replace( '#', '', $color );

		$c_r = hexdec( substr( $hex, 0, 2 ) );
		$c_g = hexdec( substr( $hex, 2, 2 ) );
		$c_b = hexdec( substr( $hex, 4, 2 ) );

		$brightness = ( ( $c_r * 299 ) + ( $c_g * 587 ) + ( $c_b * 114 ) ) / 1000;

		return $brightness > 155;
	}
}

/**
 * Shim for wp_body_open, ensuring backward compatibility with versions of WordPress older than 5.2.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

/**
 * Check if Block Editor is active.
 * Must only be used after plugins_loaded action is fired.
 *
 * @return bool
 */
function is_gutenberg_active() {
    // Gutenberg plugin is installed and activated.
    $gutenberg = ! ( false === has_filter( 'replace_editor', 'gutenberg_init' ) );

    // Block editor since 5.0.
    $block_editor = version_compare( $GLOBALS['wp_version'], '5.0-beta', '>' );

    if ( ! $gutenberg && ! $block_editor ) {
        return false;
    }

    if ( is_classic_editor_plugin_active() ) {
        $editor_option       = get_option( 'classic-editor-replace' );
        $block_editor_active = array( 'no-replace', 'block' );

        return in_array( $editor_option, $block_editor_active, true );
    }

    return true;
}

/**
 * Check if Classic Editor plugin is active.
 *
 * @return bool
 */
function is_classic_editor_plugin_active() {
    if ( ! function_exists( 'is_plugin_active' ) ) {
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
    }

    if ( class_exists( 'Classic_Editor' ) ) {
        return true;
    }

    return false;
}

/**
 * Remove Update notification and Admin menu for ACF PRO
 */

function nomady_acf_pro_remove_update_notification( $value ) {
	unset( $value->response['advanced-custom-fields-pro/acf.php'] );
	return $value;
}
add_filter( 'site_transient_update_plugins', 'nomady_acf_pro_remove_update_notification' );

function nomady_acf_pro_modify_settings() {
	if ( class_exists( 'acf_pro' ) && !class_exists( 'ACF' ) )  {
		acf_update_setting( 'show_admin', false );
    	acf_update_setting( 'show_updates', false );
	}
}
add_action( 'acf/init', 'nomady_acf_pro_modify_settings' );

// Disables the block editor from managing widgets in the Gutenberg plugin.
add_filter( 'gutenberg_use_widgets_block_editor', '__return_false', 100 );

// Disables the block editor from managing widgets. renamed from wp_use_widgets_block_editor
add_filter( 'use_widgets_block_editor', '__return_false' );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328160&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        