<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 */

// Get theme options.
$post_listing_args = nomady_get_post_listing_args();
$sidebar = nomady_get_option( 'blog_sidebar', 'mnmd-default' );
$sticky_sidebar = nomady_get_option( 'sticky_sidebar', 'yes' );

// Setting up variables
$section_class = 'mnmd-section mnmd-section-main-section post-listing-section post-listing-section-' . $post_listing_args['post_layout'];

get_header();

$page_title = '';
$page_subtitle = '';

if ( is_search() ) {
	global $wp_query;

	$page_title = sprintf(
		'%1$s %2$s',
		'<span>' . esc_html__( 'Search:', 'nomady' ) . '</span>',
		'&ldquo;' . get_search_query() . '&rdquo;'
	);

	if ( $wp_query->found_posts ) {
		$page_subtitle = sprintf(
			/* translators: %s: Number of search results. */
			_n(
				esc_html__( 'We found %s result for your search.', 'nomady' ),
				esc_html__( 'We found %s results for your search.', 'nomady' ),
				$wp_query->found_posts,
				'nomady'
			),
			number_format_i18n( $wp_query->found_posts )
		);
	} else {
		$page_subtitle = esc_html__( 'We could not find any results for your search.', 'nomady' );
	}
} elseif ( is_archive() && !have_posts() ) {
	$page_title = esc_html__( 'Nothing Found', 'nomady' );
} elseif ( !is_home() ) {
	$page_title    = get_the_archive_title();
	$page_subtitle = get_the_archive_description();
}

if ( $page_title || $page_subtitle ) {
?>
<header class="page-header">
	<div class="container">
		<h2 class="page-title display-5"><?php echo wp_kses_post( $page_title ); ?></h2>
		<?php
		if ( $page_subtitle ) {
		?>
			<div class="page-subtitle mnmd-lead"><?php echo wp_kses_post( wpautop( $page_subtitle ) ); ?></div>
		<?php
		}
		?>
	</div>
</header>
<?php
}
?>

<div id="primary" class="content-area">
	<?php
	if ( have_posts() ) {
	    if ( in_array( $post_listing_args['post_layout'], array( 'list-landscape', 'list-portrait', 'list-mixed-1', 'list-mixed-2', 'grid-portrait', 'grid-mixed-1', 'grid-mixed-2', 'masonry-portrait' ) ) ) {
	?>
	    <section class="mnmd-section mnmn-section-fullwidth mnmd-section-main-n-sidebar has-right-sidebar clearfix">
	        <div class="container">
	            <div class="mnmd-section-inner d-lg-flex">
	                <main class="mnmd-section mnmd-section-main">
	                    <section class="<?php echo esc_attr( $section_class ); ?>">
							<?php
							nomady_post_listing( $post_listing_args );
							?>
                        </section>
                    </main><!-- #main -->

	                <aside class="mnmd-section-sidebar sidebar<?php if ( $sticky_sidebar === 'yes' ) { echo ' js-mnmd-sticky-sidebar'; } ?>">
	                    <?php
	                    if ( $sticky_sidebar === 'yes' ) {
	                    	echo '<div class="theiaStickySidebar">';
	                    }

	                    if ( is_active_sidebar( $sidebar ) ) {
	                        dynamic_sidebar( $sidebar );
	                    } elseif ( current_user_can( 'administrator' ) ) {
	                    	global $wp_registered_sidebars;
	                    	$sidebar_name = $wp_registered_sidebars[$sidebar]['name'];
	                    	echo '<p style="padding: 32px;background-color:#f5f5f5;">';
	                    	printf(
								/* translators: 1: sidebar's name */
								esc_html__( 'Place widgets in %1$s widget area to make them appear here', 'nomady' ), $sidebar_name
							);
							echo '</p>';
	                    }

	                    if ( $sticky_sidebar === 'yes' ) {
	                    	echo '</div>';
	                    }
	                    ?>
	                </aside>
                </div>
            </div>
        </section>
    <?php
		} else {
	?>
		<section class="<?php echo esc_attr( $section_class ); ?>">
			<div class="container">
				<?php
				nomady_post_listing( $post_listing_args );
				?>
	        </div>
        </section>
    <?php
		}
	}
	?>

</div><!-- #primary -->

<?php
get_footer();