<?php
/**
 * The template for displaying all pages
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 */

// Get options.
$hide_header = nomady_get_meta_box( 'page_header_hide', NULL, 'no' );
if ( $hide_header !== 'yes' ) {
	$auto_header_layout = nomady_get_option( 'page_auto_header_style', 'yes' );

	$page_header_layout = nomady_get_meta_box( 'page_header_layout' );
	if ( !$page_header_layout || ( $page_header_layout === 'global') ) {
		$page_header_layout = nomady_get_option( 'page_header_style', 'default' );
	} else {
		$auto_header_layout = 'no'; // There's a specific layout set for this post therefore we will disable auto header layout.
	}

	$single_header_width = nomady_get_meta_box( 'page_header_width' );
	if ( !$single_header_width || ( $single_header_width === 'global') ) {
		$single_header_width = nomady_get_option( 'page_header_width', 'wide' );
	}

	if ( ( $page_header_layout !== 'no-ft-img' ) && has_post_thumbnail() ) {
		if ( ( nomady_img_orientation_check() === 'vertical' ) && ( $auto_header_layout === 'yes' ) ) {
			$page_header_layout = 'split';
		}
	} else {
		$page_header_layout = 'default';
	}
}

get_header();
?>
<div id="primary" class="content-area">
	<?php
	/* Start the Loop */
	if ( have_posts() ) {
		while ( have_posts() ) {
			the_post();
			?>
			<div class="mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous">
				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
					<?php
					if ( $hide_header !== 'yes' ) {
						get_template_part( 'template-parts/misc/page-header-' . $page_header_layout );
					}
					?>

					<div class="mnmd-section mnmd-section-fullwidth single-post-body">
						<div class="single-post-content-wrapper">
							<div class="single-post-content post-body-copy body-copy font-body-text entry-content clearfix">
								<?php
								if ( has_excerpt() && ( in_array( $page_header_layout, array( 'overlay', 'split' ) ) ) ) {
									if ( $page_header_layout === 'overlay' ) {
										$excerpt_inside = nomady_get_meta_box( 'page_header_overlay_excerpt_inside' );
										if ( !$excerpt_inside || ( $excerpt_inside === 'global') ) {
											$excerpt_inside = nomady_get_option( 'page_overlay_excerpt_inside', 'yes' );
										}

										if ( $excerpt_inside === 'yes' ) {
											echo '<div class="post-lead post-excerpt font-default d-xl-none">';
										} else {
											echo '<div class="post-lead post-excerpt font-default">';
										}

										the_excerpt();
										echo '</div>';
									} else {
										if ( $single_header_width === 'default' ) {
											echo '<div class="post-lead post-excerpt font-default d-none d-lg-block">';
										} else {
											echo '<div class="post-lead post-excerpt font-default d-none d-lg-block d-xl-none">';
										}

										the_excerpt();
										echo '</div>';
									}
								}
								?>

								<?php
								the_content();
								?>

								<?php
								wp_link_pages( array(
									'before'      		=> '<div class="mnmd-post-pagination font-meta">' . '<span class="mnmd-post-pagination-heading">' . esc_html__( 'Pages:', 'nomady' ) . '</span>',
									'after'       		=> '</div>',
									'linkbefore'      		=> '<span class="mnmd-post-pagination-item">' . esc_html__( 'Pages:', 'nomady' ),
									'linkafter'       		=> '</span>',
									'next_or_number'	=> 'next_and_number',
									'nextpagelink'     	=> esc_html__( 'Next page', 'nomady' ),
	        						'previouspagelink' 	=> esc_html__( 'Previous page', 'nomady' ),
								) );
								?>
							</div>
						</div>
					</div>
				</article>
			</div>

			<?php
			// If comments are open or we have at least one comment, load up the comment template.
			if ( comments_open() || get_comments_number() ) {
			?>
				<div class="mnmd-section mnmd-section-fullwidth post-comments-section">
					<div class="container-post-body">
						<?php comments_template(); ?>
					</div>
				</div>
			<?php
			}
		}
	}; // End of the loop.
	?>
</div><!-- #primary -->

<?php get_footer();