<?php
/**
 * The template for displaying all single posts
 */

// Get options.
$auto_header_layout = nomady_get_option( 'single_post_auto_header_style', 'yes' );

$single_header_layout = nomady_get_meta_box( 'post_header_layout' );
if ( !$single_header_layout || ( $single_header_layout === 'global') ) {
	$single_header_layout = nomady_get_option( 'single_post_header_style', 'default' );
} else {
	$auto_header_layout = 'no'; // There's a specific layout set for this post therefore we will disable auto header layout.
}

$single_header_width = nomady_get_meta_box( 'post_header_width' );
if ( !$single_header_width || ( $single_header_width === 'global') ) {
	$single_header_width = nomady_get_option( 'single_post_header_width', 'wide' );
}

$excerpt_as_lead = nomady_get_meta_box( 'post_header_excerpt_as_lead' );
if ( !$excerpt_as_lead || ( $excerpt_as_lead === 'global') ) {
	$excerpt_as_lead = nomady_get_option( 'single_post_excerpt_as_lead', 'yes' );
}
$social_share_switch = nomady_get_option( 'single_social_share_switch', 'yes' );
$author_box_switch = nomady_get_option( 'single_author_box_switch', 'yes' );
$related_posts_switch = nomady_get_option( 'single_related_posts_switch', 'yes' );

// Setting up variables.
$post_url =  get_permalink();
$post_format = get_post_format();
$post_image = NULL;

if ( ( $single_header_layout === 'overlay' ) && ( $post_format !== 'standard' ) ) {
	switch ( $post_format ) {
		case 'audio':
			$post_audio = nomady_get_meta_box( 'post_format_audio_url' );

			if ( !$post_audio ) {
				$post_audio = nomady_get_meta_box( 'post_format_audio_file' );
			}

			if ( $post_audio ) {
				$single_header_layout = 'default';
			}
			break;

		case 'gallery':
			$post_gallery = nomady_get_meta_box( 'post_format_gallery_files' );

			if ( $post_gallery ) {
				$single_header_layout = 'default';
			}
			break;

		case 'image':
			$post_image = nomady_get_meta_box( 'post_format_image_file' );

			if ( $post_image ) {
				if ( ( nomady_img_orientation_check( $post_image['ID'] ) === 'vertical' ) && ( $auto_header_layout === 'yes' ) ) {
					$single_header_layout = 'split';
				} else {
					$single_header_layout = 'default';
				}
			}
			break;

		case 'video':
			$post_video = nomady_get_meta_box( 'post_format_video_url' );

			if ( $post_video ) {
				$single_header_layout = 'default';
			}
			break;
	}
}

if ( ( $single_header_layout === 'default' ) || ( $single_header_layout === 'title-top' ) ) {
	if ( $post_format === 'image' ) {
		$post_image = nomady_get_meta_box( 'post_format_image_file' );
	} elseif ( !has_post_thumbnail() && ( $post_format === 'standard' ) ) {
		$single_header_layout = 'no-featured-image';
	}
}

if ( ( $single_header_layout !== 'no-featured-image' ) && ( has_post_thumbnail() || $post_image ) ) {
	if ( $post_image ) {
		if ( ( nomady_img_orientation_check( $post_image['ID'] ) === 'vertical' ) && ( $auto_header_layout === 'yes' ) ) {
			$single_header_layout = 'split';
		}
	} else {
		if ( ( nomady_img_orientation_check() === 'vertical' ) && ( $auto_header_layout === 'yes' ) ) {
			$single_header_layout = 'split';
		}
	}
}

get_header();
?>
<div id="primary" class="content-area">
	<?php
	/* Start the Loop */
	if ( have_posts() ) {
		while ( have_posts() ) {
			the_post();
			?>

			<div class="mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous">
				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
					<?php
						nomady_get_template_part( 'template-parts/misc/single-header-' . $single_header_layout, NULL, array(
							'excerpt_as_lead' => $excerpt_as_lead,
						) );
					?>

					<div class="mnmd-section mnmd-section-fullwidth single-post-body">
						<div class="single-post-content-wrapper">
							<div class="single-post-content post-body-copy body-copy font-body-text entry-content clearfix">
								<?php
								if ( has_excerpt() && ( $excerpt_as_lead === 'yes' ) && ( in_array( $single_header_layout, array( 'split', 'overlay' ) ) ) ) {
										if ( $single_header_layout === 'split' ) {
											echo '<div class="post-lead post-excerpt font-default d-none d-lg-block d-xl-none">';
										} else {
											echo '<div class="post-lead post-excerpt font-default">';
										}
												the_excerpt();
											echo '</div>';
								}
								?>

								<?php
								the_content();
								?>

								<?php
								wp_link_pages( array(
									'before'      		=> '<div class="mnmd-post-pagination font-meta">' . '<span class="mnmd-post-pagination-heading">' . esc_html__( 'Pages:', 'nomady' ) . '</span>',
									'after'       		=> '</div>',
									'linkbefore'      		=> '<span class="mnmd-post-pagination-item">' . esc_html__( 'Pages:', 'nomady' ),
									'linkafter'       		=> '</span>',
									'next_or_number'	=> 'next_and_number',
									'nextpagelink'     	=> esc_html__( 'Next page', 'nomady' ),
	        						'previouspagelink' 	=> esc_html__( 'Previous page', 'nomady' ),
								) );
								?>
							</div>
						</div>

						<div class="single-post-footer">
							<div class="container-post-body">
								<?php
								if ( ( $social_share_switch === 'yes' ) && ( class_exists( 'Nomady_Core' ) ) ) {
								?>
									<div class="single-post-footer-row single-post-social-share">
										<div class="mnmd-social-share mnmd-social-share-inline text-center">
											<?php
											Nomady_Core::post_social_share( [
												'url' => $post_url,
												'title' => get_the_title(),
												'image' => get_the_post_thumbnail( 'nomady_sm' ),
												'desc' => get_the_excerpt(),
											] );
											?>
										</div>
									</div>
								<?php
								}
								?>

								<div class="single-post-footer-row">
									<div class="row">
										<?php
										$post_categories = get_the_category();
										if ( $post_categories ) {
										?>
											<div class="col-md single-post-categories mb-4 mb-md-0">
												<h5 class="single-post-footer-section-heading font-meta"><?php echo esc_html__( 'Filed under', 'nomady' ) ?></h5>
												<?php
												nomady_post_categories_with_count();
												?>
											</div>
										<?php
										}
										?>

										<?php
										$post_tags = get_the_tags();
										if ( $post_tags ) {
										?>
											<div class="col-md single-post-tags">
												<h5 class="single-post-footer-section-heading font-meta"><?php echo esc_html__( 'Tags', 'nomady' ) ?></h5>
												<?php
												nomady_post_tags();
												?>
											</div>
										<?php
										}
										?>
									</div>
								</div>

								<?php
								$author_bio = get_the_author_meta( 'description' );
								if ( ( $author_bio !== '' ) && ( $author_box_switch === 'yes' ) ) {
								?>
									<div class="single-post-footer-row single-post-author-box">
										<?php
										get_template_part( 'template-parts/misc/author-box' );
										?>
									</div>
								<?php
								}
								?>

								<?php
								if ( !post_password_required() && comments_open() ) {
								?>
								<div class="single-post-footer-row">
									<div class="single-post-footer-section single-post-comments-count text-center">
										<a class="btn st-btn-secondary has-icon-first" href="<?php echo get_comments_link( get_the_ID() ); ?>"><?php echo nomady_svg_icon( [ 'icon' => 'message-square', 'class' => 'mnmd-icon-md' ] ); ?><span><?php
										$comments_number = get_comments_number();
										if ( $comments_number !== '0' ) {
											printf(
												/* translators: 1: number of comments, 2: post title */
												esc_html( _nx(
													'There is %1$s comment',
													'There are %1$s comments',
													$comments_number,
													'comments title',
													'nomady'
												) ),
												number_format_i18n( $comments_number )
											);
										} else {
											echo esc_html__( 'Be the first to comment', 'nomady' );
										}
										?></span></a>
									</div>
								</div>
								<?php
								}
								?>
							</div>
						</div>

						<div class="post-navigation-wrapper">
							<div class="container-post-body">
								<div class="post-navigation-inner">
									<?php
									the_post_navigation( array(
										'prev_text' => '<span class="mnmd-post-navigation-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle fill="none" cx="50" cy="50" r="48"/></svg></span>' . nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md', 'echo' => false ) ) . '<span class="sr-only">' . esc_html__( 'Previous Post', 'nomady' ) . '</span><div aria-hidden="true" class="nav-subtitle font-meta">' . esc_html__( 'Previous', 'nomady' ) . '</div><h5 class="nav-title">%title</h5>',
										'next_text' => '<span class="mnmd-post-navigation-circle"><svg width="48px" height="48px" viewBox="0 0 100 100"><circle fill="none" cx="50" cy="50" r="48"/></svg></span>' . nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md', 'echo' => false ) ) . '<span class="sr-only">' . esc_html__( 'Next Post', 'nomady' ) . '</span><div aria-hidden="true" class="nav-subtitle font-meta">' . esc_html__( 'Next', 'nomady' ) . '</div><h5 class="nav-title">%title</h5>',
									) );
									?>
								</div>
							</div>
						</div>
					</div>
				</article>
			</div>

			<?php
			if ( is_active_sidebar( 'mnmd-after-post-content' ) ) {
			?>
				<div class="mnmd-section mnmd-section-fullwidth mnmd-widget-area-after-post-content">
					<div class="container">
						<?php dynamic_sidebar( 'mnmd-after-post-content' ); ?>
					</div>
				</div>
			<?php
			}
			?>

			<?php
			if ( $related_posts_switch === 'yes' ) {
				get_template_part( 'template-parts/sections/related-posts' );
			}
			?>

			<?php
			// If comments are open or we have at least one comment, load up the comment template.
			if ( comments_open() || get_comments_number() ) {
			?>
				<div class="mnmd-section mnmd-section-fullwidth post-comments-section">
					<div class="container-post-body">
						<?php comments_template(); ?>
					</div>
				</div>
			<?php
			}
		}
	}; // End of the loop.
	?>
</div><!-- #primary -->

<?php get_footer();