<?php
/**
 * Display single post header: Split.
 */

// Get options.
$page_header_width = nomady_get_meta_box( 'page_header_width' );
if ( !$page_header_width || ( $page_header_width === 'global') ) {
	$page_header_width = nomady_get_option( 'page_header_width', 'wide' );
}

$background_toggle = nomady_get_meta_box( 'page_header_background_toggle' );
if ( $background_toggle === 'global' ) {
	$background_toggle = nomady_get_option( 'page_header_background_toggle' );
} elseif ( $background_toggle === 'yes' ) {
	$background = array(
		'color' => nomady_get_meta_box( 'page_header_background_color' ),
		'image' => nomady_get_meta_box( 'page_header_background_image' ),
		'repeat' => nomady_get_meta_box( 'page_header_background_repeat' ),
		'position' => nomady_get_meta_box( 'page_header_background_position' ),
		'size' => nomady_get_meta_box( 'page_header_background_size' ),
		'attachment' => nomady_get_meta_box( 'page_header_background_attachment' ),
	);
}

// Setting up variables.
$post_time_attr = get_the_time( 'c' );
$post_time = get_the_time( get_option( 'date_format' ) );
$post_format = get_post_format();

$header_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous single-post-header single-post-header-split single-post-header-width-' . $page_header_width;
$title_class = 'single-post-title post-title entry-title h1 display-5-sm h2-lg h1-xl';
$header_text_class = 'single-post-header-text';

switch ( $page_header_width ) {
	case 'wide':
		$container_class = 'container-xl-fullwidth container-xxl-wide';
		$title_class .= ' display-5-xxl';
		break;

	case 'fullwidth':
		$container_class = 'container-xl-fullwidth';
		$title_class .= ' display-5-xxl';
		break;

	case 'fullbleed':
		$container_class = 'container-xl-fullbleed';
		$title_class .= ' display-5-xxl';
		break;

	default:
		$container_class = 'container-xl';
		if ( !isset( $background ) || ( $background_toggle !== 'yes' ) ) {
			$header_text_class .= ' pl-xl-0';
		}
		break;
}

if ( has_post_thumbnail() ) {
	if ( nomady_img_orientation_check() === 'vertical' ) {
		$thumb_size = 'nomady_lg_org';
	} else {
		if ( $page_header_width === 'default' ) {
			$thumb_size = 'nomady_lg_1_1';
		} else {
			$thumb_size = 'nomady_lg_4_3';
		}

		// Check if image is taller than 800px, if yes then we can stretch it.
		$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), $thumb_size );
		if ( $thumb_data[2] >= 800 ) {
			$header_class .= ' single-post-header-split-image-fit';
		}
	}
}

if ( $background_toggle === 'yes' ) {
	$header_class .= ' single-post-header-has-background mnmd-section-first-contiguous';
}
?>
<header class="<?php echo esc_attr( $header_class ); ?>">
	<div class="single-post-header-wrapper">
		<?php
		if ( $background_toggle === 'yes' ) {
		?>
		<div class="mnmd-section-background background-object"<?php if ( isset( $background ) && ( $background_toggle === 'yes' ) ) { echo ' style="' . esc_attr( nomady_background_style_convert( $background ) ) . '"'; } ?>></div>
		<?php
		}
		?>

		<div class="<?php echo esc_attr( $container_class ); ?>">
			<div class="single-post-header-inner">
				<div class="row">
					<div class="col-12 col-lg-6 order-lg-1 d-flex align-items-center justify-content-lg-end<?php if ( $page_header_width === 'default' ) { echo ' col-xl-6'; } else { echo ' col-xl-7'; } ?>">
						<?php
						if ( has_post_thumbnail() ) {
							nomady_featured_img( array(
								'size' => $thumb_size,
								'class' => 'single-post-header-image d-lg-flex align-items-center',
								'link'=> false,
							) );
						}
						?>
					</div>

					<div class="col-12 col-lg-6 d-flex align-items-center<?php if ( $page_header_width === 'default' ) { echo ' col-xl-6'; } else { echo ' col-xl-5'; } ?>">
						<div class="<?php echo esc_attr( $header_text_class ); ?>">
							<div class="container px-lg-0">
								<div class="single-post-header-text-inner">
									<?php nomady_breadcrumb(); ?>

									<div class="post-meta single-post-meta">
										<?php nomady_post_categories(); ?>
									</div>

									<?php
									the_title( '<h1 class="'. esc_attr( $title_class ) .'">', '</h1>' );
									?>

									<?php
									if ( has_excerpt() ) {
										if ( $page_header_width === 'default' ) {
											echo '<div class="single-post-excerpt font-default d-lg-none d-xl-block">';
										} else {
											echo '<div class="single-post-excerpt font-default d-lg-none d-xl-block">';
										}
												the_excerpt();
											echo '</div>';
									}
									?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</header>