<?php
/**
 * Display single post header: Title top.
 */

// Get options.
$page_header_center = nomady_get_meta_box( 'page_header_center' );
if ( !$page_header_center || ( $page_header_center === 'global') ) {
	$page_header_center = nomady_get_option( 'page_header_center', 'no' );
}

$page_header_width = nomady_get_meta_box( 'page_header_width' );
if ( !$page_header_width || ( $page_header_width === 'global') ) {
	$page_header_width = nomady_get_option( 'page_header_width', 'wide' );
}

$background_toggle = nomady_get_meta_box( 'page_header_background_toggle' );
if ( $background_toggle === 'global' ) {
	$background_toggle = nomady_get_option( 'page_header_background_toggle' );
} elseif ( $background_toggle === 'yes' ) {
	$background = array(
		'color' => nomady_get_meta_box( 'page_header_background_color' ),
		'image' => nomady_get_meta_box( 'page_header_background_image' ),
		'repeat' => nomady_get_meta_box( 'page_header_background_repeat' ),
		'position' => nomady_get_meta_box( 'page_header_background_position' ),
		'size' => nomady_get_meta_box( 'page_header_background_size' ),
		'attachment' => nomady_get_meta_box( 'page_header_background_attachment' ),
	);
}

// Setting up variables.
$header_class = 'mnmd-section mnmd-section-fullwidth single-post-header single-post-header-title-top single-post-header-ft-img-' . $page_header_width;
$thumb_size = 'nomady_lg';
$post_time_attr = get_the_time( 'c' );
$post_time = get_the_time( get_option( 'date_format' ) );

if ( $page_header_center === 'yes' ) {
	$header_class .= ' single-post-header-center';
}

switch ( $page_header_width ) {
	case 'wide':
		$container_class = 'container-xl-fullwidth container-xxl-wide';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2.5 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_lg' );
				if ( $thumb_data[2] > 600 ) {
					$thumb_size = 'nomady_5_2';
				}
			}
		}
		break;

	case 'fullwidth':
		$container_class = 'container-xl-fullwidth';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2.5 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_org' );
				if ( $thumb_data[2] > 600 ) {
					$thumb_size = 'nomady_5_2';
				} else {
					$thumb_size = 'nomady_org';
				}
			}
		}
		break;

	case 'fullbleed':
		$container_class = 'container-xl-fullbleed';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2.5 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_org' );
				if ( $thumb_data[2] > 600 ) {
					$thumb_size = 'nomady_5_2';
				} else {
					$thumb_size = 'nomady_org';
				}
			}
		}
		break;

	default:
		$container_class = 'container';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_lg' );
				if ( $thumb_data[2] > 600 ) {
					$thumb_size = 'nomady_lg_2_1';
				}
			}
		}
		break;
}

if ( $background_toggle === 'yes' ) {
	$header_class .= ' mnmd-section-first-contiguous mnmd-section-has-background';
	if ( has_post_thumbnail() ) {
		$header_class .= ' mnmd-section-has-background-overlap-top';
	}
}
?>
<header class="<?php echo esc_attr( $header_class ); ?>">
	<div class="single-post-header-text">
		<?php
		if ( $background_toggle === 'yes' ) {
		?>
		<div class="mnmd-section-background background-object"<?php if ( isset( $background ) && ( $background_toggle === 'yes' ) ) { echo ' style="' . esc_attr( nomady_background_style_convert( $background ) ) . '"'; } ?>></div>
		<?php
		}
		?>

		<div class="container">
			<div class="single-post-header-text-inner">
				<?php nomady_breadcrumb(); ?>

				<?php
				the_title( '<h1 class="single-post-title post-title entry-title h1 display-5-sm display-4-xl">', '</h1>' );
				?>
			</div>
		</div>
	</div>

	<?php
	if ( has_post_thumbnail() ) {
	?>
		<div class="single-post-header-image">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<div class="single-post-header-image-inner text-center">
					<?php
					nomady_featured_img( array(
						'size' => $thumb_size,
						'link'=> false,
					) );
					?>
				</div>
			</div>
		</div>
	<?php
	}
	?>
</header>