<?php
/**
 * Display single post header: Default.
 */

if ( isset( $args ) ) extract( $args ); // extract passed variables.

( isset( $excerpt_as_lead ) ) || $excerpt_as_lead = 'yes';

// Get options.
$single_header_center = nomady_get_meta_box( 'post_header_center' );
if ( !$single_header_center || ( $single_header_center === 'global') ) {
	$single_header_center = nomady_get_option( 'single_post_header_center', 'no' );
}

$single_header_width = nomady_get_meta_box( 'post_header_width' );
if ( !$single_header_width || ( $single_header_width === 'global') ) {
	$single_header_width = nomady_get_option( 'single_post_header_width', 'wide' );
}

// Setting up variables.
$header_class = 'mnmd-section mnmd-section-fullwidth single-post-header single-post-header-default single-post-header-ft-img-' . $single_header_width;
$thumb_size = 'nomady_lg';
$post_time_attr = get_the_time( 'c' );
$post_time = get_the_time( get_option( 'date_format' ) );
$post_format = get_post_format();
$post_audio = NULL;
$post_gallery = NULL;
$post_image = NULL;
$post_video = NULL;


if ( $single_header_center === 'yes' ) {
	$header_class .= ' single-post-header-center';
}

if ( has_post_thumbnail() ) {
	$header_class .= ' mnmd-section-first-contiguous';
}

switch ( $single_header_width ) {
	case 'wide':
		$container_class = 'container-xl-fullwidth container-xxl-wide';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_lg' );
				if ( $thumb_data ) {
					if ( $thumb_data[2] > 900 ) {
						$thumb_size = 'nomady_lg_2_1';
					}
				}
			}
		}
		break;

	case 'fullwidth':
		$container_class = 'container-xl-fullwidth';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2.5 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_org' );
				if ( $thumb_data[2] > 900 ) {
					$thumb_size = 'nomady_5_2';
				} else {
					$thumb_size = 'nomady_org';
				}
			}
		}
		break;

	case 'fullbleed':
		$container_class = 'container-xl-fullbleed';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() <= 2.5 ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_org' );
				if ( $thumb_data[2] > 900 ) {
					$thumb_size = 'nomady_5_2';
				} else {
					$thumb_size = 'nomady_org';
				}
			}
		}
		break;

	default:
		$container_class = 'container';
		if ( has_post_thumbnail() ) {
			if ( nomady_img_aspect_ratio() < ( 16 / 9 ) ) {
				$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), 'nomady_lg' );
				if ( $thumb_data[2] > 700 ) {
					$thumb_size = 'nomady_lg_16_9';
				}
			}
		}
		break;
}

switch ( $post_format ) {
	case 'audio':
		$post_audio = nomady_get_meta_box( 'post_format_audio_url' );
		if ( $post_audio ) {
			$post_audio_is_embed = true;
			$header_class .= ' mnmd-section-first-contiguous';
		} else {
			$post_audio_is_embed = false;
			$post_audio = nomady_get_meta_box( 'post_format_audio_file' );
			$header_class .= ' mnmd-section-first-contiguous';
		}
		break;

	case 'gallery':
		$post_gallery = nomady_get_meta_box( 'post_format_gallery_files' );
		if ( $post_gallery ) {
			$header_class .= ' mnmd-section-first-contiguous';
		}
		break;

	case 'image':
		$post_image = nomady_get_meta_box( 'post_format_image_file' );
		if ( $post_image ) {
			$header_class .= ' mnmd-section-first-contiguous';
		}
		break;

	case 'video':
		$post_video = nomady_get_meta_box( 'post_format_video_url' );
		if ( $post_video ) {
			$header_class .= ' mnmd-section-first-contiguous';
		}
		break;
}
?>
<header class="<?php echo esc_attr( $header_class ); ?>">
	<?php
	if ( $post_audio ) {
	?>
		<div class="single-post-header-media">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<?php
				if ( $post_audio_is_embed ) {
					echo '<div class="mnmd-post-media mnmd-post-media-audio mnmd-responsive-embed">' . $post_audio . '</div>';
				} else {
					$post_audio_url = '';
					$post_audio_title = '';
					if ( array_key_exists( 'url', $post_audio ) ) {
						$post_audio_url = $post_audio['url'];
					}
					if ( array_key_exists( 'title', $post_audio ) ) {
						$post_audio_title = $post_audio['title'];
					}
				?>
					<div class="single-post-header-image">
						<div class="single-post-header-image-inner text-center">
							<?php
							nomady_featured_img( array(
								'size' => $thumb_size,
								'link'=> false,
							) );
							?>
						</div>
					</div>

					<div class="mnmd-post-media mnmd-post-media-audio">
						<audio controls>
							<source src="<?php echo esc_url( $post_audio_url ); ?>">
						</audio>
					</div>
				<?php
				}
				?>
			</div>
		</div>
	<?php
	} elseif ( $post_gallery ) {
	?>
		<div class="single-post-header-media">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<div class="mnmd-post-media mnmd-post-media-gallery">
					<div class="single-format-gallery-wrap">
					    <div class="single-format-gallery mnmd-gallery-carousel js-mnmd-gallery-carousel swiper-container">
					    	<div class="swiper-wrapper js-mnmd-lightbox-gallery" itemscope itemtype="http://schema.org/ImageGallery">
						        <?php
						        foreach( $post_gallery as $image ) {
						        	echo '<figure class="swiper-slide" itemprop="associatedMedia" itemscope itemtype="http://schema.org/ImageObject">';
						        		echo '<a href="' . esc_url( $image['url'] ) . '" itemprop="contentUrl" data-size="' . esc_attr( $image['width'] ) . 'x' . esc_attr( $image['height'] ) . '">';
							        			echo wp_get_attachment_image(  $image['ID'], 'nomady_lg', false, array( 'itemprop' => 'thumbnail') );
										echo '</a>';

										if ( $image[ 'caption' ] !== '' ) {
											echo '<figcaption itemprop="caption description" class="mnmd-gallery-carousel-item-caption">' . $image[ 'caption' ] . '</figcaption>';
										}
									echo '</figure>';
						    	}
						    	?>
					    	</div>
					    	<div class="swiper-scrollbar"></div>
					    </div>
					</div>
				</div>
			</div>
		</div>
	<?php
	} elseif ( $post_image ) {
	?>
		<div class="single-post-header-media">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<div class="mnmd-post-media mnmd-post-media-image js-mnmd-lightbox-gallery" itemscope itemtype="http://schema.org/ImageGallery">
			        <?php
		        	echo '<figure class="mnmd-post-media-image-img" itemprop="associatedMedia" itemscope itemtype="http://schema.org/ImageObject">';
		        		echo '<a href="' . esc_url( $post_image['url'] ) . '" itemprop="contentUrl" data-size="' . esc_attr( $post_image['width'] ) . 'x' . esc_attr( $post_image['height'] ) . '">';
			        			echo wp_get_attachment_image(  $post_image['ID'], 'nomady_xl', false, array( 'itemprop' => 'thumbnail') );
						echo '</a>';

						if ( $post_image[ 'caption' ] !== '' ) {
							echo '<figcaption itemprop="caption description" class="mnmd-post-media-image-caption">' . $post_image[ 'caption' ] . '</figcaption>';
						}
					echo '</figure>';
			    	?>
				</div>
			</div>
		</div>
	<?php
	} elseif ( $post_video ) {
	?>
		<div class="single-post-header-media">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<div class="mnmd-post-media mnmd-post-media-video mnmd-responsive-embed">
					<?php echo '<div class="mnmd-responsive-video">' . $post_video . '</div>'; ?>
				</div>
			</div>
		</div>
	<?php
	} elseif ( has_post_thumbnail() ) {
	?>
		<div class="single-post-header-image">
			<div class="<?php echo esc_attr( $container_class ); ?>">
				<div class="single-post-header-image-inner text-center">
					<?php
					nomady_featured_img( array(
						'size' => $thumb_size,
						'link'=> false,
					) );
					?>
				</div>
			</div>
		</div>
	<?php
	}
	?>

	<div class="single-post-header-text">
		<div class="container">
			<div class="single-post-header-text-outer">
				<div class="single-post-header-text-inner">
					<?php nomady_breadcrumb(); ?>

					<?php
					if ( has_category() ) {
					?>
					<div class="post-meta single-post-meta">
						<?php nomady_post_categories(); ?>
					</div>
					<?php
					}
					?>

					<?php
					the_title( '<h1 class="single-post-title post-title entry-title h1 display-5-sm display-4-xl">', '</h1>' );
					?>

					<?php
					if ( has_excerpt() && ( $excerpt_as_lead === 'yes' ) ) {
					?>
						<div class="single-post-excerpt">
							<?php the_excerpt(); ?>
						</div>
					<?php
					}
					?>

					<?php
					if ( !is_page() ) {
					?>
					<div class="single-post-header-footer d-flex align-items-center">
						<div class="single-post-header-footer-left post-meta single-post-meta ">
							<span class="post-author"><?php esc_html_e( 'By', 'nomady' ); ?><span class="post-author-avatar"><?php echo get_avatar( get_the_author_meta( 'ID' ), '32', '', esc_html__( 'avatar', 'nomady' ) ); ?></span><?php the_author_posts_link(); ?></span><!--
							--><span class="meta-separator"></span><!--
							--><time class="published" datetime="<?php echo esc_attr( $post_time_attr ); ?>" title="<?php echo esc_attr( $post_time ); ?>"><?php echo nomady_human_datetime(); ?></time><?php
							$display_modified_date = nomady_get_option( 'single_post_modified_date_toggle', 'no' );
							if ( $display_modified_date === 'yes' ) {
								$post_modified_date_format = get_the_modified_date( get_option( 'date_format' ) );
								$post_modified_time = get_the_modified_time( 'U' );
								$post_modified_time_attr = get_the_modified_time( 'c' );
								$post_published_time = get_the_time( 'U' );
								// Display modified time if enabled or if more than 24 hrs since post created.
								if ( ( $post_modified_time !== $post_published_time ) && ( $post_modified_time > $post_published_time - ( 60 * 60 * 24 ) ) ) {
									?><span class="meta-separator"></span><time class="updated" datetime="<?php echo esc_attr( $post_modified_time_attr ); ?>" title="<?php echo esc_attr( $post_modified_date_format ); ?>"><?php echo nomady_human_modified_datetime(); ?></time>
							<?php
								}
							}
							?>
						</div>

						<div class="single-post-header-footer-right post-meta single-post-meta ">
							<?php
							if ( !post_password_required() && ( comments_open() || get_comments_number() ) ) {
								?><a class="single-post-comment-link has-icon-last" href="<?php echo get_comments_link( get_the_ID() ); ?>"><?php if ( get_comments_number() ) { echo '<span>' . get_comments_number() . '</span>'; } ?><?php echo nomady_svg_icon( [ 'icon' => 'message-square', 'class' => 'mnmd-icon-lg' ] ); ?></a><?php
							}

							if ( function_exists('wpp_get_views') ) {
								$post_views = wpp_get_views( get_the_ID() );
								if ( $post_views > 0 ) {
									?><span class="single-post-views has-icon-last"><span><?php echo esc_html( $post_views ); ?></span><?php echo nomady_svg_icon( [ 'icon' => 'eye', 'class' => 'mnmd-icon-lg' ] ); ?></span><?php
								}
							}
							?>
						</div>
					</div>
					<?php
					}
					?>
				</div>
			</div>
		</div>
	</div>
</header>