<?php
/**
 * Display single post header: Default.
 */

if ( isset( $args ) ) extract( $args ); // extract passed variables.

( isset( $excerpt_as_lead ) ) || $excerpt_as_lead = 'yes';

// Get options.
$single_header_center = nomady_get_meta_box( 'post_header_center' );
if ( !$single_header_center || ( $single_header_center === 'global') ) {
	$single_header_center = nomady_get_option( 'single_post_header_center', 'no' );
}

$single_header_width = nomady_get_meta_box( 'post_header_width' );
if ( !$single_header_width || ( $single_header_width === 'global') ) {
	$single_header_width = nomady_get_option( 'single_post_header_width', 'wide' );
}

// Setting up variables.
$header_class = 'mnmd-section mnmd-section-fullwidth single-post-header single-post-header-no-ft-img single-post-header-center';
$post_time_attr = get_the_time( 'c' );
$post_time = get_the_time( get_option( 'date_format' ) );

switch ( $single_header_width ) {
	case 'wide':
		$container_class = 'container-xl-fullwidth container-xxl-wide';
		break;

	case 'fullwidth':
		$container_class = 'container-xl-fullwidth';
		break;

	case 'fullbleed':
		$container_class = 'container-xl-fullbleed';
		break;

	default:
		$container_class = 'container';
		break;
}
?>
<header class="<?php echo esc_attr( $header_class ); ?>">
	<div class="single-post-header-text">
		<div class="container">
			<div class="single-post-header-text-outer">
				<div class="single-post-header-text-inner">
					<?php nomady_breadcrumb(); ?>

					<?php
					if ( has_category() ) {
					?>
					<div class="post-meta single-post-meta">
						<?php nomady_post_categories(); ?>
					</div>
					<?php
					}
					?>

					<?php
					the_title( '<h1 class="single-post-title post-title entry-title h1 display-5-sm display-4-xl">', '</h1>' );
					?>

					<?php
					if ( has_excerpt() && ( $excerpt_as_lead === 'yes' ) ) {
					?>
						<div class="single-post-excerpt">
							<?php the_excerpt(); ?>
						</div>
					<?php
					}
					?>

					<?php
					if ( !is_page() ) {
					?>
					<div class="single-post-header-footer">
						<div class="single-post-header-footer-left post-meta single-post-meta ">
							<span class="post-author"><?php esc_html_e( 'By', 'nomady' ); ?><span class="post-author-avatar"><?php echo get_avatar( get_the_author_meta( 'ID' ), '32', '', esc_html__( 'avatar', 'nomady' ) ); ?></span><?php the_author_posts_link(); ?></span><!--
							--><span class="meta-separator"></span><!--
							--><time class="published" datetime="<?php echo esc_attr( $post_time_attr ); ?>" title="<?php echo esc_attr( $post_time ); ?>"><?php echo nomady_human_datetime(); ?></time><?php
							$display_modified_date = nomady_get_option( 'single_post_modified_date_toggle', 'no' );
							if ( $display_modified_date === 'yes' ) {
								$post_modified_date_format = get_the_modified_date( get_option( 'date_format' ) );
								$post_modified_time = get_the_modified_time( 'U' );
								$post_modified_time_attr = get_the_modified_time( 'c' );
								$post_published_time = get_the_time( 'U' );
								// Display modified time if enabled or if more than 24 hrs since post created.
								if ( ( $post_modified_time !== $post_published_time ) && ( $post_modified_time > $post_published_time - ( 60 * 60 * 24 ) ) ) {
									?><span class="meta-separator"></span><time class="updated" datetime="<?php echo esc_attr( $post_modified_time_attr ); ?>" title="<?php echo esc_attr( $post_modified_date_format ); ?>"><?php echo nomady_human_modified_datetime(); ?></time>
							<?php
								}
							}
							?>
						</div>

						<div class="single-post-header-footer-right post-meta single-post-meta ">
							<?php
							if ( !post_password_required() && ( comments_open() || get_comments_number() ) ) {
								?><a class="single-post-comment-link has-icon-last" href="<?php echo get_comments_link( get_the_ID() ); ?>"><?php if ( get_comments_number() ) { echo '<span>' . get_comments_number() . '</span>'; } ?><?php echo nomady_svg_icon( [ 'icon' => 'message-square', 'class' => 'mnmd-icon-lg' ] ); ?></a><?php
							}

							if ( function_exists('wpp_get_views') ) {
								$post_views = wpp_get_views( get_the_ID() );
								if ( $post_views > 0 ) {
									?><span class="single-post-views has-icon-last"><span><?php echo esc_html( $post_views ); ?></span><?php echo nomady_svg_icon( [ 'icon' => 'eye', 'class' => 'mnmd-icon-lg' ] ); ?></span><?php
								}
							}
							?>
						</div>
					</div>
					<?php
					}
					?>
				</div>
			</div>
		</div>
	</div>
</header>