<?php
/**
 * Display single post header: Split.
 */

if ( isset( $args ) ) extract( $args ); // extract passed variables.

( isset( $excerpt_as_lead ) ) || $excerpt_as_lead = 'yes';

// Get options.
$single_header_width = nomady_get_meta_box( 'post_header_width' );
if ( !$single_header_width || ( $single_header_width === 'global') ) {
	$single_header_width = nomady_get_option( 'single_post_header_width', 'wide' );
}

$background_toggle = nomady_get_meta_box( 'post_header_background_toggle' );
if ( $background_toggle === 'global' ) {
	$background_toggle = nomady_get_option( 'single_post_header_background_toggle' );
} elseif ( $background_toggle === 'yes' ) {
	$background = array(
		'color' => nomady_get_meta_box( 'post_header_background_color' ),
		'image' => nomady_get_meta_box( 'post_header_background_image' ),
		'repeat' => nomady_get_meta_box( 'post_header_background_repeat' ),
		'position' => nomady_get_meta_box( 'post_header_background_position' ),
		'size' => nomady_get_meta_box( 'post_header_background_size' ),
		'attachment' => nomady_get_meta_box( 'post_header_background_attachment' ),
	);
}

// Setting up variables.
$is_vertical_image = false;
$thumb_size = 'nomady_md';
$post_time_attr = get_the_time( 'c' );
$post_time = get_the_time( get_option( 'date_format' ) );
$post_format = get_post_format();
$post_audio = NULL;
$post_gallery = NULL;
$post_image = NULL;
$post_video = NULL;
$header_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous single-post-header single-post-header-split single-post-header-width-' . $single_header_width;
$title_class = 'single-post-title post-title entry-title h1 display-5-sm h2-lg h1-xl';
$header_text_class = 'single-post-header-text';

switch ( $single_header_width ) {
	case 'wide':
		$container_class = 'container-xl-fullwidth container-xxl-wide';
		$title_class .= ' display-5-xxl';
		break;

	case 'fullwidth':
		$container_class = 'container-xl-fullwidth';
		$title_class .= ' display-5-xxl';
		break;

	case 'fullbleed':
		$container_class = 'container-xl-fullbleed';
		$title_class .= ' display-5-xxl';
		break;

	default:
		$container_class = 'container-xl';
		if ( !isset( $background ) || ( $background_toggle !== 'yes' ) ) {
			$header_text_class .= ' pl-xl-0';
		}
		break;
}

switch ( $post_format ) {
	case 'audio':
		$post_audio = nomady_get_meta_box( 'post_format_audio_url' );
		if ( $post_audio ) {
			$post_audio_is_embed = true;
			$header_class .= ' mnmd-section-first-contiguous';
		} else {
			$post_audio_is_embed = false;
			$post_audio = nomady_get_meta_box( 'post_format_audio_file' );
		}

		if ( has_post_thumbnail() ) {
			if ( nomady_img_orientation_check() === 'vertical' ) {
				$is_vertical_image = true;
			}
		}
		break;

	case 'image':
		$post_image = nomady_get_meta_box( 'post_format_image_file' );
		if ( $post_image ) {
			if ( nomady_img_orientation_check( $post_image['ID'] ) === 'vertical' ) {
				$is_vertical_image = true;
			}
		}
		break;

	case 'video':
		$post_video = nomady_get_meta_box( 'post_format_video_url' );
		break;

	default:
		if ( nomady_img_orientation_check() === 'vertical' ) {
			$is_vertical_image = true;
		} else {
			if ( $single_header_width === 'default' ) {
				$thumb_size = 'nomady_md_1_1';
			} elseif ( $single_header_width === 'wide' ) {
				$thumb_size = 'nomady_md_4_3';
			} else {
				$thumb_size = 'nomady_lg_4_3';
			}

			// Check if image is taller than 800px, if yes then we can stretch it.
			$thumb_data = wp_get_attachment_image_src( get_post_thumbnail_id(), $thumb_size );
			if ( $thumb_data[2] >= 800 ) {
				$header_class .= ' single-post-header-split-image-fit';
			}
		}
		break;
}

if ( $background_toggle === 'yes' ) {
	$header_class .= ' single-post-header-has-background mnmd-section-first-contiguous';
}
?>
<header class="<?php echo esc_attr( $header_class ); ?>">
	<div class="single-post-header-wrapper">
		<?php
		if ( $background_toggle === 'yes' ) {
		?>
		<div class="mnmd-section-background background-object"<?php if ( isset( $background ) && ( $background_toggle === 'yes' ) ) { echo ' style="' . esc_attr( nomady_background_style_convert( $background ) ) . '"'; } ?>></div>
		<?php
		}
		?>

		<div class="<?php echo esc_attr( $container_class ); ?>">
			<div class="single-post-header-inner">
				<div class="row d-block d-lg-flex">
					<div class="col-lg-6 order-lg-1 d-flex justify-content-lg-end<?php if ( ( $single_header_width === 'default' ) || $is_vertical_image ) { echo ' col-xl-6'; } else { echo ' col-xl-7'; } ?>">
						<?php
						if ( $post_audio ) {
						?>
							<div class="single-post-header-media d-lg-flex flex-column justify-content-center">
								<?php
								if ( $post_audio_is_embed ) {
									echo '<div class="mnmd-post-media mnmd-post-media-audio mnmd-responsive-embed">' . $post_audio . '</div>';
								} else {
									$post_audio_url = '';
									$post_audio_title = '';
									if ( array_key_exists( 'url', $post_audio ) ) {
										$post_audio_url = $post_audio['url'];
									}
									if ( array_key_exists( 'title', $post_audio ) ) {
										$post_audio_title = $post_audio['title'];
									}
								?>
									<?php
									if ( has_post_thumbnail() ) {
									?>
										<div class="single-post-header-image">
											<div class="single-post-header-image-inner text-center">
												<?php
												nomady_featured_img( array(
													'size' => $thumb_size,
													'link'=> false,
												) );
												?>
											</div>
										</div>
									<?php
									}
									?>

									<div class="mnmd-post-media mnmd-post-media-audio">
										<div class="container">
											<audio controls>
												<source src="<?php echo esc_url( $post_audio_url ); ?>">
											</audio>
										</div>
									</div>
								<?php
								}
								?>
							</div>
						<?php
						} elseif ( $post_image ) {
						?>
							<div class="single-post-header-media">
								<div class="mnmd-post-media mnmd-post-media-image js-mnmd-lightbox-gallery" itemscope itemtype="http://schema.org/ImageGallery">
							        <?php
						        	echo '<figure class="mnmd-post-media-image-img" itemprop="associatedMedia" itemscope itemtype="http://schema.org/ImageObject">';
						        		echo '<a href="' . esc_url( $post_image['url'] ) . '" itemprop="contentUrl" data-size="' . esc_attr( $post_image['width'] ) . 'x' . esc_attr( $post_image['height'] ) . '">';
							        			echo wp_get_attachment_image(  $post_image['ID'], 'nomady_xl', false, array( 'itemprop' => 'thumbnail') );
										echo '</a>';

										if ( $post_image[ 'caption' ] !== '' ) {
											echo '<figcaption itemprop="caption description" class="mnmd-post-media-image-caption">' . $post_image[ 'caption' ] . '</figcaption>';
										}
									echo '</figure>';
							    	?>
								</div>
							</div>
						<?php
						} elseif ( $post_video ) {
						?>
							<div class="single-post-header-media d-flex align-items-center">
								<div class="mnmd-post-media mnmd-post-media-video mnmd-responsive-embed">
									<?php echo '<div class="mnmd-responsive-video">' . $post_video . '</div>'; ?>
								</div>
							</div>
						<?php
						} elseif ( has_post_thumbnail() ) {
							nomady_featured_img( array(
								'size' => $thumb_size,
								'class' => 'single-post-header-image',
								'link'=> false,
							) );
						}
						?>
					</div>

					<div class="col-lg d-flex align-items-center">
						<div class="<?php echo esc_attr( $header_text_class ); ?>">
							<div class="container px-lg-0">
								<div class="single-post-header-text-inner">
									<?php nomady_breadcrumb(); ?>

									<div class="post-meta single-post-meta">
										<?php nomady_post_categories(); ?>
									</div>

									<?php
									the_title( '<h1 class="'. esc_attr( $title_class ) .'">', '</h1>' );
									?>

									<?php
									if ( has_excerpt() && ( $excerpt_as_lead === 'yes' ) ) {
										if ( $single_header_width === 'default' ) {
											echo '<div class="single-post-excerpt font-default d-lg-none d-xl-block">';
										} else {
											echo '<div class="single-post-excerpt font-default d-lg-none d-xl-block">';
										}
												the_excerpt();
											echo '</div>';
									}
									?>

									<?php
									if ( !is_page() ) {
									?>
									<div class="single-post-header-footer d-flex align-items-center">
										<div class="single-post-header-footer-left post-meta single-post-meta ">
											<span class="post-author"><?php esc_html_e( 'By', 'nomady' ); ?><span class="post-author-avatar"><?php echo get_avatar( get_the_author_meta( 'ID' ), '32', '', esc_html__( 'avatar', 'nomady' ) ); ?></span><?php the_author_posts_link(); ?></span><!--
											--><span class="meta-separator"></span><!--
											--><time class="published" datetime="<?php echo esc_attr( $post_time_attr ); ?>" title="<?php echo esc_attr( $post_time ); ?>"><?php echo nomady_human_datetime(); ?></time><?php
											$display_modified_date = nomady_get_option( 'single_post_modified_date_toggle', 'no' );
											if ( $display_modified_date === 'yes' ) {
												$post_modified_date_format = get_the_modified_date( get_option( 'date_format' ) );
												$post_modified_time = get_the_modified_time( 'U' );
												$post_modified_time_attr = get_the_modified_time( 'c' );
												$post_published_time = get_the_time( 'U' );
												// Display modified time if enabled or if more than 24 hrs since post created.
												if ( ( $post_modified_time !== $post_published_time ) && ( $post_modified_time > $post_published_time - ( 60 * 60 * 24 ) ) ) {
													?><span class="meta-separator"></span><time class="updated" datetime="<?php echo esc_attr( $post_modified_time_attr ); ?>" title="<?php echo esc_attr( $post_modified_date_format ); ?>"><?php echo nomady_human_modified_datetime(); ?></time>
											<?php
												}
											}
											?>
										</div>

										<div class="single-post-header-footer-right post-meta single-post-meta ">
											<?php
											if ( !post_password_required() && ( comments_open() || get_comments_number() ) ) {
												?><a class="single-post-comment-link has-icon-last" href="<?php echo get_comments_link( get_the_ID() ); ?>"><?php if ( get_comments_number() ) { echo '<span>' . get_comments_number() . '</span>'; } ?><?php echo nomady_svg_icon( [ 'icon' => 'message-square', 'class' => 'mnmd-icon-lg' ] ); ?></a><?php
											}

											if ( function_exists('wpp_get_views') ) {
												$post_views = wpp_get_views( get_the_ID() );
												if ( $post_views > 0 ) {
													?><span class="single-post-views has-icon-last"><span><?php echo esc_html( $post_views ); ?></span><?php echo nomady_svg_icon( [ 'icon' => 'eye', 'class' => 'mnmd-icon-lg' ] ); ?></span><?php
												}
											}
											?>
										</div>
									</div>
									<?php
									}
									?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</header>
