<?php
/**
 * Displays about section
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'image' => array(),
    'image_style' => 'none',
    'image_caption' => '',
    'image_position' => 'left',
    'social_list' => NULL,
    'link_list' => NULL,
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-about-a';
$section_class .= ' mnmd-section-about-image-style-' . $settings['image_style'];
$section_class .= ' mnmd-section-about-image-position-' . $settings['image_position'];
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<div class="mnmd-section-wrapper">
		<div class="container">
			<div class="mnmd-section-inner row row-space-around align-items-xl-center">
				<?php
				if ( array_key_exists( 'id', $settings['image'] ) && $settings['image']['id'] ) {
					$image_attachment = wp_get_attachment_image_src( $settings['image']['id'], 'nomady_sm_1_1' );
				?>
					<div class="mnmd-about-image col-lg-12 col-xl<?php if ( $settings['image_position'] === 'center' ) { echo ' order-xl-1'; } ?>">
						<div class="mnmd-about-image-outer">
							<div class="mnmd-about-image-inner">
								<?php
								if ( $settings['image_style'] === 'pattern' ) {
									echo '<div class="mnmd-pattern-object pattern-dots-md"></div>';
								}
								echo '<div class="mnmd-about-image-wrapper">';
									echo '<img class="img-fluid" src="' . esc_url( $settings['image']['url'] ) . '" alt="figure">';
								echo '</div>';
								if ( ( $settings['image_style'] === 'polaroid' ) && ( $settings['image'] ) ) {
									echo '<div class="mnmd-about-image-caption d-flex flex-column justify-content-center text-center text-h4 text-h5-lg text-h4-xl">';
									if ( $settings['image_caption'] ) {
										echo '<p>';
										echo esc_html( $settings['image_caption'] );
										echo '</p>';
									}
									echo '</div>';
								}
								?>
							</div>
						</div>
					</div>
				<?php
				}
				?>

				<div class="mnmd-about-content-text col-lg">
					<?php
					if ( $settings['heading'] ) {
						echo '<div class="mnmd-about-heading">';
						echo '<h2 class="h1">';
						echo '<span class="mnmd-about-heading-text">' . wp_kses_post( $settings['heading'] ) . '</span>';
						echo '</h2>';
						echo '</div>';
					}

					if ( $settings['body'] ) {
						echo '<div class="mnmd-about-body-text">' . wp_kses_post( $settings['body'] ) . '</div>';
					}
					?>
				</div>

				<?php
				if ( ( $settings['social_list'] ) || ( $settings['links_list'] ) ) {
				?>
				<div class="mnmd-about-content-info col-lg order-2">
					<div class="row row-space-around">
						<?php
						if ( $settings['social_list'] ) {
						?>
							<div class="mnmd-about-content-social col-sm-6 col-lg-12">
								<?php
								if ( $settings['social_heading'] ) {
									echo '<h6 class="h7 text-uppercase font-meta">' . wp_kses_post( $settings['social_heading'] ) . '</h6>';
								}
								?>
								<div class="mnmd-about-content-social-list">
									<?php
									nomady_get_template_part( 'template-parts/misc/social-inline', NULL, array( 'social_list' => $settings['social_list'] ) );
									?>
								</div>
							</div>
						<?php
						}
						?>

						<?php
						if ( $settings['links_list'] ) {
						?>
							<div class="mnmd-about-content-links col-sm-6 col-lg-12">
								<?php
								if ( $settings['links_heading'] ) {
									echo '<h6 class="h7 text-uppercase font-meta">' . wp_kses_post( $settings['links_heading'] ) . '</h6>';
								}

								$output = '';
								$output .= '<ul>';
								foreach ( $settings['links_list'] as $link_item ) {
									$output .= '<li>';
										if ( $link_item['link_url']['url'] ) {
											$output .= '<a class="st-link" href="'. esc_url( $link_item['link_url']['url'] ) . '"';
											if ( $link_item['link_url']['is_external'] ) {
												if ( $link_item['link_url']['nofollow'] ) {
													$output .= ' target="_blank" rel="noopener nofollow"';
												} else {
													$output .= ' target="_blank" rel="noopener"';
												}
											}
											$output .= '>';
										}

										$output .= '<span>' . wp_kses_post( $link_item['link_title'] ) . '</span>';

										if ( $link_item['link_url']['url'] ) {
											$output .= '</a>';
										}
									$output .= '</li>';
								}
								$output .= '</ul>';
								echo mnmd_wp_kses_post( $output );
								?>
							</div>
						<?php
						}
						?>
					</div>
				</div>
				<?php
				}
				?>
			</div>
		</div>
	</div>
</section>