<?php
/**
 * Displays categories.
 */

if ( ! isset( $args ) ) return; // there's no variables passed.

$settings = $args['settings'];

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth categories-section categories-section-' . $settings['columns'] . '-col categories-section-layout-' . $settings['layout'];
$thumb_size = 'nomady_sm_1_1';

switch ( $settings['layout'] ) {
	case '1':
	default:
		$category_template = 'category-item-a';
		$row_class = 'row row-space-around flex-wrap';
		if ( ( $settings['columns'] === '4' ) || ( $settings['tall_item'] !== 'yes' ) ) {
			$thumb_size = 'nomady_xs_1_1';
		}
		break;

	case '2':
		$category_template = 'category-item-b';
		$row_class = 'row row-space-around flex-wrap';
		break;

	case '3':
		$category_template = 'category-item-c';
		$row_class = 'row row-space-around flex-wrap';
		$thumb_size = 'nomady_xxs_1_1';
		break;
}

switch ( $settings['columns'] ) {
	case '4':
	default:
		$col_class = 'col-sm-6 col-lg-3';
		break;

	case '3':
		$col_class = 'col-sm-6 col-lg-4';
		break;
}

if ( $settings['select_by'] === 'name' ) {
	$category_ids = $settings['category_ids_name'];
} elseif ( $settings['category_ids'] ) {
	$category_ids = explode( ',', $settings['category_ids'] );
} else {
	$category_ids = NULL;
}

if ( $category_ids ) {
	if ( ( $settings['select_by'] === 'id' ) && ( $settings['orderby'] === 'include' ) ) {
		$query_args = array(
			'taxonomy'				=> 'category',
			'include'   			=> $category_ids,
			'orderby'   			=> $settings['orderby'],
			'order'   				=> 'asc',
		);
	} else {
		$query_args = array(
			'taxonomy'				=> 'category',
			'include'   			=> $category_ids,
			'orderby'   			=> $settings['orderby'],
			'order'   				=> $settings['order'],
		);
	}
} elseif ( $settings['number'] ) {
	$query_args = array(
		'taxonomy'				=> 'category',
		'number'   				=> $settings['number'],
		'orderby'   			=> $settings['orderby'],
		'order'   				=> $settings['order'],
	);
} else {
	$query_args = NULL;
}

if ( $query_args ) {
	$categories = get_categories( $query_args );
}
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<div class="container">
		<div class="mnmd-section-inner">
			<?php
            if ( $settings['heading'] ) {
            ?>
                <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                    <div class="mnmd-section-heading-primary">
                        <h4 class="mnmd-section-heading-title h3 meta-font">
                            <?php
                            echo wp_kses_post( $settings['heading'] );
                            ?>
                        </h4>

                        <?php
                        if ( $settings['subheading'] ) {
                            echo '<div class="mnmd-section-heading-subtitle">';
                            echo wp_kses_post( $settings['subheading'] );
                            echo '</div>';
                        }
                        ?>
                    </div>

                    <div class="mnmd-section-heading-secondary mt-2 mt-sm-0">
                        <?php
                        if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                        ?>
                            <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php
                                if( $settings['heading_url']['is_external'] ) {
                                    if( $settings['heading_url']['nofollow'] ) {
                                        echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                    } else {
                                        echo ' target="_blank" rel="noopener noreferrer"';
                                    }
                                } ?>>
                                <?php
                                echo '<span class="align-middle">';
                                echo wp_kses_post( $settings['heading_url_text'] );
                                echo '</span>';
                                echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                ?>
                            </a>
                        <?php
                        }
                        ?>
                    </div>
                </div><!-- .mnmd-section-heading -->
            <?php
            }
            ?>

            <?php
            if ( $query_args ) {
            	if ( $settings['layout'] === '1' ) {
            ?>
		    		<div class="mnmd-items-wrapper">
						<div class="<?php echo esc_attr( $row_class ); ?>">
							<?php
							foreach ( $categories as $category ) {
							?>

								<div class="<?php echo esc_attr( $col_class ); ?>">
									<?php
									nomady_get_template_part( 'template-parts/misc/' . $category_template, NULL,
										array(
											'category' => $category,
											'show_post_count' => $settings['show_post_count'],
											'category_tall' => $settings['tall_item'],
										)
									);
									?>
								</div>
							<?php
							}
							?>
						</div>
					</div>
				<?php
				} else {
				?>
					<ul class="categories-section-list<?php if ( $settings['align_center'] === 'yes' ) { echo ' text-center'; } ?>">
					<?php
					foreach ( $categories as $category ) {
					?>
						<li class="categories-section-list-item">
							<?php
							nomady_get_template_part( 'template-parts/misc/' . $category_template, NULL,
								array(
									'category' => $category,
									'show_post_count' => $settings['show_post_count'],
								)
							);
							?>
						</li>
					<?php
					}
					?>
					</ul>
			<?php
				}
			}
			?>
		</div>
	</div>
</section>