<?php
/**
 * Displays about section
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];
$section_id = $args['section_id'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'heading_center' => 'no',
	'heading_style' => 'default',
	'wide_layout' => 'no',
	'image' => [],
    'widget_background_background' => '',
    'background_video_url' => [],
    'widget_background_overlay_background' => '',
) );

// Setting up variables.
$has_background = false;
$section_class = 'mnmd-section cat-section cat-section-split-background mnmd-section-fullwidth';
$section_class .= ' cat-section-heading-' . $settings['heading_style'];

if ( ( $settings['widget_background_background'] ) || ( array_key_exists( 'url', $settings['background_video_url'] ) && $settings['background_video_url']['url'] ) ) {
	$section_class .= ' mnmd-section-has-background mnmd-section-first-contiguous';
	$has_background = true;
}

if ( $settings['wide_layout'] === 'yes' ) {
	$container_class = 'container-wide';
} else {
	$container_class = 'container';
}
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<?php
	if ( $has_background ) {
		echo '<div class="mnmd-section-background background-object d-none d-lg-block">';

		if ( array_key_exists( 'url', $settings['background_video_url'] ) && $settings['background_video_url']['url'] ) {
			echo '<video class="mnmd-background-video" playsinline="playsinline" autoplay="autoplay" muted="muted" loop="loop">';
			echo '<source src="' . esc_url( $settings['background_video_url']['url'] ) . '">';
			echo '</video>';
		}

		if ( $settings['widget_background_overlay_background'] ) {
			echo '<div class="background-overlay"></div>';
		}

		echo '</div>'; // .mnmd-section-background
	}
	?>

	<div class="mnmd-section-wrapper">
		<div class="<?php echo esc_attr( $container_class ); ?>">
			<div class="mnmd-section-inner">
				<div class="row row-space-around">
					<div class="col-lg-6 order-lg-1">
						<div class="cat-section-image d-flex align-items-center">
							<?php
							if ( array_key_exists( 'url', $settings['image'] ) && $settings['image']['url'] ) {
								if ( $has_background ) {
									echo '<img class="img-fluid" src="' . esc_url( $settings['image']['url'] ) . '" alt="figure">';
								} else {
									echo '<img class="img-fluid ml-lg-auto" src="' . esc_url( $settings['image']['url'] ) . '" alt="figure">';
								}
							}
							?>
						</div>
					</div>

					<div class="col-lg-6 d-flex align-items-center">
						<div class="cat-section-text ml-auto mr-auto mr-lg-4<?php if ( $settings['heading_center'] === 'yes' ) echo ' text-center'; ?>">
							<?php
							if ( $settings['heading'] ) {
								echo '<div class="cat-section-heading">';
								echo '<h2 class="display-5 h1-lg display-5-xl">';
								echo '<span class="cat-section-heading-text">' . wp_kses_post( $settings['heading'] ) . '</span>';
								echo '</h2>';
								echo '</div>';
							}

							if ( $settings['body'] ) {
								echo '<div class="cat-section-body-text">' . wp_kses_post( $settings['body'] ) . '</div>';
							}

							if ( $settings['primary_btn_text'] || $settings['secondary_btn_text'] ) {
								$btn_extra_attr = '';
								echo '<div class="cat-section-btns">';

								if ( $settings['primary_btn_text'] ) {
									$btn_class = 'btn st-btn-primary';

									if ( $settings['primary_btn_url']['is_external'] ) {
										if ( $settings['primary_btn_url']['nofollow'] ) {
											$btn_extra_attr = ' target="_blank" rel="noopener noreferrer nofollow"';
										} else {
											$btn_extra_attr = ' target="_blank" rel="noopener noreferrer"';
										}
									}

									echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['primary_btn_url']['url'] ) . '"' . $btn_extra_attr . '><span>' . esc_html( $settings['primary_btn_text'] ) . '</span></a>';
								}

								if ( $settings['secondary_btn_text'] ) {
									$btn_class = 'btn st-btn-secondary';

									if ( $settings['secondary_btn_url']['is_external'] ) {
										if ( $settings['secondary_btn_url']['nofollow'] ) {
											$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer nofollow"';
										} else {
											$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer"';
										}
									}

									echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['secondary_btn_url']['url'] ) . '"' . $btn_extra_attr . '><span>' . esc_html( $settings['secondary_btn_text'] ) . '</span></a>';
								}

								echo '</div>';
							}
							?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</section>