<?php
/**
 * Displays about section
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];
$section_id = $args['section_id'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'heading_center' => 'no',
	'heading_style' => 'default',
	'wide_layout' => 'no',
	'stretch_img' => 'yes',
	'gallery' => [],
) );

// Setting up variables.
$section_class = 'mnmd-section cat-section cat-section-gallery-vertical mnmd-section-fullwidth';
$section_class .= ' cat-section-heading-' . $settings['heading_style'];

if ( $settings['stretch_right'] === 'yes' ) {
	$section_class .= ' cat-section-stretch-right';
}

if ( $settings['widget_background_background'] ) {
	$section_class .= ' mnmd-section-has-background mnmd-section-first-contiguous';
}

if ( $settings['wide_layout'] === 'yes' ) {
	$section_class .= ' cat-section-wide';
	$container_class = 'container-wide';
} else {
	$container_class = 'container';
}
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<?php
	if ( $settings['widget_background_background'] ) {
		echo '<div class="mnmd-section-background background-object d-none d-lg-block">';

		if ( $settings['widget_background_overlay_background'] ) {
			echo '<div class="background-overlay"></div>';
		}

		echo '</div>'; // .mnmd-section-background
	}
	?>

	<div class="mnmd-section-wrapper">
		<div class="<?php echo esc_attr( $container_class ); ?>">
			<div class="mnmd-section-inner">
				<div class="cat-section-content">
					<div class="row row-space-around">
						<div class="cat-section-gallery-col col-lg-6 order-lg-1 d-flex flex-column">
							<div class="cat-section-gallery-outer">
								<div class="cat-section-gallery-inner">
									<?php
									if ( $settings['gallery'] ) {
										?>
										<div class="cat-section-gallery-col-item js-scrolling-gallery-vertical" data-speed="25">
											<ul class="cat-section-gallery-wrapper cat-section-gallery-first">
										    	<?php
										    	$i = 0;
										    	foreach( $settings['gallery'] as $gallery_item ) {
										    		$i++;
										    		if ( $i % 2 ) {
										    	?>
											            <li>
											            	<?php echo wp_get_attachment_image( $gallery_item['id'], 'full' ); ?>
											            </li>
										    	<?php
										    		}
										    	}
										    	?>
										    </ul>
										</div>

										<div class="cat-section-gallery-col-item js-scrolling-gallery-vertical" data-speed="30">
											<ul class="cat-section-gallery-wrapper cat-section-gallery-second">
										    	<?php
										    	$i = 0;
										    	foreach( $settings['gallery'] as $gallery_item ) {
										    		$i++;
										    		if ( !( $i % 2 ) ) {
										    	?>
											            <li>
											            	<?php echo wp_get_attachment_image( $gallery_item['id'], 'full' ); ?>
											            </li>
										    	<?php
										    		}
										    	}
										    	?>
										    </ul>
										</div>
									<?php
									}
									?>
								</div>
							</div>
						</div>

						<div class="col-lg-6 d-flex align-items-center">
							<div class="cat-section-text ml-auto mr-auto mr-lg-4<?php if ( $settings['heading_center'] === 'yes' ) echo esc_attr( ' text-center' ); ?>">
								<?php
								if ( $settings['heading'] ) {
									echo '<div class="cat-section-heading">';
									echo '<h2 class="display-5 h1-lg display-5-xl">';
									echo '<span class="cat-section-heading-text">' . wp_kses_post( $settings['heading'] ) . '</span>';
									echo '</h2>';
									echo '</div>';
								}

								if ( $settings['body'] ) {
									echo '<div class="cat-section-body-text">' . wp_kses_post( $settings['body'] ) . '</div>';
								}

								if ( $settings['primary_btn_text'] || $settings['secondary_btn_text'] ) {
									$btn_extra_attr = '';
									echo '<div class="cat-section-btns">';

									if ( $settings['primary_btn_text'] ) {
										$btn_class = 'btn st-btn-primary';

										if ( $settings['primary_btn_url']['is_external'] ) {
											if ( $settings['primary_btn_url']['nofollow'] ) {
												$btn_extra_attr = ' target="_blank" rel="noopener noreferrer nofollow"';
											} else {
												$btn_extra_attr = ' target="_blank" rel="noopener noreferrer"';
											}
										}

										echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['primary_btn_url']['url'] ) . '"' . $btn_extra_attr . '>' . esc_html( $settings['primary_btn_text'] ) . '</a>';
									}

									if ( $settings['secondary_btn_text'] ) {
										$btn_class = 'btn st-btn-secondary';

										if ( $settings['secondary_btn_url']['is_external'] ) {
											if ( $settings['secondary_btn_url']['nofollow'] ) {
												$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer nofollow"';
											} else {
												$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer"';
											}
										}

										echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['secondary_btn_url']['url'] ) . '"' . $btn_extra_attr . '>' . esc_html( $settings['secondary_btn_text'] ) . '</a>';
									}

									echo '</div>';
								}
								?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</section>