<?php
/**
 * Displays about section
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];
$section_id = $args['section_id'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'heading_center' => 'no',
	'heading_style' => 'default',
	'wide_layout' => 'no',
	'stretch_img' => 'yes',
	'image' => [],
	'image_secondary' => [],
    'widget_background_background' => '',
    'background_video_url' => [],
    'widget_background_overlay_background' => '',
) );

// Setting up variables.
$section_class = 'mnmd-section cat-section cat-section-split mnmd-section-fullwidth';
$section_class .= ' cat-section-heading-' . $settings['heading_style'];

if ( array_key_exists( 'id', $settings['image'] ) && $settings['image_secondary']['id'] ) {
	$section_class .= ' cat-section-has-secondary-image';
}

if ( $settings['stretch_right'] === 'yes' ) {
	$section_class .= ' cat-section-stretch-right';
}
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<div class="mnmd-section-wrapper">
		<div class="container<?php if ( $settings['wide_layout'] === 'yes' ) echo ' container-lg-wide'; ?>">
			<div class="mnmd-section-inner">
				<div class="row row-space-around align-items-center">
					<div class="col-lg-6 order-lg-1">
						<div class="cat-section-images">
							<?php
							if ( array_key_exists( 'id', $settings['image'] ) && $settings['image']['id'] ) {
								echo '<div class="cat-section-image-primary">';
									echo '<img class="img-fluid" src="' . esc_url( $settings['image']['url'] ) . '" alt="figure">';
								echo '</div>';
							}
							?>

							<?php
							if ( array_key_exists( 'id', $settings['image'] ) && $settings['image_secondary']['id'] ) {
								echo '<div class="cat-section-image-secondary d-flex align-items-end">';
									echo '<img class="" src="' . esc_url( $settings['image_secondary']['url'] ) . '" alt="figure">';
								echo '</div>';
							}
							?>
						</div>
					</div>

					<div class="col-lg-6">
						<div class="cat-section-text mr-lg-4 mr-xl-5<?php if ( $settings['heading_center'] === 'yes' ) echo ' text-center'; ?>">
							<?php
							if ( $settings['heading'] ) {
								echo '<div class="cat-section-heading">';
								echo '<h2 class="display-5 h1-lg display-5-xl">';
								echo '<span class="cat-section-heading-text">' . wp_kses_post( $settings['heading'] ) . '</span>';
								echo '</h2>';
								echo '</div>';
							}

							if ( $settings['body'] ) {
								echo '<div class="cat-section-body-text">' . wp_kses_post( $settings['body'] ) . '</div>';
							}

							if ( $settings['primary_btn_text'] || $settings['secondary_btn_text'] ) {
								$btn_extra_attr = '';
								echo '<div class="cat-section-btns">';

								if ( $settings['primary_btn_text'] ) {
									$btn_class = 'btn st-btn-primary';

									if ( $settings['primary_btn_url']['is_external'] ) {
										if ( $settings['primary_btn_url']['nofollow'] ) {
											$btn_extra_attr = ' target="_blank" rel="noopener noreferrer nofollow"';
										} else {
											$btn_extra_attr = ' target="_blank" rel="noopener noreferrer"';
										}
									}

									echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['primary_btn_url']['url'] ) . '"' . $btn_extra_attr . '>' . esc_html( $settings['primary_btn_text'] ) . '</a>';
								}

								if ( $settings['secondary_btn_text'] ) {
									$btn_class = 'btn st-btn-secondary';

									if ( $settings['secondary_btn_url']['is_external'] ) {
										if ( $settings['secondary_btn_url']['nofollow'] ) {
											$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer nofollow"';
										} else {
											$btn_extra_attr .= ' target="_blank" rel="noopener noreferrer"';
										}
									}

									echo '<a class="' . esc_attr( $btn_class ) . '" href="' . esc_url( $settings['secondary_btn_url']['url'] ) . '"' . $btn_extra_attr . '>' . esc_html( $settings['secondary_btn_text'] ) . '</a>';
								}

								echo '</div>';
							}
							?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</section>