<?php
/**
 * Displays Hero Post Block A.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

$post_meta_author = nomady_get_option( 'meta_author_toggle', 'yes' );
$post_meta_date = nomady_get_option( 'meta_date_toggle', 'yes' );

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'excerpt_length' => 40,
	'post_meta_author' => 'yes',
	'post_meta_date' => 'yes',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous mnmd-hero-post-block-a';

if ( $settings['widget_background_background'] ) {
	$section_class .= ' mnmd-hero-post-block-a-secondary-posts-has-background';
}

if ( $settings['color_scheme'] === 'dark' ) {
	$section_class .= ' mnmd-section-dark-scheme';
}

$query_args[ 'posts_per_page' ] = 4;
$feat_query = new WP_Query( $query_args );

if ( $feat_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<div class="mnmd-section-wrapper">
		<?php
		while ( $feat_query->have_posts() ) {
			$feat_query->the_post();
			if ( $feat_query->current_post === 0 ) {
			?>
				<div class="mnmd-hero-post-block-a-primary-post-wrapper">
					<div class="container-wide">
						<?php
						$post_class = array(
							'mnmd-hero-post-block-a-primary',
							'post-item',
							'post-landscape',
							'post-landscape-reverse',
							'media',
							'flex-column',
							'flex-md-row',
							'align-items-stretch',
						);
						$post_link = get_permalink();
						?>
						<article <?php post_class( $post_class ); ?>>
							<div class="post-image mb-4 mb-md-0 order-md-1">
								<?php
								nomady_featured_img( array(
									'size' => 'nomady_lg_16_9',
									'barebone' => true,
								) );
								?>
								<a class="post-image-url" href="<?php echo esc_url( $post_link ); ?>"></a>
							</div>

							<div class="media-body post-text d-md-flex flex-column justify-content-center">
								<div class="container container-md-fullbleed">
									<div class="post-text-inner">
										<div class="post-meta">
											<?php nomady_post_category(); ?>
										</div>

										<h3 class="h2 h1-xl display-5-xxl post-title entry-title'">
											<a href="<?php echo esc_url( $post_link ); ?>" rel="bookmark"><?php the_title(); ?></a>
										</h3>

										<?php
										if( get_the_excerpt() && ( $settings['excerpt_length'] > 0 ) ) {
										?>
											<div class="post-excerpt post-excerpt-lg">
												<?php nomady_excerpt( $settings['excerpt_length'], true ); ?>
											</div>
										<?php
										}
										?>

										<a class="post-read-more st-link" href="<?php echo esc_url( $post_link ); ?>"><span><?php esc_html_e( 'Read more', 'nomady' ); ?></span></a>
									</div>
								</div>
							</div>
						</article>
					</div>
				</div>
			<?php
			} elseif ( $feat_query->current_post < 4 ) {
				if ( $feat_query->current_post === 1 ) {
				?>
					<div class="mnmd-hero-post-block-a-secondary">
						<div class="container">
							<div class="mnmd-hero-post-block-a-secondary-inner">
								<div class="row">
				<?php
				}
				?>
									<div class="col-lg">
										<?php
										$post_class = array(
											'post-item',
											'post-landscape',
											'post-landscape-reverse',
											'media',
										);
										?>
										<article <?php post_class( $post_class ); ?>>
											<div class="media-body post-text mnmd-scheme-applicable">
												<div class="post-meta">
													<?php nomady_post_category(); ?>
												</div>

												<h3 class="h5 h7-lg h6l-xl post-title entry-title">
													<a href="<?php echo esc_url( get_permalink() ); ?>" rel="bookmark"><?php the_title(); ?></a>
												</h3>
											</div>

											<?php
											nomady_featured_img( array(
												'size' => 'nomady_sm_1_1',
												'class' => 'post-image',
											) );
											?>
										</article>
									</div>
				<?php
				if ( ( $feat_query->current_post === 3 ) || ( $feat_query->current_post === ( $feat_query->post_count - 1 ) ) ) {
				?>
								</div>
							</div>
						</div>
					</div>
				<?php
				}
			} else {
				break;
			}
		}

		// Reset postdata
		wp_reset_postdata();
		?>
		</div>
	</section>
<?php
}