<?php
/**
 * Displays Hero Post Block C.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'excerpt_length' => 24,
	'post_meta_author' => 'yes',
	'post_meta_date' => 'yes',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous post-box-c-section';

if ( $settings['color_scheme'] === 'dark' ) {
	$section_class .= ' mnmd-section-dark-scheme';
}

$query_args[ 'posts_per_page' ] = 3;
$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<div class="mnmd-section-wrapper">
			<div class="container-wide">
				<div class="mnmd-section-inner">
					<?php
					while ( $post_query->have_posts() ) {
						$post_query->the_post();
						if ( $post_query->current_post === 0 ) {
						?>
							<div class="post-box-c-primary-wrapper">
								<?php
								if ( $settings['widget_background_background'] ) {
									echo '<div class="mnmd-section-background background-object stretched-viewport"></div>';
								}

								$post_class = array(
									'post-box-c-primary',
									'post-item',
									'd-lg-flex',
									'mnmd-scheme-appliable'
								);

								$post_link = get_permalink();
								$post_time = get_the_time( get_option( 'date_format' ) );
								$post_time_attr = get_the_time( 'c' );

								if ( $settings['color_scheme'] === 'dark' ) {
									$btn_class = 'btn btn-xs st-btn-link-white d-none d-sm-inline-block';
								} else {
									$btn_class = 'btn btn-xs st-btn-link d-none d-sm-inline-block';
								}
								?>
								<article <?php post_class( $post_class ); ?>>
									<div class="post-image mb-4 mb-lg-0 order-lg-1">
										<?php
										nomady_featured_img( array(
											'size' => 'nomady_lg_16_9',
											'barebone' => true,
										) );
										?>
										<a class="post-image-url" href="<?php echo esc_url( $post_link ); ?>"></a>
									</div>

									<div class="post-text d-lg-flex align-items-center text-center<?php if ( $settings['color_scheme'] === 'dark' ) { echo ' text-inverse'; } ?>">
										<div class="post-text-inner">
											<div class="post-meta">
												<?php nomady_post_categories(); ?>
											</div>

											<h3 class="h1 h3-lg h2-xl h1-xxl post-title entry-title">
												<a href="<?php echo esc_url( $post_link ); ?>" rel="bookmark"><?php the_title(); ?></a>
											</h3>

											<?php
											if ( get_the_excerpt() && ( $settings['excerpt_length'] > 0 ) ) {
											?>
												<div class="post-excerpt post-excerpt-lg">
													<?php nomady_excerpt( $settings['excerpt_length'], true ); ?>
												</div>

												<a class="post-read-more st-link d-none d-sm-inline-block" href="<?php echo esc_url( $post_link ); ?>"><?php esc_html_e( 'Read more', 'nomady' ); ?></a>
											<?php
											}
											?>
										</div>
									</div>
								</article>
							</div>
						<?php
						} elseif ( $post_query->current_post === 1 ) {
						?>
							<div class="post-box-c-secondary-posts">
								<div class="d-sm-flex">
									<div class="post-box-c-secondary-post-first">
										<?php
										$post_class = array(
											'post-item',
											'post-portrait',
										);
										$post_link =  get_permalink();
										$post_time = get_the_time( get_option( 'date_format' ) );
										$post_time_attr = get_the_time( 'c' );
										?>
										<article <?php post_class( $post_class ); ?>>
											<?php
											nomady_featured_img( array(
												'size' => 'nomady_md_16_9',
												'class' => 'post-image',
											) );
											?>

											<div class="post-text text-lg-right">
												<h3 class="h4 h3-xl post-title entry-title ml-lg-auto">
													<a href="<?php echo esc_url( $post_link ); ?>" rel="bookmark"><?php the_title(); ?></a>
												</h3>

												<a class="post-read-more st-link d-none d-lg-inline-block" href="<?php echo esc_url( $post_link ); ?>"><?php esc_html_e( 'Read post', 'nomady' ); ?></a>
											</div>
										</article>
									</div>
									<?php
									if ( $post_query->current_post === ( $post_query->post_count - 1 ) ) {
									?>
								</div>
							</div>
						<?php
									}
						} else {
						?>
									<div class="post-box-c-secondary-post-second">
										<?php
										$post_class = array(
											'post-item',
											'post-landscape',
											'media',
											'align-items-lg-center',
											'flex-column',
											'flex-lg-row',
										);
										$post_link =  get_permalink();
										$post_time = get_the_time( get_option( 'date_format' ) );
										$post_time_attr = get_the_time( 'c' );
										?>
										<article <?php post_class( $post_class ); ?>>
											<?php
											nomady_featured_img( array(
												'size' => 'nomady_xs_4_5',
												'class' => 'post-image d-none d-lg-block',
											) );
											?>
											<?php
											nomady_featured_img( array(
												'size' => 'nomady_sm_16_9',
												'class' => 'post-image d-lg-none',
											) );
											?>

											<div class="media-body post-text">
												<h3 class="h4 h3-xl post-title entry-title">
													<a href="<?php echo esc_url($post_link); ?>" rel="bookmark"><?php the_title(); ?></a>
												</h3>

												<a class="post-read-more st-link d-none d-lg-inline-block" href="<?php echo esc_url( $post_link ); ?>"><?php esc_html_e( 'Read post', 'nomady' ); ?></a>
											</div>
										</article>
									</div>
									<?php
									if ( $post_query->current_post === ( $post_query->post_count - 1 ) ) {
									?>
								</div>
							</div>
									<?php
									}
						}
					}

					// Reset postdata
					wp_reset_postdata();
					?>
				</div>
			</div>
		</div>
	</section>
<?php
}