<?php
/**
 * Displays Hero Post Block D.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

$post_meta_author = nomady_get_option( 'meta_author_toggle', 'yes' );
$post_meta_date = nomady_get_option( 'meta_date_toggle', 'yes' );

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'excerpt_length' => 40,
) );

// Setting up variables.
$post_hero_class = ( $settings['widget_background_background'] ) ? array( 'post-portrait-cutout-background' ) : array();
$query_args[ 'posts_per_page' ] = 3;
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous post-box-d-section';

if ( $settings['widget_background_background'] ) {
	$section_class .= ' mnmd-section-has-background';
}

if ( $settings['color_scheme'] === 'dark' ) {
	$section_class .= ' mnmd-section-dark-scheme';
}

$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<div class="container-wide">
			<div class="mnmd-section-wrapper">
				<div class="row">
					<?php
					while ( $post_query->have_posts() ) {
						$post_query->the_post();
						if ( $post_query->current_post === 0 ) {
						?>
							<div class="post-box-d-primary-post-wrapper col-lg">
								<?php
								$post_class = array_merge( $post_hero_class,
									array(
										'post-item',
										'post-portrait',
										'post-portrait-lg',
										'post-portrait-cutout',
										'post-portrait-cutout-reverse',
										'post-portrait-cutout-hero',
									)
								);
								$post_link =  get_permalink();
								$post_time = get_the_time( get_option( 'date_format' ) );
								$post_time_attr = get_the_time( 'c' );
								?>
								<article <?php post_class( $post_class ); ?>>
									<div class="post-image">
										<div class="post-image-inner">
											<?php
											nomady_featured_img( array(
												'size' => 'nomady_lg_3_2',
												'barebone' => true,
											) );
											?>
											<a class="post-image-url" href="<?php echo esc_url( $post_link ); ?>"></a>
										</div>
									</div>

									<div class="post-text mnmd-scheme-applicable">
										<div class="post-meta">
											<?php nomady_post_categories(); ?>
										</div>

										<h3 class="post-title entry-title h2-sm h2-lg h1-xl display-5-xxl">
											<a href="<?php echo esc_url( $post_link ); ?>" rel="bookmark"><?php the_title(); ?></a>
										</h3>

										<?php
										if ( get_the_excerpt() && ( $settings['excerpt_length'] > 0 ) ) {
										?>
											<div class="post-excerpt post-excerpt-lg">
												<?php nomady_excerpt( $settings['excerpt_length'], true ); ?>
											</div>

											<a class="post-read-more st-link d-none d-sm-inline-block" href="<?php echo esc_url( $post_link ); ?>"><?php esc_html_e( 'Read more', 'nomady' ); ?></a>
										<?php
										}
										?>
									</div>
								</article>
							</div>
						<?php
						} elseif ( $post_query->current_post < 3 ) {
							if ( $post_query->current_post === 1 ) {
							?>
								<div class="post-box-d-secondary col-lg">
									<div class="row d-lg-block">
							<?php
							}
							?>
										<div class="post-box-d-secondary-item col-sm">
											<?php
											$post_class = array(
												'post-item',
												'post-portrait',
											);
											$post_link =  get_permalink();
											$post_time = get_the_time( get_option( 'date_format' ) );
											$post_time_attr = get_the_time( 'c' );
											?>
											<article <?php post_class( $post_class ); ?>>
												<?php
												nomady_featured_img( array(
													'size' => 'nomady_sm_3_2',
													'class' => 'post-image',
												) );
												?>

												<div class="post-text">
													<div class="post-meta">
														<?php nomady_post_categories(); ?>
													</div>

													<h3 class="post-title entry-title h5 h4-xxl">
														<a href="<?php echo esc_url( $post_link ); ?>" rel="bookmark"><?php the_title(); ?></a>
													</h3>
												</div>
											</article>
										</div>
							<?php
							if ( ( $post_query->current_post === 2 ) || ( $post_query->current_post === ( $post_query->post_count - 1 ) ) ) {
							?>
									</div>
								</div>
							<?php
							}
						} else {
							break;
						}
					}

					// Reset postdata
					wp_reset_postdata();
					?>
				</div>
			</div>
		</div>
	</section>
<?php
}