<?php
/**
 * Displays Hero Post Block Lone.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'fullwidth_layout' => 'wide',
	'excerpt_length' => 40,
    'post_meta_author' => 'yes',
    'post_meta_date' => 'yes',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous';
$section_class .= ' post-box-' . $settings['post_layout'] . '-section';
$section_class .= ' post-box-container-width-' . $settings['container_width'];
$post_template_args = array(
    'excerpt_length' => $settings['excerpt_length'],
);

if ( $settings['color_scheme'] === 'dark' ) {
	$section_class .= ' mnmd-section-dark-scheme';
}

switch ( $settings['post_layout'] ) {
	case 'e':
    default:
        $post_template = 'hero-cover';
        $post_template_args['container_width'] = $settings['container_width'];
        if ( $settings['container_width'] === 'fullwidth' ) {
            $post_template_args['thumb_size'] = 'nomady_4_3';
        }
        break;

    case 'f':
        $post_template = 'landscape-overlap';
        $post_template_args['container_width'] = $settings['container_width'];
        $post_template_args['thumb_reverse'] = $settings['reverse_layout'];
        if ( $settings['widget_background_background'] ) {
            $post_template_args['post_class'] = array( 'post-landscape-overlap-has-background' );
        }
        break;

    case 'g':
        $post_template = 'portrait-hero';
        if ( ( $settings['container_width'] === 'fullwidth' ) || ( $settings['container_width'] === 'fullbleed' ) ) {
            $post_template_args['thumb_size'] = 'nomady_2_1';
        }
        $post_template_args['container_width'] = $settings['container_width'];
        break;

    case 'h':
        $post_template = 'portrait-cutout-hero';
        if ( ( $settings['container_width'] === 'fullwidth' ) || ( $settings['container_width'] === 'fullbleed' ) ) {
            $settings['container_width'] = 'wide';
        }
        if ( $settings['widget_background_background'] ) {
            $post_template_args['post_class'] = array( 'post-portrait-cutout-background' );
        }
        break;

    case 'i':
        $post_template = 'hero-overlap';
        $post_template_args['container_width'] = $settings['container_width'];
        if ( $settings['container_width'] === 'fullwidth' ) {
            $post_template_args['thumb_size'] = 'nomady_4_3';
        }
        break;
}

switch ( $settings['container_width'] ) {
    default:
    case 'default':
        $container_class = 'container';
        $section_class .= ' post-box-e-default-width';
        break;

    case 'wide':
        $container_class = 'container-wide';
        break;

    case 'fullwidth':
        $container_class = 'container-fullwidth';
        break;

    case 'fullbleed':
        $container_class = '';
        break;
}

$query_args[ 'posts_per_page' ] = 1;
$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<div class="mnmd-section-wrapper">
            <?php
            if ( $container_class !== '' ) {
            ?>
            <div class="<?php echo esc_attr( $container_class ); ?>">
            <?php
            }

    		$post_query->the_post();
    		nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $post_template_args );

    		// Reset postdata
    		wp_reset_postdata();

            if ( $container_class !== '' ) {
            ?>
            </div>
            <?php
            }
            ?>
		</div>
	</section>
<?php
}