<?php
/**
 * Displays categories as tiles
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-links mnmd-links-' . $settings['columns'] . '-col mnmd-links-style-' . $settings['layout'];

if ( $settings['circle_image'] === 'yes' ) {
	$section_class .= ' mnmd-links-circle-image';
}

switch ( $settings['layout'] ) {
	case '1':
	default:
		$item_template = 'link-item-a';
		$row_class = 'row row-space-around flex-wrap';
		break;

	case '2':
		$item_template = 'link-item-b';
		$row_class = 'row row-space-around flex-wrap';
		break;

	case '3':
		$item_template = 'link-item-c';
		$row_class = 'row row-space-around flex-wrap';
		break;

	case '4':
		$item_template = 'link-item-d';
		$row_class = 'row row-space-around flex-wrap align-items-start';
		break;
}

switch ( $settings['columns'] ) {
	case '4':
		$col_class = 'col-sm-6 col-lg-3';
		break;

	case '3':
		$col_class = 'col-sm-6 col-md-4';
		break;

	default:
		$col_class = 'col';
		break;
}
?>
<section class="<?php echo esc_attr( $section_class ); ?>">
	<div class="container">
		<div class="mnmd-section-inner">
			<?php
            if ( $settings['heading'] ) {
            ?>
                <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                    <div class="mnmd-section-heading-primary">
                        <h4 class="mnmd-section-heading-title h3 meta-font">
                            <?php
                            echo wp_kses_post( $settings['heading'] );
                            ?>
                        </h4>

                        <?php
                        if ( $settings['subheading'] ) {
                            echo '<div class="mnmd-section-heading-subtitle">';
                            echo wp_kses_post( $settings['subheading'] );
                            echo '</div>';
                        }
                        ?>
                    </div>

                    <div class="mnmd-section-heading-secondary mt-2 mt-sm-0">
                        <?php
                        if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                        ?>
                            <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php
                                if( $settings['heading_url']['is_external'] ) {
                                    if( $settings['heading_url']['nofollow'] ) {
                                        echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                    } else {
                                        echo ' target="_blank" rel="noopener noreferrer"';
                                    }
                                } ?>>
                                <?php
                                echo '<span class="align-middle">';
                                echo wp_kses_post( $settings['heading_url_text'] );
                                echo '</span>';
                                echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                ?>
                            </a>
                        <?php
                        }
                        ?>
                    </div>
                </div><!-- .mnmd-section-heading -->
            <?php
            }
            ?>

        	<div class="mnmd-items-wrapper">
				<div class="<?php echo esc_attr( $row_class ); ?>">
					<?php
					if ( $settings['item_list'] ) {
						foreach ( $settings['item_list'] as $item ) {
							?>
							<div class="<?php echo esc_attr( $col_class ); ?>">
							<?php
							nomady_get_template_part( 'template-parts/misc/' . $item_template, NULL,
								array(
									'item_title' => $item['item_title'],
									'item_subtitle' => $item['item_subtitle'],
									'item_image' => $item['item_image'],
									'item_url' => $item['item_url'],
									'columns' => $settings['columns'],
								)
							);
							?>
							</div>
							<?php
						}
					}
					?>
				</div>
			</div>
		</div>
	</div>
</section>