<?php
/**
 * Displays Parallax Carousel.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'widget_background_background' => '',
    'widget_background_overlay_background' => '',
    'color_scheme' => 'light',
) );

$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous parallax-carousel-section';

if ( $settings['widget_background_background'] ) {
	$section_class .= ' mnmd-section-has-background';
}

if ( $settings['color_scheme'] === 'dark' ) {
	$section_class .= ' mnmd-section-dark-scheme';
}

$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<?php
		if ( $settings['widget_background_background'] ) {
			echo '<div class="mnmd-section-background background-object">';

			if ( $settings['widget_background_overlay_background'] ) {
				echo '<div class="background-overlay"></div>';
			}

			echo '</div>'; //.mnmd-section-background
		} ?>

		<div class="mnmd-section-wrapper">
			<div class="mnmd-section-inner">
				<div class="parallax-carousel-section-carousel js-parallax-carousel">
					<?php
					while ( $post_query->have_posts() ) {
						$post_query->the_post();
						nomady_get_template_part( 'template-parts/posts/carousel-item', NULL, array( 'color_scheme' => $settings['color_scheme'] ) );
					}
					// Reset postdata
					wp_reset_postdata();
					?>
				</div>

				<div class="parallax-carousel-navigation mx-auto font-meta">
					<div class="container">
						<div class="parallax-carousel-navigation-inner d-flex justify-content-between align-items-center">
							<span class="parallax-carousel-prev-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-lg' ) ); ?></span>
							<div class="parallax-carousel-progress">
								<span class="parallax-carousel-current-index">1</span>/<?php echo esc_html( $query_args['posts_per_page'] ); ?>
							</div>
							<span class="parallax-carousel-next-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-lg' ) ); ?></span>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
<?php
}