<?php
/**
 * Displays Post Block A.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'post_style' => 'default',
    'thumb_style' => 'default',
    'columns' => '4',
    'columns_horizontal_post' => '4',
    'vertical_align' => 'default',
    'widget_background_background' => '',
    'color_scheme' => 'light',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-post-block-a';
$section_class .= ' mnmd-post-block-post-style-' . $settings['post_style'];
$section_class .= ' mnmd-post-block-vertical-align-' . $settings['vertical_align'];

if ( $settings['widget_background_background'] ) {
    $section_class .= ' mnmd-section-has-background mnmd-section-has-background-overlap-top';
}

if ( $settings['color_scheme'] === 'dark' ) {
    $section_class .= ' mnmd-section-dark-scheme';
}

$section_content_class = 'mnmd-post-block-posts-wrapper row row-space-around';

if ( in_array( $settings['vertical_align'], array( 'start', 'center', 'end' ) ) ) {
    $section_content_class .= ' align-items-' . $settings['vertical_align'];
}

switch ( $settings['post_style'] ) {
	case 'portrait':
	default:
        if ( $settings['columns'] === '3' ) {
            $grid_item_class = 'col-sm-6 col-lg-4';
            $post_template = 'portrait';
        } else {
            $grid_item_class = 'col-sm-6 col-lg-3';
            $post_template = 'portrait-sm';
        }

		switch ( $settings['thumb_style'] ) {
			case 'default':
			default:
                if ( $settings['columns'] === '3' ) {
                    $thumb_size = 'nomady_sm_16_9';
                } else {
                    $thumb_size = 'nomady_sm_4_3';
                }

				break;

            case 'circle':
                $thumb_size = 'nomady_sm_1_1';

                break;

			case 'tall':
                $thumb_size = 'nomady_sm_4_5';

				break;

			case 'original':
                $thumb_size = 'nomady_sm';

				break;
		}

		break;

    case 'landscape':
        $settings['columns'] = $settings['columns_horizontal_post'];
        if ( $settings['columns'] === '2' ) {
            $grid_item_class = 'col-lg-6';
            $post_template = 'landscape';
        } else {
            $grid_item_class = 'col-md-6 col-xl-4';
            $post_template = 'landscape-sm';
        }
        $thumb_size = NULL;

        break;

	case 'card':
        if ( $settings['columns'] === '3' ) {
            $grid_item_class = 'col-md-6 col-lg-4';
            $post_template = 'card';
        } else {
            $grid_item_class = 'col-sm-6 col-lg-3';
            $post_template = 'card-sm';
        }
		$thumb_size = 'nomady_sm_16_9';

		break;

	case 'card-background':
        if ( $settings['columns'] === '3' ) {
            $grid_item_class = 'col-md-6 col-lg-4';
            $post_template = 'card-background';
        } else {
            $grid_item_class = 'col-sm-6 col-lg-3';
            $post_template = 'card-background-sm';
        }
		$thumb_size = 'nomady_sm_4_5';
        break;
}

$section_class .= ' mnmd-post-block-columns-' . $settings['columns'];

$query_args['posts_per_page'] = (int)$settings['columns'];
$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) {
?>
    <section class="<?php echo esc_attr( $section_class ); ?>">
        <?php
        if ( $settings['widget_background_background'] ) {
            echo '<div class="mnmd-section-background background-object stretched-viewport">';
            if ( $settings['widget_background_overlay_background'] ) {
                echo '<div class="background-overlay"></div>';
            }
            echo '</div>'; // .mnmd-section-background
        }
        ?>

        <div class="mnmd-section-wrapper">
            <div class="container">
                <?php
                if ( $settings['heading'] ) {
                ?>
                    <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                        <div class="mnmd-section-heading-primary">
                            <h4 class="mnmd-section-heading-title h3 meta-font">
                                <?php
                                echo wp_kses_post( $settings['heading'] );
                                ?>
                            </h4>

                            <?php
                            if ( $settings['subheading'] ) {
                                echo '<div class="mnmd-section-heading-subtitle">';
                                echo wp_kses_post( $settings['subheading'] );
                                echo '</div>';
                            }
                            ?>
                        </div>

                        <div class="mnmd-section-heading-secondary mt-2 mt-sm-0">
                            <?php
                            if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                            ?>
                                <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php
                                    if( $settings['heading_url']['is_external'] ) {
                                        if( $settings['heading_url']['nofollow'] ) {
                                            echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                        } else {
                                            echo ' target="_blank" rel="noopener noreferrer"';
                                        }
                                    } ?>>
                                    <?php
                                    echo '<span class="align-middle">';
                                    echo wp_kses_post( $settings['heading_url_text'] );
                                    echo '</span>';
                                    echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                    ?>
                                </a>
                            <?php
                            }
                            ?>
                        </div>
                    </div><!-- .mnmd-section-heading -->
                <?php
                }
                ?>

                <div class="<?php echo esc_attr( $section_content_class ); ?>">
    	            <?php
                    $post_template_args = array(
                        'center_text' => 'no',
                        'thumb_size' => $thumb_size,
                        'post_format_icon' => 'no',
                        'excerpt_length' => 0,
                        'post_meta_secondary' => false,
                    );

                    if ( $settings['thumb_style'] === 'circle' ) {
                        $post_template_args['post_class'] = array( 'post-portrait-circle-thumb' );
                        $post_template_args['center_text'] = 'yes';
                        $post_template_args['post_meta_author'] = 'no';
                        $post_template_args['post_meta_date'] = 'no';
                    }

                    if ( ( $settings['post_style'] === 'card' ) || ( $settings['post_style'] === 'card-background' ) ) {
                        $post_template_args['center_text'] = 'yes';
                    }

    	            while ( $post_query->have_posts() ) {
    	                $post_query->the_post();

    	                echo '<div class="' . esc_attr( $grid_item_class ) . '">';
    	                nomady_get_template_part( 'template-parts/posts/post-' . $post_template, NULL, $post_template_args );
    	                echo '</div>';
    	            }
    	            ?>
                </div>
            </div>
        </div>
    </section>
<?php
}