<?php
/**
 * Displays Post Block E.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'heading' => '',
    'reverse_layout' => 'no',
    'excerpt_length' => 40,
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-section-first-contiguous mnmd-post-block-e';

$query_args['posts_per_page'] = 4;
$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) {
?>
    <section class="<?php echo esc_attr( $section_class ); ?>">
        <div class="container">
            <?php
            if ( $settings['heading'] ) {
            ?>
                <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                    <div class="mnmd-section-heading-primary">
                        <h4 class="mnmd-section-heading-title h3 meta-font">
                            <?php
                            echo wp_kses_post( $settings['heading'] );
                            ?>
                        </h4>

                        <?php
                        if ( $settings['subheading'] ) {
                            echo '<div class="mnmd-section-heading-subtitle">';
                            echo wp_kses_post( $settings['subheading'] );
                            echo '</div>';
                        }
                        ?>
                    </div>

                    <div class="mnmd-section-heading-secondary mt-2 mt-sm-0">
                        <?php
                        if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                        ?>
                            <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php
                                if( $settings['heading_url']['is_external'] ) {
                                    if( $settings['heading_url']['nofollow'] ) {
                                        echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                    } else {
                                        echo ' target="_blank" rel="noopener noreferrer"';
                                    }
                                } ?>>
                                <?php
                                echo '<span class="align-middle">';
                                echo wp_kses_post( $settings['heading_url_text'] );
                                echo '</span>';
                                echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                ?>
                            </a>
                        <?php
                        }
                        ?>
                    </div>
                </div><!-- .mnmd-section-heading -->
            <?php
            }
            ?>

            <div class="mnmd-section-inner">
                <?php
                while ( $post_query->have_posts() ) {
                    $post_query->the_post();
                    if ( $post_query->current_post === 0 ) {
                        echo '<div class="row row-space-around">';
                    }

                    if ( ( $post_query->current_post === 0 ) ) {
                            echo '<div class="col-lg-6">';
                                nomady_get_template_part( 'template-parts/posts/post-portrait-lg', NULL,
                                    array(
                                        'thumb_size' => 'nomady_md_4_3',
                                        'thumb_reverse' => 'yes',
                                        'excerpt_length' => $settings['excerpt_length'],
                                    )
                                );
                            echo '</div>';
                    } elseif ( ( $post_query->current_post === 1 ) )  {
                            echo '<div class="col-lg-6">';
                                echo '<div class="row row-space-around">';
                                    echo '<div class="col-lg-12">';
                                        nomady_get_template_part( 'template-parts/posts/post-card-background', NULL,
                                            array(
                                                'thumb_size' => 'nomady_md_16_9',
                                                'excerpt_length' => 0,
                                                'center_text' => 'no',
                                                'post_meta_author' => 'no',
                                                'post_meta_date' => 'no',
                                            )
                                        );
                                    echo '</div>';
                    } elseif ( ( $post_query->current_post > 1 ) )  {
                                    echo '<div class="col-lg-6">';
                                        nomady_get_template_part( 'template-parts/posts/post-portrait-sm', NULL,
                                           array(
                                                'thumb_size' => 'nomady_sm_16_9',
                                            )
                                        );
                                    echo '</div>';
                    }

                    if ( $post_query->found_posts === 1 ) {
                        echo '</div>';
                    } elseif ( ( $post_query->current_post === ( $post_query->found_posts - 1 ) ) || ( $post_query->current_post === 3 ) ) {
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    }
                }
                ?>
            </div>
        </div>
    </section>
<?php
}