<?php
/**
 * Displays Post Carousel A.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'items_per_view' => '4',
    'thumb_style' => 'default',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-post-carousel-section mnmd-post-carousel-a';
$section_class .= ' mnmd-post-carousel-' . $settings['items_per_view'] . 'i';
$section_class .= ' mnmd-post-carousel-post-' . $settings['post_style'];

if ( $settings['overflow'] === 'yes' ) {
	$section_class .= ' mnmd-post-carousel-overflow';
}

$carousel_class = 'swiper-container mnmd-carousel mnmd-carousel-swiper js-mnmd-post-carousel';
$carousel_class .= ' mnmd-carousel-' . $settings['items_per_view'] . 'i';
$carousel_class .= ' mnmd-carousel-post-' . $settings['post_style'];

$template_args = array();

switch ( $settings['post_style'] ) {
	default:
	case 'card':
		if ( $settings['widget_background_background'] ) {
			$section_class .= ' mnmd-section-has-background mnmd-section-has-background-overlap-top';
		}

		if ( $settings['items_per_view'] === '3' ) {
			$post_template = 'post-card';
		} else {
			$post_template = 'post-card-sm';
		}

		break;

	case 'card-background':
		if ( $settings['widget_background_background'] ) {
			$section_class .= ' mnmd-section-has-background mnmd-section-has-background-overlap-top';
		}

		if ( $settings['items_per_view'] === '3' ) {
			$post_template = 'post-card-background';
		} else {
			$post_template = 'post-card-background-sm';
		}

		break;

	case 'portrait':
		if ( $settings['widget_background_background'] ) {
			$section_class .= ' mnmd-section-has-background mnmd-section-has-background';
		}

		if ( $settings['items_per_view'] === '3' ) {
			$post_template = 'post-portrait';
		} else {
			$post_template = 'post-portrait-sm';
		}

		if ( $settings['thumb_style'] === 'default' ) {
			$template_args['thumb_size'] = 'nomady_sm_4_3';
		} else {
			$template_args['thumb_size'] = 'nomady_sm_4_5';
		}

		$template_args['excerpt_length'] = 0;
		$template_args['post_meta_secondary'] = false;

		break;
}

$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<?php
		if ( $settings['widget_background_background'] ) {
			if ( $settings['post_style'] === 'portrait' ) {
				echo '<div class="mnmd-section-background mnmd-section-background-stretch-left background-object"></div>';
			} else {
				echo '<div class="mnmd-section-background mnmd-section-background-stretch background-object"></div>';
			}
		}
		?>

		<div class="mnmd-section-wrapper">
			<div class="container">
				<div class="mnmd-section-inner">
                    <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                    	<?php
	                    if ( $settings['heading'] ) {
	                    ?>
                        <div class="mnmd-section-heading-primary">
                            <h4 class="mnmd-section-heading-title h3 meta-font">
                                <?php
                                echo wp_kses_post( $settings['heading'] );
                                ?>
                            </h4>

                            <?php
                            if ( $settings['subheading'] ) {
                                echo '<div class="mnmd-section-heading-subtitle">';
                                echo wp_kses_post( $settings['subheading'] );
                                echo '</div>';
                            }
                            ?>
                        </div>
                        <?php
	                    }
	                    ?>

	                    <?php
	                    if ( $post_query->post_count > $settings['items_per_view'] ) {
	                    ?>
                        <div class="mnmd-section-heading-secondary mt-2 mt-sm-0 ml-auto d-flex align-items-center">
                        	<div class="mnmd-carousel-pagination-fraction font-meta mr-3"><span class="mnmd-carousel-pagination-current">1</span>/<span class="mnmd-carousel-pagination-total"><?php printf( $post_query->post_count - $settings['items_per_view'] + 1 ); ?></span></div>
                            <div class="mnmd-carousel-navigation">
								<div class="mnmd-carousel-prev-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md' ) ) ;?></div>
								<div class="mnmd-carousel-next-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md' ) ) ;?></div>
							</div>
                        </div>
                        <?php
	                    }
	                    ?>
                    </div><!-- .mnmd-section-heading -->

					<div class="<?php echo esc_attr( $carousel_class ); ?>">
						<div class="swiper-wrapper">
							<?php
							while ( $post_query->have_posts() ) {
								$post_query->the_post();
								echo '<div class="mnmd-carousel-item swiper-slide">';
								nomady_get_template_part( 'template-parts/posts/' . $post_template, NULL, $template_args );
								echo '</div>';
							}
							// Reset postdata
							wp_reset_postdata();
							?>
						</div>

						<div class="mnmd-carousel-hidden-pagination"></div>
					</div>
				</div>
			</div>
		</div>
	</section>
<?php
}