<?php
/**
 * Displays Post Carousel C.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];
$block_id = $args['block_id'];

// Merge with default value.
$settings = wp_parse_args( $settings, array(
    'widget_background_background' => '',
) );

// Setting up variables.
$section_class = 'mnmd-section mnmd-section-fullwidth mnmd-post-carousel-section mnmd-post-carousel-c';
$carousel_class = 'swiper-container mnmd-carousel mnmd-carousel-swiper mnmd-carousel-auto-width js-mnmd-post-carousel';
$post_template = 'carousel-c-item';

$section_class .= ' mnmd-post-carousel-' . $settings['carousel_style'];
$section_class .= ' mnmd-post-carousel-post-' . $settings['post_style'];

if ( $settings['overflow'] === 'yes' ) {
	$section_class .= ' mnmd-post-carousel-overflow';
}

if ( $settings['widget_background_background'] ) {
	$section_class .= ' mnmd-section-has-background mnmd-section-has-background';
}

if ( $settings['items_per_view'] ) {
	$section_class .= ' mnmd-post-carousel-' . $settings['items_per_view'] . 'i';
	$carousel_class .= ' mnmd-carousel-' . $settings['items_per_view'] . 'i';
}

$carousel_class .= ' mnmd-carousel-post-' . $settings['post_style'];

$post_query = new WP_Query( $query_args );

if ( $post_query->have_posts() ) { ?>
	<section class="<?php echo esc_attr( $section_class ); ?>">
		<?php
		if ( $settings['widget_background_background'] ) {
			echo '<div class="mnmd-section-background background-object"></div>';
		}
		?>

		<div class="mnmd-section-wrapper">
			<div class="container">
				<div class="mnmd-section-inner">
                    <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                    	<?php
	                    if ( $settings['heading'] ) {
	                    ?>
                        <div class="mnmd-section-heading-primary">
                            <h4 class="mnmd-section-heading-title h3 meta-font">
                                <?php
                                echo wp_kses_post( $settings['heading'] );
                                ?>
                            </h4>

                            <?php
                            if ( $settings['subheading'] ) {
                                echo '<div class="mnmd-section-heading-subtitle">';
                                echo wp_kses_post( $settings['subheading'] );
                                echo '</div>';
                            }
                            ?>
                        </div>
                        <?php
	                    }
	                    ?>

	                    <?php
	                    if ( $post_query->post_count > $settings['items_per_view'] ) {
	                    ?>
                        <div class="mnmd-section-heading-secondary mt-2 mt-sm-0 ml-auto d-flex align-items-center">
                        	<div class="mnmd-carousel-pagination-fraction font-meta mr-3"><span class="mnmd-carousel-current-index">1</span>/<span><?php printf( $post_query->post_count - $settings['items_per_view'] + 1 ); ?></span></div>
                            <div class="mnmd-carousel-navigation">
								<div class="mnmd-carousel-prev-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-left', 'class' => 'mnmd-icon-md' ) ) ;?></div>
								<div class="mnmd-carousel-next-btn"><?php echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-md' ) ) ;?></div>
							</div>
                        </div>
                        <?php
	                    }
	                    ?>
                    </div><!-- .mnmd-section-heading -->

					<div class="<?php echo esc_attr( $carousel_class ); ?>">
						<div class="swiper-wrapper">
							<?php
							$average_width = 25; // Average width in rem.
							$min_width = 15; // Min width in rem.
							$max_width = 37.5; // Max width in rem.
							$style = '@media (min-width: 768px) { ';
							while ( $post_query->have_posts() ) {
								$post_query->the_post();

								if ( has_post_thumbnail() ) {
									$thumb_id   = get_post_thumbnail_id();
									$thumb_data = wp_get_attachment_image_src( $thumb_id , 'nomady_sm' );

									// calculate new width by width/height ratio.
									$new_width = ( $thumb_data[1] / $thumb_data[2] ) * $average_width;

									// limit min and max width.
									if ( $new_width < $min_width ) $new_width = $min_width;
									if ( $new_width > $max_width ) $new_width = $max_width;

									$style .= ' #mnmd-post-carousel-' . $block_id . ' .mnmd-carousel-item:nth-child(' . ( $post_query->current_post + 1 ) . ') { width: ' . $new_width . 'rem; }';
								}

								echo '<div class="mnmd-carousel-item swiper-slide">';
								nomady_get_template_part( 'template-parts/posts/' . $post_template, NULL,
									array(
										'color_scheme' => $settings['color_scheme'],
									)
								);
								echo '</div>';
							}
							$style .= ' }';

							// Reset postdata
							wp_reset_postdata();
							?>
						</div>
					</div>

					<?php
					echo '<style type="text/css">';
					echo esc_html( $style );
					echo '</style>';
					?>
				</div>
			</div>
		</div>
	</section>
<?php
}