<?php
/**
 * Displays Post Listing section.
 */

if ( !isset( $args ) ) return; // Exit if there's no variables passed.

$settings = $args['settings'];
$query_args = $args['query_args'];
$sticky_sidebar = nomady_get_option( 'sticky_sidebar', 'yes' );

// Merge with default value.
$settings = wp_parse_args( $settings, array(
	'post_layout' => 'list-landscape',
    'grid_columns' => 3,
    'flow_columns' => 3,
    'hero_post_first' => 'no',
    'hero_cycle' => 4,
	'thumb_reverse' => 'no',
    'thumb_original_ratio' => 'no',
    'post_format_icon' => 'no',
	'pagination' => 'default',
	'view_more_url' => '',
	'view-more-url-title' => '',
) );

// Setting up variables.
$post_listing_args = array(
    'ignore_sticky_posts' => 'yes',
    'post_layout' => $settings['post_layout'],
    'grid_columns' => $settings['grid_columns'],
    'flow_columns' => $settings['flow_columns'],
    'hero_post_first' => $settings['hero_post_first'],
    'hero_cycle' => $settings['hero_cycle'],
    'thumb_reverse' => $settings['thumb_reverse'],
    'thumb_original_ratio' => $settings['thumb_original_ratio'],
    'post_format_icon' => $settings['post_format_icon'],
    'excerpt_length' => NULL,
    'excerpt_length_hero' => NULL,
    'pagination' => $settings['pagination'],
);

if ( $settings['excerpt_length_toggle'] === 'yes' ) {
    $post_listing_args['excerpt_length'] = $settings['excerpt_length'];
    $post_listing_args['excerpt_length_hero'] = $settings['excerpt_length_hero'];
}

if ( $settings['pagination'] === 'view-more-url' ) {
    $post_listing_args['view_more_url'] = $settings['view_more_url'];
    $post_listing_args['view_more_url_title'] = $settings['view_more_url_title'];
}

// Get current page.
if ( get_query_var( 'paged' ) ) {
    $paged = get_query_var( 'paged' );
} elseif ( get_query_var( 'page' ) ) {
    $paged = get_query_var( 'page' );
} else {
    $paged = 1;
}

// Calculate offset if not the first page.
if ( $paged > 1 ) {
    $query_args['offset'] += ( $paged - 1 ) * $query_args[ 'posts_per_page' ];
}

$post_listing_args['query'] = $query_args;

$query_string = build_query( $query_args ); // Build query string for AJAX load posts.

$post_query = new \WP_Query( $query_args );

$post_listing_args['post_query'] = $post_query;

$section_class = 'mnmd-section mnmd-section-main-section post-listing-section post-listing-section-' . $settings['post_layout'];
$section_content_class = 'post-listing-content';

if ( $settings['pagination'] === 'ajax-load-more' ) {
    $section_content_class .= ' js-mnmd-ajax-content';
}

if ( $post_query->have_posts() ) {
    if ( in_array( $post_listing_args['post_layout'], array( 'list-landscape', 'list-portrait', 'list-mixed-1', 'list-mixed-2', 'grid-portrait', 'grid-mixed-1', 'grid-mixed-2', 'masonry-portrait' ) ) ) {
    ?>
        <section class="mnmd-section main-n-sidebar-section has-right-sidebar clearfix">
            <div class="container">
                <div class="mnmd-section-inner d-lg-flex">
                    <main class="mnmd-section-main">
                        <section class="<?php echo esc_attr( $section_class ); ?>">
                            <div class="mnmd-section-inner">
                                <?php
                                if ( $settings['heading'] ) {
                                ?>
                                    <div class="mnmd-section-heading d-sm-flex justify-content-between align-items-end">
                                        <div class="mnmd-section-heading-primary">
                                            <h4 class="mnmd-section-heading-title h3 meta-font">
                                                <?php
                                                echo wp_kses_post( $settings['heading'] );

                                                if ( $paged > 1) {
                                                    esc_html_e( ' - Page ', 'nomady' );
                                                    echo esc_html( $paged );
                                                }
                                                ?>
                                            </h4>

                                            <?php
                                            if ( $settings['subheading'] ) {
                                                echo '<div class="mnmd-section-heading-subtitle">';
                                                echo wp_kses_post( $settings['subheading'] );
                                                echo '</div>';
                                            }
                                            ?>
                                        </div>

                                        <div class="mnmd-section-heading-secondary mt-2 mt-sm-0">
                                            <?php
                                            if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                                            ?>
                                                <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php if( $settings['heading_url']['is_external'] ) {
                                                        if( $settings['heading_url']['nofollow'] ) {
                                                            echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                                        } else {
                                                            echo ' target="_blank" rel="noopener noreferrer"';
                                                        }
                                                    } ?>>
                                                    <?php
                                                    echo '<span class="align-middle">';
                                                    echo wp_kses_post( $settings['heading_url_text'] );
                                                    echo '</span>';
                                                    echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                                    ?>
                                                </a>
                                            <?php
                                            }
                                            ?>
                                        </div>
                                    </div><!-- .mnmd-section-heading -->
                                <?php
                                }
                                ?>

                                <?php
                                nomady_post_listing( $post_listing_args );
                                ?>
                        </section>
                    </main><!-- #main -->

                    <aside class="mnmd-section-sidebar sidebar<?php if ( $sticky_sidebar === 'yes' ) { echo ' js-mnmd-sticky-sidebar'; } ?>">
                        <?php
                        if ( $sticky_sidebar === 'yes' ) {
                            echo '<div class="theiaStickySidebar">';
                        }

                        if ( is_active_sidebar( $settings['sidebar'] ) ) {
                            dynamic_sidebar( $settings['sidebar'] );
                        }

                        if ( $sticky_sidebar === 'yes' ) {
                            echo '</div>';
                        }
                        ?>
                    </aside>
                </div>
            </div>
        </section>
    <?php
    } else { ?>
        <section class="<?php echo esc_attr( $section_class ); ?>">
            <div class="container">
                <div class="mnmd-section-inner">
                    <?php
                    if ( $settings['heading'] ) {
                    ?>
                        <div class="mnmd-section-heading d-md-flex justify-content-between align-items-end">
                            <div class="mnmd-section-heading-primary">
                                <h4 class="mnmd-section-heading-title h3 meta-font">
                                    <?php
                                    echo wp_kses_post( $settings['heading'] );

                                    if ( $paged > 1) {
                                        esc_html_e( ' - Page ', 'nomady' );
                                        echo esc_html( $paged );
                                    }
                                    ?>
                                </h4>

                                <?php
                                if ( $settings['subheading'] ) {
                                    echo '<div class="mnmd-section-heading-subtitle">';
                                    echo wp_kses_post( $settings['subheading'] );
                                    echo '</div>';
                                }
                                ?>
                            </div>

                            <div class="mnmd-section-heading-secondary">
                                <?php
                                if ( $settings['heading_url']['url'] && $settings['heading_url_text'] ) {
                                ?>
                                    <a class="mnmd-section-heading-view-more st-btn-icon-animation-on-hover" href="<?php echo esc_url( $settings['heading_url']['url'] ); ?>"<?php if( $settings['heading_url']['is_external'] ) {
                                            if( $settings['heading_url']['nofollow'] ) {
                                                echo ' target="_blank" rel="noopener noreferrer nofollow"';
                                            } else {
                                                echo ' target="_blank" rel="noopener noreferrer"';
                                            }
                                        } ?>>
                                        <?php
                                        echo '<span class="align-middle">';
                                        echo wp_kses_post( $settings['heading_url_text'] );
                                        echo '</span>';
                                        echo nomady_svg_icon( array( 'icon' => 'arrow-right', 'class' => 'mnmd-icon-last' ) );
                                        ?>
                                    </a>
                                <?php
                                }
                                ?>
                            </div>
                        </div><!-- .mnmd-section-heading -->
                    <?php
                    }
                    ?>

                    <?php
                    nomady_post_listing( $post_listing_args );
                    ?>
                </div>
            </div>
        </section>
    <?php
    }
}