<?php
/**
 * Displays related posts
 */

$heading_text = nomady_get_option( 'single_related_posts_heading', esc_html__( 'Related posts', 'nomady' ) );
$post_order = nomady_get_option( 'single_related_posts_order', 'latest' );
$post_style = nomady_get_option( 'single_related_posts_style', 'default' );
$columns = nomady_get_option( 'single_related_posts_columns', '3' );
$background_switch = nomady_get_option( 'single_related_posts_background_switch', 'yes' );
$posts_wrapper_class = '';
$post_item_wrapper_class = '';
$post_template = '';
$template_args = array();

$section_class = 'mnmd-section mnmd-section-fullwidth single-related-posts-section';
$section_class .= ' single-related-posts-section-' . $post_style;
$section_class .= ' single-related-posts-section-' . $columns . '-col';

if ( $background_switch === 'yes' ) {
	$text_color = nomady_get_option( 'single_related_posts_text_color', 'dark' );
	$section_class .= ' mnmd-section-has-background';
	if ( ( $post_style === 'card' ) || ( $post_style === 'card-overlay' ) ) {
		$overlap_background = nomady_get_option( 'single_related_posts_overlap_background', 'no' );
		if ( $overlap_background === 'yes' ) {
			$section_class .= ' mnmd-section-has-background-overlap-top';
		}

		if ( $text_color === 'light' ) {
			$section_class .= ' mnmd-section-text-inverted';
		}
	} else {
		if ( $text_color === 'light' ) {
			$section_class .= ' mnmd-section-text-inverted mnmd-section-post-text-inverted';
		}
	}
}

$post_id = get_the_id();
$posts_per_page = (int)$columns;

if ( current_user_can('read_private_posts') ) {
	$post_status = array(
		'publish',
		'private',
	);
} else {
	$post_status = 'publish';
}

if ( is_single() ) {
	$next_post = get_next_post();
	$next_post_ID = ( property_exists( $next_post, 'ID' ) ) ? $next_post->ID : 0;
	$prev_post = get_previous_post();
	$prev_post_ID = ( property_exists( $prev_post, 'ID' ) ) ? $prev_post->ID : 0;
} else {
	$next_post_ID = 0;
	$prev_post_ID = 0;
}

$query_args = array(
	'post_type'      		=> get_post_type( $post_id ),
	'post_status'			=> $post_status,
	'posts_per_page'      	=> $posts_per_page,
	'post__not_in'   => array( $post_id, $next_post_ID, $prev_post_ID ),
	'ignore_sticky_posts' 	=> 1,
	'orderby'   			=> $post_order,
);

$post       = get_post( $post_id );
$taxonomies = get_object_taxonomies( $post, 'names' );

foreach( $taxonomies as $taxonomy ) {
	if  (( $taxonomy === 'tag' ) || ( $taxonomy === 'category' ) ) {
		$terms = get_the_terms( $post_id, $taxonomy );
		if ( empty( $terms ) ) continue;
		$term_list = wp_list_pluck( $terms, 'slug' );
		$query_args['tax_query'][] = array(
			'taxonomy' => $taxonomy,
			'field'    => 'slug',
			'terms'    => $term_list,
		);
	}
}

if ( array_key_exists( 'tax_query', $query_args ) ) {
	if ( is_array( $query_args['tax_query'] ) ) {
		if( count( $query_args['tax_query'] ) > 1 ) {
			$query_args['tax_query']['relation'] = 'OR';
		}
	}
}

$query = new WP_Query( $query_args );

if ( $query->have_posts() ) { ?>
	<div class="<?php echo esc_attr( $section_class ); ?>">
		<?php
		if ( $background_switch === 'yes' ) {
		?>
			<div class="mnmd-section-background background-object"></div>
		<?php
		}
		?>

		<div class="container">
			<div class="single-related-posts-section-inner">
				<?php
				if ( $heading_text !== '' ) {
				?>
				<div class="mnmd-section-heading">
					<h4 class="mnmd-section-heading-title h3 meta-font">
						<?php
						echo wp_kses_post( $heading_text );
						?>
					</h4>
				</div><!-- .mnmd-section-heading -->
				<?php
				}

				switch ( $post_style ) {
					case 'default':
					default:
						$posts_wrapper_class = 'row row-space-around';
						if ( $columns === '3' ) {
							$post_item_wrapper_class = 'col-sm-6 col-md-4';
							$post_template = 'post-portrait';
						} else {
							$post_item_wrapper_class = 'col-sm-6 col-md-3';
							$post_template = 'post-portrait-sm';
						}
						break;

					case 'original-ratio-thumb':
						$posts_wrapper_class = 'row row-space-around';
						if ( $columns === '3' ) {
							$post_item_wrapper_class = 'col-sm-6 col-md-4';
							$post_template = 'post-portrait';
							$template_args['thumb_size'] = 'nomady_md';
						} else {
							$post_item_wrapper_class = 'col-sm-6 col-lg-3';
							$post_template = 'post-portrait-sm';
							$template_args['thumb_size'] = 'nomady_sm';
						}
						break;

					case 'tall':
						$posts_wrapper_class = 'row row-space-around';
						if ( $columns === '3' ) {
							$post_item_wrapper_class = 'col-sm-6 col-md-4';
							$post_template = 'post-portrait';
							$template_args['thumb_size'] = 'nomady_md_4_5';
						} else {
							$post_item_wrapper_class = 'col-sm-6 col-lg-3';
							$post_template = 'post-portrait-sm';
							$template_args['thumb_size'] = 'nomady_sm_4_5';
						}
						break;

					case 'card':
						$posts_wrapper_class = 'card-deck card-deck-space-around card-deck-' . esc_attr( $columns ) . '-col';
						if ( $columns === '3' ) {
							$post_template = 'post-card';
						} else {
							$post_template = 'post-card-sm';
						}
						break;

					case 'card-overlay':
						$posts_wrapper_class = 'card-deck card-deck-space-around card-deck-' . esc_attr( $columns ) . '-col';
						if ( $columns === '3' ) {
							$post_template = 'post-card-background';
						} else {
							$post_template = 'post-card-background-sm';
						}
						break;
				}

				if ( $posts_wrapper_class !== '' ) {
					echo '<div class="' . esc_attr( $posts_wrapper_class ) . '">';
				}

				while ( $query->have_posts() ) {
					$query->the_post();
					if ( $post_item_wrapper_class !== '' ) {
						echo '<div class="' . esc_attr( $post_item_wrapper_class ) . '">';
					}

					nomady_get_template_part( 'template-parts/posts/' . $post_template, NULL, $template_args );

					if ( $post_item_wrapper_class !== '' ) {
						echo '</div>';
					}
				}

				if ( $posts_wrapper_class !== '' ) {
					echo '</div>';
				}
				?>
			</div>
		</div>
	</div>
<?php
}

wp_reset_query();