<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class About extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady About', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info-circle-o';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'label_block' => true,
				'default' => 'Welcome to my blog!',
			]
		);

		$this->add_control(
			'body',
			[
				'label' => esc_html__( 'Body', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'rows' => 10,
			]
		);

		$this->add_control(
			'social_heading',
			[
				'label' => esc_html__( 'Social list heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'Follow me', 'nomady-core' ),
			]
		);

		$social_repeater = new \Elementor\Repeater();

		$social_repeater->add_control(
			'social_name',
			[
				'label' => esc_html__( 'Name', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'Behance' => esc_html__( 'Behance', 'nomady-core' ),
					'Dribbble' => esc_html__( 'Dribbble', 'nomady-core' ),
					'Facebook' => esc_html__( 'Facebook', 'nomady-core' ),
					'Google' => esc_html__( 'Google', 'nomady-core' ),
					'Instagram' => esc_html__( 'Instagram', 'nomady-core' ),
					'Linkedin' => esc_html__( 'Linkedin', 'nomady-core' ),
					'Pinterest' => esc_html__( 'Pinterest', 'nomady-core' ),
					'Snapchat' => esc_html__( 'Snapchat', 'nomady-core' ),
					'Soundcloud' => esc_html__( 'Soundcloud', 'nomady-core' ),
					'Spotify' => esc_html__( 'Spotify', 'nomady-core' ),
					'Telegram' => esc_html__( 'Telegram', 'nomady-core' ),
					'Tumblr' => esc_html__( 'Tumblr', 'nomady-core' ),
					'Twitter' => esc_html__( 'Twitter', 'nomady-core' ),
					'VK' => esc_html__( 'VK', 'nomady-core' ),
					'Youtube' => esc_html__( 'Youtube', 'nomady-core' ),
				],
			]
		);

		$social_repeater->add_control(
			'social_url',
			[
				'label' => esc_html__( 'URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$this->add_control(
			'social_list',
			[
				'label' => esc_html__( 'Social list', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $social_repeater->get_controls(),
				'title_field' => '{{{ social_name }}}',
			]
		);

		$this->add_control(
			'links_heading',
			[
				'label' => esc_html__( 'Links heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'Other links', 'nomady-core' ),
			]
		);

		$links_repeater = new \Elementor\Repeater();

		$links_repeater->add_control(
			'link_title',
			[
				'label' => esc_html__( 'Link title', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$links_repeater->add_control(
			'link_url',
			[
				'label' => esc_html__( 'URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$this->add_control(
			'links_list',
			[
				'label' => esc_html__( 'Links', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $links_repeater->get_controls(),
				'title_field' => '{{{ link_title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::HIDDEN,
				'default' => 'about-a',
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Image', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'image_caption',
			[
				'label' => esc_html__( 'Image caption', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'condition' => [
                    'image_style' => 'polaroid',
                    'image!' => '',
                ],
			]
		);

		$this->add_control(
			'image_caption_font',
			[
				'label' => esc_html__( 'Image caption font family', 'nomady' ),
				'type' => \Elementor\Controls_Manager::FONT,
				'label_block' => true,
				'default' => "'Waiting for the Sunrise', sans-serif",
				'selectors' => [
					'{{WRAPPER}} .mnmd-about-image-caption' => 'font-family: {{VALUE}}',
				],
				'condition' => [
                    'image_style' => 'polaroid',
                    'image!' => '',
                ],
			]
		);

		$this->add_control(
			'image_style',
			[
				'label' => esc_html__( 'Image decoration', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'polaroid' => esc_html__( 'Polaroid', 'nomady-core' ),
					'pattern' => esc_html__( 'Pattern', 'nomady-core' ),
					'none' => esc_html__( 'None', 'nomady-core' ),
				],
				'default' => 'polaroid',
			]
		);

		$this->add_control(
			'image_position',
			[
				'label' => esc_html__( 'Image position', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'left' => esc_html__( 'Left', 'nomady-core' ),
					'center' => esc_html__( 'Center', 'nomady-core' ),
				],
				'default' => 'left',
			]
		);

		$this->add_control(
			'accent_color',
			[
				'label' => esc_html__( 'Accent color', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'alpha' => false,
				'selectors' => [
					'{{WRAPPER}} .mnmd-pattern-object' => 'color: {{VALUE}}',
				],
				'default' => '#000',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();
		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
			'section_id' => $this->get_id(),
		);

        $this->add_render_attribute(
            'about_wrapper',
            [
                'id' => 'mnmd-about-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-about',
                    'mnmd-about-' . esc_attr( $settings['layout'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'about_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/' . $settings['layout'], NULL, $template_args );
        echo '</div>';
	}
}