<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Hero_Post_Block extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-hero-post-block';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Hero Post Block', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-group';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		/**
         * Query Controls
         * @source includes/helper.php
         */
        $this->post_query_controls();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'post_layout',
			[
				'label' => esc_html__( 'Post layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'a' => esc_html__( 'Layout 1', 'nomady-core' ),
					'c' => esc_html__( 'Layout 2', 'nomady-core' ),
					'd' => esc_html__( 'Layout 3', 'nomady-core' ),
					'e' => esc_html__( 'Layout 4', 'nomady-core' ),
					'f' => esc_html__( 'Layout 5', 'nomady-core' ),
					'g' => esc_html__( 'Layout 6', 'nomady-core' ),
					'h' => esc_html__( 'Layout 7', 'nomady-core' ),
					'i' => esc_html__( 'Layout 8', 'nomady-core' ),
				],
				'default' => 'a',
			]
		);

		$this->add_control(
			'container_width',
			[
				'label' => esc_html__( 'Container width', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'nomady-core' ),
					'wide' => esc_html__( 'Wide', 'nomady-core' ),
					'fullwidth' => esc_html__( 'Full-width', 'nomady-core' ),
					'fullbleed' => esc_html__( 'Full-bleed', 'nomady-core' ),
				],
				'default' => 'default',
				'condition' => [
                    'post_layout' => [
						'e',
						'f',
						'g',
						'i',
					],
                ],
			]
		);

		$this->add_control(
			'reverse_layout',
			[
				'label' => esc_html__( 'Reverse layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
                    'post_layout' => [
						'f',
					],
                ],
			]
		);

        $this->add_control(
            'excerpt_length',
            [
                'label' => esc_html__('Excerpt Length', 'nomady-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 55,
                'default' => 40,
                'title' => esc_html__('In words', 'nomady-core'),
            ]
        );

        $this->add_control(
            'excerpt_length_secondary',
            [
                'label' => esc_html__('Excerpt length of secondary posts', 'nomady-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 20,
                'title' => esc_html__('In words', 'nomady-core'),
                'condition' => [
                    'post_layout' => [
						'c',
					],
                ],
            ]
        );

		$this->add_control(
			'background_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
                    'post_layout' => [
                    	'a',
                    	'c',
						'd',
						'f',
						'i',
					],
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background',
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mnmd-section-background, {{WRAPPER}} .mnmd-hero-post-block-a-secondary-inner, {{WRAPPER}} .post-box-d-primary-post-wrapper .post-text, {{WRAPPER}} .post-landscape-overlap .post-text, {{WRAPPER}} .post-box-e-section .post-inner, {{WRAPPER}} .post-box-i-section .post-hero-overlap .post-inner',
				'condition' => [
                    'post_layout' => [
                    	'a',
                    	'c',
						'd',
						'f',
						'i',
					],
                ],
			]
		);

		$this->add_control(
			'color_scheme',
			[
				'label' => esc_html__( 'Background color scheme', 'nomady-core' ),
				'description' => esc_html__( 'Select color scheme base on your background settings', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'light' => esc_html__( 'Light', 'nomady-core' ),
					'dark' => esc_html__( 'Dark', 'nomady-core' ),
				],
				'default' => 'light',
				'condition' => [
					'widget_background_background' => [
                    	'classic',
                    	'gradient',
					],
					'post_layout' => [
                    	'a',
                    	'c',
						'd',
						'f',
						'i',
					],
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();

		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
		);

        $this->add_render_attribute(
            'posts_list_wrapper',
            [
                'id' => 'mnmd-post-box-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-post-box',
                    'mnmd-post-box-' . esc_attr( $settings['post_layout'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'posts_list_wrapper' ) . '>';
        if ( in_array( $settings['post_layout'], [ 'a', 'c', 'd'] ) ) {
        	nomady_get_template_part( 'template-parts/sections/hero-post-block-' . $settings['post_layout'], NULL, $template_args );
        } else {
        	nomady_get_template_part( 'template-parts/sections/hero-post-block-lone', NULL, $template_args );
        }
        echo '</div>';
	}
}