<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Hero extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-hero';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Hero', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-call-to-action';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'label_block' => true,
				'default' => 'Welcome to my blog!',
			]
		);

		$this->add_control(
			'heading_center',
			[
				'label' => esc_html__( 'Center text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'body',
			[
				'label' => esc_html__( 'Body', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'rows' => 10,
				'default' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'nomady-core' ),
			]
		);

		$this->add_control(
			'primary_btn_text',
			[
				'label' => esc_html__( 'Primary button\'s text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'primary_btn_url',
			[
				'label' => esc_html__( 'Primary button\'s URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'show_external' => true,
			]
		);

		$this->add_control(
			'secondary_btn_text',
			[
				'label' => esc_html__( 'Secondary button\'s text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'secondary_btn_url',
			[
				'label' => esc_html__( 'Secondary button\'s URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'show_external' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'a' => esc_html__( 'Layout 1', 'nomady-core' ),
					'b' => esc_html__( 'Layout 2', 'nomady-core' ),
					'c' => esc_html__( 'Layout 3', 'nomady-core' ),
				],
				'default' => 'a',
			]
		);

		$this->add_control(
			'wide_layout',
			[
				'label' => esc_html__( 'Wide layout', 'nomady-core' ),
				'description' => esc_html__( 'Need parent section\'s Content Width set to Full Width', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'stretch_right',
			[
				'label' => esc_html__( 'Stretch to right', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
                    'layout' => [
                    	'b',
                    	'c',
                    ],
                ],
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__( 'Primary Image', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
                    'layout' => [
                    	'a',
                    	'c',
                    ],
                ],
			]
		);

		$this->add_control(
			'image_secondary',
			[
				'label' => esc_html__( 'Secondary Image', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
                    'layout' => [
                    	'c',
                    ],
                ],
			]
		);

		$this->add_control(
			'gallery',
			[
				'label' => esc_html__( 'Image Gallery', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'condition' => [
                    'layout' => [
                    	'b',
                    ],
                ],
			]
		);

		$this->add_control(
			'background_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
                    'layout' => [
                    	'a',
                    	'b',
                    ],
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background',
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mnmd-section-background',
				'condition' => [
                    'layout' => [
                    	'a',
                    	'b',
                    ],
                ],
			]
		);

		$this->add_control(
			'background_video_url',
			[
				'label' => esc_html__( 'Background video\'s URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'show_external' => false,
				'condition' => [
                    'layout' => [
                    	'a',
                    ],
                ],
			]
		);

		$this->add_control(
			'background_overlay_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
                    'layout' => [
                    	'a',
                    	'b',
                    ],
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background_overlay',
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .background-overlay',
				'condition' => [
                    'layout' => [
                    	'a',
                    	'b',
                    ],
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();
		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
			'section_id' => $this->get_id(),
		);

        $this->add_render_attribute(
            'about_wrapper',
            [
                'id' => 'mnmd-about-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-about',
                    'mnmd-about-' . esc_attr( $settings['layout'] ),
                    ( $settings['wide_layout'] === 'yes' ) ? 'mnmd-about-wide' : '',
                    ( $settings['stretch_right'] === 'yes' ) ? 'mnmd-about-stretch-right' : '',
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'about_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/hero-' . $settings['layout'], NULL, $template_args );
        echo '</div>';
	}
}