<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Category Listing
 *
 * Elementor widget for Nomady Elementor plugin.
 *
 * @since 1.0.0
 */
class Links extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-links';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Links', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-handle';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'heading_section',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label' => esc_html__( 'Subheading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'heading_url',
			[
				'label' => esc_html__( 'Heading URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$this->add_control(
			'heading_url_text',
			[
				'label' => esc_html__( 'Heading URL text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'View more', 'nomady-core' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'nomady-core' ),
            ]
        );

        $item_repeater = new \Elementor\Repeater();

		$item_repeater->add_control(
			'item_title',
			[
				'label' => esc_html__( 'Item title', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Item title', 'nomady-core' ),
			]
		);

		$item_repeater->add_control(
			'item_subtitle',
			[
				'label' => esc_html__( 'Item subtitle', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$item_repeater->add_control(
			'item_url',
			[
				'label' => esc_html__( 'Item URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$item_repeater->add_control(
			'item_image',
			[
				'label' => esc_html__( 'Item image', 'nomady-core' ),
				'description' => esc_html__( 'At least 400px each side is recommended', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'item_list',
			[
				'label' => __( 'Item list', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $item_repeater->get_controls(),
				'default' => [
					[
						'item_title' => esc_html__( 'Item 1', 'nomady-core' ),
					],
					[
						'item_title' => esc_html__( 'Item 2', 'nomady-core' ),
					],
					[
						'item_title' => esc_html__( 'Item 3', 'nomady-core' ),
					],

				],
				'title_field' => '{{{ item_title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'1' => esc_html__( 'Layout 1', 'nomady-core' ),
					'2' => esc_html__( 'Layout 2', 'nomady-core' ),
					'3' => esc_html__( 'Layout 3', 'nomady-core' ),
					'4' => esc_html__( 'Layout 4', 'nomady-core' ),
				],
				'default' => '1',
			]
		);

		$this->add_control(
			'columns',
			[
				'label' => esc_html__( 'Columns', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'3' => esc_html__( '3', 'nomady-core' ),
					'4' => esc_html__( '4', 'nomady-core' ),
					'auto' => esc_html__( 'Auto', 'nomady-core' ),
				],
				'default' => '4',
			]
		);

		$this->add_control(
			'circle_image',
			[
				'label' => esc_html__( 'Circle image', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
                    'layout' => [
						'2',
						'3',
						'4',
					],
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();

		// Create variable to pass to template.
		$template_args = array(
			'settings' => $settings,
		);

        $this->add_render_attribute(
            'section_wrapper',
            [
                'id' => 'mnmd-links-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-links',
                    'mnmd-links-style-' . esc_attr( $settings['layout'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'section_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/links', NULL, $template_args );
        echo '</div>';
	}
}