<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Post_Block extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-post-block';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Post Block', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-group';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'heading_section',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label' => esc_html__( 'Subheading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'heading_url',
			[
				'label' => esc_html__( 'Heading URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$this->add_control(
			'heading_url_text',
			[
				'label' => esc_html__( 'Heading URL text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'View more', 'nomady-core' ),
			]
		);

		$this->end_controls_section();

		/**
         * Query Controls
         * @source includes/helper.php
         */
        $this->post_query_controls();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'post_layout',
			[
				'label' => esc_html__( 'Post layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'a' => esc_html__( 'Layout 1', 'nomady-core' ),
					'b' => esc_html__( 'Layout 2', 'nomady-core' ),
					'd' => esc_html__( 'Layout 3', 'nomady-core' ),
					'c' => esc_html__( 'Layout 4', 'nomady-core' ),
					'e' => esc_html__( 'Layout 5', 'nomady-core' ),
				],
				'default' => 'a',
			]
		);

		$this->add_control(
			'post_style',
			[
				'label' => esc_html__( 'Post style', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'portrait' => esc_html__( 'Default', 'nomady-core' ),
					'landscape' => esc_html__( 'Horizontal', 'nomady-core' ),
					'card' => esc_html__( 'Card', 'nomady-core' ),
					'card-background' => esc_html__( 'Background card', 'nomady-core' ),
				],
				'default' => 'portrait',
				'condition' => [
                    'post_layout' => [
						'a',
					],
                ],
			]
		);

		$this->add_control(
			'thumb_style',
			[
				'label' => esc_html__( 'Thumbnail style', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'nomady-core' ),
					'circle' => esc_html__( 'Circle', 'nomady-core' ),
					'tall' => esc_html__( 'Tall', 'nomady-core' ),
					'original' => esc_html__( 'Original', 'nomady-core' ),
				],
				'default' => 'default',
				'condition' => [
                    'post_layout' => 'a',
                    'post_style' => 'portrait',
                ],
			]
		);

		$this->add_control(
			'columns',
			[
				'label' => esc_html__( 'Columns', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'3' => esc_html__( '3', 'nomady-core' ),
					'4' => esc_html__( '4', 'nomady-core' ),
				],
				'default' => '3',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'portrait',
						'card',
						'card-background',
					],
                ],
			]
		);

		$this->add_control(
			'columns_horizontal_post',
			[
				'label' => esc_html__( 'Columns', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'2' => esc_html__( '2', 'nomady-core' ),
					'3' => esc_html__( '3', 'nomady-core' ),
				],
				'default' => '3',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => 'landscape',
                ],
			]
		);

		$this->add_control(
			'vertical_align',
			[
				'label' => esc_html__( 'Vertical align', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'start' => esc_html__( 'Top', 'nomady-core' ),
					'center' => esc_html__( 'Center', 'nomady-core' ),
					'end' => esc_html__( 'Bottom', 'nomady-core' ),
					'zigzag' => esc_html__( 'Zigzag', 'nomady-core' ),
					'staircase' => esc_html__( 'Staircase', 'nomady-core' ),
				],
				'default' => 'start',
				'condition' => [
                    'post_layout' => [
						'a',
					],
                ],
			]
		);

		$this->add_control(
            'excerpt_length',
            [
                'label' => esc_html__('Excerpt Length', 'nomady-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 20,
                'title' => esc_html__('In words', 'nomady-core'),
                'condition' => [
                    'post_layout' => [
						'b',
						'c',
						'd',
						'e',
					],
                ],
            ]
        );

		$this->add_control(
			'big_post_position',
			[
				'label' => esc_html__( 'Big post position', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'first' => esc_html__( 'First', 'nomady-core' ),
					'second' => esc_html__( 'Second', 'nomady-core' ),
					'last' => esc_html__( 'Last', 'nomady-core' ),
				],
				'default' => 'first',
				'condition' => [
                    'post_layout' => 'b',
                ],
			]
		);

		$this->add_control(
			'background_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background',
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mnmd-section-background',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
                ],
			]
		);

		$this->add_control(
			'background_overlay_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background_overlay',
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .background-overlay',
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
                ],
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'condition' => [
                    'post_layout' => [
						'a',
					],
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
                ],
			]
		);

		$this->add_control(
			'color_scheme',
			[
				'label' => esc_html__( 'Background color scheme', 'nomady-core' ),
				'description' => esc_html__( 'Select the color scheme of your background settings for text legibility', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'light' => esc_html__( 'Light', 'nomady-core' ),
					'dark' => esc_html__( 'Dark', 'nomady-core' ),
				],
				'default' => 'light',
				'condition' => [
					'post_style' => [
						'card',
						'card-background',
						'card-cutout',
					],
					'widget_background_background' => 'classic',
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();

		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
		);

        $this->add_render_attribute(
            'posts_list_wrapper',
            [
                'id' => 'mnmd-elementor-post-block-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-elementor-post-block',
                    'mnmd-elementor-post-block-' . esc_attr( $settings['post_layout'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'posts_list_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/post-block-' . $settings['post_layout'], NULL, $template_args );
        echo '</div>';
	}
}