<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Post_Carousel extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-post-carousel';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Post Carousel', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-carousel';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'heading_section',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label' => esc_html__( 'Subheading', 'nomady-core' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();

		/**
         * Query And Layout Controls!
         * @source includes/helper.php
         */
        $this->post_query_controls();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'carousel_style',
			[
				'label' => esc_html__( 'Carousel style', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'a' => esc_html__( 'Carousel 1', 'nomady-core' ),
					'c' => esc_html__( 'Carousel 2', 'nomady-core' ),
				],
				'default' => 'a',
			]
		);

		$this->add_control(
			'post_style',
			[
				'label' => esc_html__( 'Post style', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'portrait' => esc_html__( 'Default', 'nomady-core' ),
					'card' => esc_html__( 'Card', 'nomady-core' ),
					'card-background' => esc_html__( 'Background card', 'nomady-core' ),
				],
				'default' => 'card',
				'condition' => [
                    'carousel_style' => 'a',
                ],
			]
		);

		$this->add_control(
			'thumb_style',
			[
				'label' => esc_html__( 'Thumbnail style', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'nomady-core' ),
					'tall' => esc_html__( 'Tall', 'nomady-core' ),
					'original' => esc_html__( 'Original', 'nomady-core' ),
				],
				'default' => 'default',
				'condition' => [
                    'carousel_style' => 'a',
                    'post_style' => 'portrait',
                ],
			]
		);

		$this->add_control(
            'items_per_view',
            [
                'label' => esc_html__( 'Posts per view', 'nomady-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
					'3' => esc_html__( '3', 'nomady-core' ),
					'4' => esc_html__( '4', 'nomady-core' ),
				],
                'default' => '4',
                'condition' => [
                    'carousel_style' => 'a',
                ],
            ]
        );

        $this->add_control(
			'overflow',
			[
				'label' => esc_html__( 'Overflow', 'nomady-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
                    'carousel_style' => [
						'a',
					],
                ],
			]
		);

		$this->add_control(
			'background_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background',
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mnmd-section-background',
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'color_scheme',
			[
				'label' => esc_html__( 'Background color scheme', 'nomady-core' ),
				'description' => esc_html__( 'Select color scheme base on your selected background', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'light' => __( 'Light', 'nomady-core' ),
					'dark' => __( 'Dark', 'nomady-core' ),
				],
				'default' => 'light',
				'condition' => [
					'widget_background_background' => 'classic',
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();
		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
			'block_id' => $this->get_id(),
		);

        $this->add_render_attribute(
            'posts_list_wrapper',
            [
                'id' => 'mnmd-post-carousel-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-post-carousel',
                    'mnmd-post-carousel-' . esc_attr( $settings['carousel_style'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'posts_list_wrapper' ) . '>';
        	nomady_get_template_part( 'template-parts/sections/post-carousel-' . $settings['carousel_style'], NULL, $template_args );
        echo '</div>';
	}
}