<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Post_Listing extends Widget_Base {

	use \NomadyCore\Traits\Helper;
	// use \NomadyElementor\Template\Posts_Listing;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-posts-list';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Nomady Post Listing', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'masonry' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'heading_section',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label' => esc_html__( 'Subheading', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'heading_url',
			[
				'label' => esc_html__( 'Heading URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
			]
		);

		$this->add_control(
			'heading_url_text',
			[
				'label' => esc_html__( 'Heading URL text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'View more', 'nomady-core' ),
			]
		);

		$this->end_controls_section();

		/**
         * Query And Layout Controls
         * @source includes/helper.php
         */
        $this->post_query_controls();

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'post_layout',
			[
				'label' => esc_html__( 'Post layout', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'list-landscape' => esc_html__( 'List - Landscape', 'nomady-core' ),
					'list-landscape-no-sidebar' => esc_html__( 'List - Landscape - No sidebar', 'nomady-core' ),
					'list-portrait' => esc_html__( 'List - Portrait', 'nomady-core' ),
					'list-portrait-no-sidebar' => esc_html__( 'List - Portrait - No sidebar', 'nomady-core' ),
					'list-mixed-1' => esc_html__( 'List - Mixed 1', 'nomady-core' ),
					'list-mixed-2' => esc_html__( 'List - Mixed 2', 'nomady-core' ),
					'list-mixed-no-sidebar' => esc_html__( 'List - Mixed - No sidebar', 'nomady-core' ),
					'grid-portrait' => esc_html__( 'Grid - Portrait', 'nomady-core' ),
					'grid-portrait-no-sidebar' => esc_html__( 'Grid - Portrait - No sidebar', 'nomady-core' ),
					'grid-flow' => esc_html__( 'Grid - Portrait Flow', 'nomady-core' ),
					'grid-mixed-1' => esc_html__( 'Grid - Mixed 1', 'nomady-core' ),
					'grid-mixed-2' => esc_html__( 'Grid - Mixed 2', 'nomady-core' ),
					'grid-mixed-no-sidebar' => esc_html__( 'Grid - Mixed - No sidebar', 'nomady-core' ),
					'masonry-portrait' => esc_html__( 'Masonry - Portrait', 'nomady-core' ),
					'masonry-flow' => esc_html__( 'Masonry - Portrait Flow', 'nomady-core' ),
					'masonry-portrait-no-sidebar' => esc_html__( 'Masonry - Portrait - No sidebar', 'nomady-core' ),
				],
				'default' => 'list-landscape',
			]
		);

		$this->sidebar_select_control();

		$this->add_control(
			'hero_post_first',
			[
				'label' => esc_html__( 'Show hero post first', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html( 'Yes', 'nomady' ),
				'label_off' => esc_html( 'No', 'nomady' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
                    'post_layout' => [
						'list-mixed-1',
						'list-mixed-2',
						'list-mixed-no-sidebar',
						'grid-mixed-1',
						'grid-mixed-2',
						'grid-mixed-no-sidebar',
                    ],
                ],
			]
		);

		$this->add_control(
			'hero_cycle',
			[
				'label' => esc_html__('Show hero post every x post', 'nomady-core'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 20,
				'step' => 1,
				'default' => 4,
				'condition' => [
                	'post_layout' => [
						'list-mixed-1',
						'list-mixed-2',
						'list-mixed-no-sidebar',
						'grid-mixed-1',
						'grid-mixed-2',
                    ],
                ],
			]
		);

		$this->add_control(
			'grid_columns',
			[
				'label' => esc_html__( 'Number of columns', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'3' => esc_html__( '3', 'nomady-core' ),
					'4' => esc_html__( '4', 'nomady-core' ),
				],
				'default' => '3',
				'condition' => [
                    'post_layout' => [
						'grid-portrait-no-sidebar',
						'masonry-portrait-no-sidebar',
                    ],
                ],
			]
		);

		$this->add_control(
			'flow_columns',
			[
				'label' => esc_html__( 'Number of columns', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'2' => esc_html__( '2', 'nomady-core' ),
					'3' => esc_html__( '3', 'nomady-core' ),
				],
				'default' => '3',
				'condition' => [
                    'post_layout' => [
						'grid-flow',
						'masonry-flow',
                    ],
                ],
			]
		);

		$this->add_control(
			'thumb_reverse',
			[
				'label' => esc_html__( 'Reverse thumbnail position', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html( 'Yes', 'nomady' ),
				'label_off' => esc_html( 'No', 'nomady' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
                    'post_layout' => [
                    	'list-landscape',
						'list-landscape-no-sidebar',
						'list-mixed-1',
						'list-mixed-2',
						'list-mixed-no-sidebar',
						'grid-mixed-no-sidebar',
                    ],
                ],
			]
		);

		$this->add_control(
			'thumb_original_ratio',
			[
				'label' => esc_html__( 'Original ratio thumbnail', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html( 'Yes', 'nomady' ),
				'label_off' => esc_html( 'No', 'nomady' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
                    'post_layout' => [
                    	'list-landscape',
						'list-portrait',
						'list-portrait-no-sidebar',
						'list-mixed-1',
						'list-mixed-2',
						'grid-portrait-no-sidebar',
						'masonry-portrait',
						'masonry-portrait-no-sidebar',
                    ],
                ],
			]
		);

		$this->add_control(
			'post_format_icon',
			[
				'label' => esc_html__( 'Display post format icon', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html( 'Yes', 'nomady' ),
				'label_off' => esc_html( 'No', 'nomady' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'excerpt_length_toggle',
			[
				'label' => esc_html__( 'Custom excerpt length', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html( 'Yes', 'nomady' ),
				'label_off' => esc_html( 'No', 'nomady' ),
				'return_value' => 'yes',
				'default' => 'no',
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
		                    'name' => 'post_layout',
		                    'operator' => 'in',
		                    'value' => [
		                    	'list-landscape',
								'list-landscape-no-sidebar',
								'list-portrait',
								'list-portrait-no-sidebar',
								'list-mixed-1',
								'list-mixed-2',
								'list-mixed-no-sidebar',
								'grid-portrait',
								'grid-mixed-1',
								'grid-mixed-2',
								'grid-mixed-no-sidebar',
								'masonry-portrait',
		                    ],
		                ],
		                [
							'terms' => [
								[
				                    'name' => 'post_layout',
				                    'operator' => '===',
				                    'value' => 'grid-portrait-no-sidebar',
				                ],
				                [
				                    'name' => 'grid_columns',
				                    'operator' => '===',
				                    'value' => '3',
				                ],
							],
						],
						[
							'terms' => [
								[
				                    'name' => 'post_layout',
				                    'operator' => '===',
				                    'value' => 'grid-flow',
				                ],
				                [
				                    'name' => 'flow_columns',
				                    'operator' => '===',
				                    'value' => '2',
				                ],
							],
						],
						[
							'terms' => [
								[
				                    'name' => 'post_layout',
				                    'operator' => '===',
				                    'value' => 'masonry-portrait-no-sidebar',
				                ],
				                [
				                    'name' => 'grid_columns',
				                    'operator' => '===',
				                    'value' => '3',
				                ],
							],
						],
						[
							'terms' => [
								[
				                    'name' => 'post_layout',
				                    'operator' => '===',
				                    'value' => 'masonry-flow',
				                ],
				                [
				                    'name' => 'flow_columns',
				                    'operator' => '===',
				                    'value' => '2',
				                ],
							],
						],
					],
                ],
			]
		);

		$this->add_control(
            'excerpt_length',
            [
                'label' => esc_html__('Excerpt length', 'nomady-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 55,
                'step' => 1,
                'default' => 24,
				'title' => esc_html__('In words', 'nomady-core'),
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'excerpt_length_toggle',
		                    'operator' => '===',
		                    'value' => 'yes',
						],
						[
							'relation' => 'or',
							'terms' => [
								[
				                    'name' => 'post_layout',
				                    'operator' => 'in',
				                    'value' => [
				                    	'list-landscape',
										'list-landscape-no-sidebar',
										'list-portrait',
										'list-portrait-no-sidebar',
										'list-mixed-1',
										'list-mixed-2',
										'list-mixed-no-sidebar',
										'grid-portrait',
										'grid-mixed-1',
										'grid-mixed-2',
										'grid-mixed-no-sidebar',
										'masonry-portrait',
				                    ],
				                ],
				                [
									'terms' => [
										[
						                    'name' => 'post_layout',
						                    'operator' => '===',
						                    'value' => 'grid-portrait-no-sidebar',
						                ],
						                [
						                    'name' => 'grid_columns',
						                    'operator' => '===',
						                    'value' => '3',
						                ],
									],
								],
								[
									'terms' => [
										[
						                    'name' => 'post_layout',
						                    'operator' => '===',
						                    'value' => 'grid-flow',
						                ],
						                [
						                    'name' => 'flow_columns',
						                    'operator' => '===',
						                    'value' => '2',
						                ],
									],
								],
								[
									'terms' => [
										[
						                    'name' => 'post_layout',
						                    'operator' => '===',
						                    'value' => 'masonry-portrait-no-sidebar',
						                ],
						                [
						                    'name' => 'grid_columns',
						                    'operator' => '===',
						                    'value' => '3',
						                ],
									],
								],
								[
									'terms' => [
										[
						                    'name' => 'post_layout',
						                    'operator' => '===',
						                    'value' => 'masonry-flow',
						                ],
						                [
						                    'name' => 'flow_columns',
						                    'operator' => '===',
						                    'value' => '2',
						                ],
									],
								],
							],
						],
					],
                ],
            ]
		);

		$this->add_control(
            'excerpt_length_hero',
            [
                'label' => esc_html__('Excerpt length of hero post', 'nomady-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 55,
                'step' => 1,
                'default' => 40,
				'title' => esc_html__('In words', 'nomady-core'),
				'conditions' => [
					'relation' => 'and',
					'terms' => [
						[
							'name' => 'excerpt_length_toggle',
		                    'operator' => '===',
		                    'value' => 'yes',
						],
						[
							'name' => 'post_layout',
		                    'operator' => 'in',
		                    'value' => [
								'list-mixed-1',
								'list-mixed-2',
								'list-mixed-no-sidebar',
								'grid-mixed-1',
								'grid-mixed-2',
								'grid-mixed-no-sidebar',
		                    ],
						],
					],
                ],
            ]
		);

		$this->add_control(
			'pagination',
			[
				'label' => esc_html__( 'Pagination', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Default', 'nomady-core' ),
					'next-and-previous' => esc_html__( 'Next and Previous', 'nomady-core' ),
					'ajax-load-more' => esc_html__( 'AJAX load more button', 'nomady-core' ),
					'view-more-url' => esc_html__( 'View more URL', 'nomady-core' ),
					'none' => esc_html__( 'No pagination', 'nomady-core' ),
				],
				'default' => 'default',
			]
		);

		$this->add_control(
			'view_more_url',
			[
				'label' => esc_html__( 'View more URL', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'URL to your archive page', 'nomady-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
                    'pagination' => 'view-more-url',
                ],
			]
		);

		$this->add_control(
			'view_more_url_title',
			[
				'label' => esc_html__( 'View more URL title', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'View more', 'nomady-core' ),
				'condition' => [
                    'pagination' => 'view-more-url',
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();
		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
		);

        $this->add_render_attribute(
            'post_listing_wrapper',
            [
                'id' => 'mnmd-post-listing-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-post-listing',
                    'mnmd-post-listing-' . esc_attr( $settings['post_layout'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'post_listing_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/post-listing', NULL, $template_args );
        echo '</div>';

        // Insert JS code for masonry layout
        if ( \Elementor\Plugin::instance()->editor->is_edit_mode() && ( $settings['post_layout'] === 'masonry' ) ) {
            echo '<script type="text/javascript">
                jQuery( document ).ready( function() {
                	if ( jQuery.isFunction( jQuery.fn.masonry ) ) { // check if masonry script is loaded
                		jQuery( ".js-masonry" ).each( function() {
	                        var $scope = jQuery( ".elementor-element-' . $this->get_id() . '" );

	                        // init masonry
	                        var $masonry = jQuery( ".js-masonry", $scope ).masonry( {
			                    itemSelector: ".masonry-item"
			                } );

			                if ( jQuery.isFunction( jQuery.fn.imagesLoaded ) ) { // check if imagesLoaded script is loaded
		                        // layout posts, while images are loading
		                        $masonry.imagesLoaded().progress(function() {
		                            $masonry.masonry("layout");
		                        } );
		                    }
	                    } );
		            }
                } );
            </script>';
        }
	}
}