<?php
namespace NomadyCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Nomady Post Slider
 *
 * @since 1.0.0
 */
class Post_Slider extends Widget_Base {

	use \NomadyCore\Traits\Helper;

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'nomady-post-slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Nomady Post Slider', 'nomady-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slides';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'nomady' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'nomady-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		/**
         * Heading Section
         */
		$this->start_controls_section(
			'heading_section',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label' => esc_html__( 'Heading', 'nomady-core' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'subheading',
			[
				'label' => esc_html__( 'Subheading', 'nomady-core' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'heading_url',
			[
				'label' => esc_html__( 'Heading URL', 'nomady-core' ),
				'type' => Controls_Manager::URL,
			]
		);

		$this->add_control(
			'heading_url_text',
			[
				'label' => esc_html__( 'Heading URL text', 'nomady-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'View more', 'nomady-core' ),
			]
		);

		$this->end_controls_section();

		/**
         * Query And Layout Controls!
         * @source includes/helper.php
         */
        $this->post_query_controls();

		/**
         * Settings Section
         */
		$this->start_controls_section(
			'settings_section',
			[
				'label' => __( 'Settings', 'nomady-core' ),
			]
		);

		$this->add_control(
			'slider_style',
			[
				'label' => __( 'Slider style', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'parallax-carousel' => __( 'Slider 1', 'nomady-core' ),
					'fw-slider' => __( 'Slider 2', 'nomady-core' ),
				],
				'default' => 'parallax-carousel',
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__( 'Autoplay', 'nomady-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'slider_style' => 'fw-slider',
                ],
			]
		);

		$this->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__( 'Autoplay speed', 'nomady-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 6000,
                'title' => esc_html__( 'In ms', 'nomady-core' ),
                'conditions' => [
                	'relation' => 'and',
                	'terms' => [
                    	[
                    		'name' => 'autoplay',
                    		'operator' => '=',
                    		'value' => 'yes',
                    	],
                    	[
                    		'name' => 'slider_style',
                    		'operator' => '=',
                    		'value' => 'fw-slider',
                    	],
                    ],
                ],
            ]
        );

        $this->add_control(
			'kenburns',
			[
				'label' => esc_html__( 'Kenburns effect', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'slider_style' => 'fw-slider',
                ],
			]
		);

		$this->add_control(
			'center_text',
			[
				'label' => esc_html__( 'Center text', 'nomady-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'nomady-core' ),
				'label_off' => esc_html__( 'No', 'nomady-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'slider_style' => 'fw-slider',
                ],
			]
		);

		$this->add_control(
			'background_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'separator' => 'before',
				'condition' => [
					'slider_style' => 'parallax-carousel',
                ],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background',
				'label' => esc_html__( 'Background', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mnmd-section-background',
				'condition' => [
					'slider_style' => 'parallax-carousel',
                ],
			]
		);

		$this->add_control(
			'background_overlay_heading',
			[
				'type' => \Elementor\Controls_Manager::HEADING,
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'widget_background_overlay',
				'label' => esc_html__( 'Background overlay', 'nomady-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .background-overlay',
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'color_scheme',
			[
				'label' => esc_html__( 'Color scheme', 'nomady-core' ),
				'description' => esc_html__( 'Select color scheme base on your selected background', 'nomady-core' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'light' => __( 'Light', 'nomady-core' ),
					'dark' => __( 'Dark', 'nomady-core' ),
				],
				'default' => 'light',
				'condition' => [
					'widget_background_background' => 'classic',
					'slider_style' => 'parallax-carousel',
                ],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		// Get widget settings
		$settings = $this->get_settings_for_display();
		// Create query
        $query_args = $this->nomady_get_query_args( $settings );

		// Create variable to pass to template.
		$template_args = array(
			'query_args' => $query_args,
			'settings' => $settings,
		);

        $this->add_render_attribute(
            'posts_list_wrapper',
            [
                'id' => 'mnmd-post-slider-' . esc_attr( $this->get_id() ),
                'class' => [
                    'mnmd-post-slider',
                    'mnmd-post-slider-' . esc_attr( $settings['slider_style'] ),
                ],
            ]
        );

        echo '<div ' . $this->get_render_attribute_string( 'posts_list_wrapper' ) . '>';
        nomady_get_template_part( 'template-parts/sections/' . $settings['slider_style'], NULL, $template_args );
        echo '</div>';
	}
}