<?php
/*
 * Display the Categories
 */
class mnmd_categories_widget extends WP_Widget {

	public function __construct()
	{
		$theme_name = wp_get_theme()->name;
		parent::__construct( 'mnmd_categories_widget', $theme_name.' - '.esc_html__( 'Categories', 'nomady-core'), array('description' => esc_html__('Display categories', 'nomady-core'), 'classname' => 'mnmd-categories-widget') );
	}

	function widget($args, $instance) {
		extract( $args );

		$title 		= apply_filters('widget_title', $instance['title']);
		$cats_id 	= $instance['cats_id'];
		$orderby 	= $instance['orderby'];
		$order = ($orderby == 'count')? 'DESC': 'ASC';
		$category_template = 'category-item-a';
		$thumb_size = 'nomady_sm_1_1';

		// The Query
		$args = array(
			'orderby'		 	=> $orderby,
			'order'		 		=> $order,
			'include'			=> $cats_id,
		);

		$categories = get_categories( $args );

		echo wp_kses_post($before_widget);

		if ($title) echo wp_kses_post($before_title . $title . $after_title);

		if ( $categories ) {
			?>
			<ul class="list-unstyled">
				<?php
				foreach ( $categories as $cat_id => $category ) {
					if ( function_exists( 'get_field' ) ) {
						$featured_img = get_field( 'field_mnmd_category_image', $category );
					} else {
						$featured_img = NULL;
					}

					if ( $featured_img ) {
						$thumb_url = $featured_img[ 'sizes' ][ $thumb_size ];
					} else {
						$category__post = get_posts( 'category='.$category->term_id.'&posts_per_page=1&orderby=post_date&post_status=publish' );
						if ( has_post_thumbnail( $category__post[0]->ID ) ) {
							$thumb_id = get_post_thumbnail_id( $category__post[0]->ID );
							$thumb_url_array = wp_get_attachment_image_src( $thumb_id, $thumb_size, true );
							$thumb_url = $thumb_url_array[0];
						} else {
							$thumb_url = '';
						}
					}
				?>
				<li>
					<?php
					nomady_get_template_part( 'template-parts/misc/' . $category_template, NULL,
						array(
							'category' => $category,
							'thumb_url' => $thumb_url,
							'show_post_count' => 'yes',
						)
					);
					?>
				</li>
				<?php
				}
				?>
			</ul>
			<?php
		}

		echo wp_kses_post($after_widget);

	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['cats_id'] = implode(',' , $new_instance['cats_id']  );
		$instance['orderby'] = strip_tags($new_instance['orderby']);
		return $instance;
	}

	function form($instance) {
		$defaults = array( 'title' => esc_html__('Categories' , 'nomady-core') , 'cats_id' => '0' , 'orderby' => 'count' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		$categories_obj = get_categories();
		$categories = array();

		foreach ($categories_obj as $pn_cat) {
			$categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
		} ?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'nomady-core'); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id('title')); ?>" class="widefat" type="text" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
		</p>
		<p>
			<?php $cats_id = explode ( ',' , $instance['cats_id'] ) ; ?>
			<label for="<?php echo esc_attr($this->get_field_id( 'cats_id' )); ?>"><?php esc_html_e('Category: ', 'nomady-core'); ?></label>
			<select multiple="multiple" id="<?php echo esc_attr($this->get_field_id( 'cats_id' )); ?>[]" name="<?php echo esc_attr($this->get_field_name( 'cats_id' )); ?>[]">
				<?php foreach ($categories as $key => $option) { ?>
				<option value="<?php echo esc_attr($key); ?>" <?php if ( in_array( $key , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo esc_html($option); ?></option>
				<?php } ?>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>"><?php esc_html_e('Categories order: ', 'nomady-core'); ?></label>
			<select id="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'orderby' )); ?>" >
				<option value="name" <?php if( $instance['orderby'] == 'name' ) echo "selected=\"selected\""; ?>><?php esc_html_e('Alphabet', 'nomady-core'); ?></option>
				<option value="count" <?php if( $instance['orderby'] == 'count' ) echo "selected=\"selected\""; ?>><?php esc_html_e('Number of posts', 'nomady-core'); ?></option>
			</select>
		</p>
	<?php
	}
}

function register_mnmd_categories_widget() {
    register_widget( 'mnmd_categories_widget' );
}

add_action( 'widgets_init', 'register_mnmd_categories_widget' );