<?php
/*
 * Display the Posts List
 */
class mnmd_posts_list_widget extends WP_Widget {

	public function __construct()
	{
		$theme_name = wp_get_theme()->name;
		parent::__construct( 'mnmd_posts_list_widget', $theme_name.' - '.esc_html__('Post List', 'nomady-core'), array('description' => esc_html__('Display the posts list in your sidebar or footer', 'nomady-core'), 'classname' => 'mnmd-post-list-widget') );
	}

	function widget($args, $instance) {
		extract( $args );

		$title 		= apply_filters('widget_title', $instance['title']);
		$cats_id 	= $instance['cats_id'];
		$orderby 	= $instance['orderby'];
		$number 	= $instance['number'];
		$post_template = 'landscape-xs';
		$thumb_size = 'nomady_sm_1_1';


		// The Query
		$args = array(
			'posts_per_page' 	=> $number,
			'cat' 		 		=> $cats_id,
			'orderby'		 	=> $orderby,
			'status' 		 	=> 'publish',
			'ignore_sticky_posts'=> true,
		);

		$query_posts = new WP_Query( $args );

		echo wp_kses_post($before_widget);

		if ($title) echo wp_kses_post($before_title . $title . $after_title);

		if ($query_posts->have_posts()) {
		?>
			<ul class="list-unstyled">
				<?php
				while ($query_posts->have_posts()) {
					$query_posts->the_post();
				?>
					<li>
					<?php
					nomady_get_template_part( 'template-parts/posts/post-' . $post_template,
						array(
							'thumb_size' => $thumb_size,
						)
					);
					?>
					</li>
				<?php
				}
				?>
			</ul>
		<?php
		}

		echo wp_kses_post($after_widget);

		// Reset Post Data
		wp_reset_postdata();
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['cats_id'] = implode(',' , $new_instance['cats_id']  );
		$instance['orderby'] = strip_tags($new_instance['orderby']);
		$instance['number'] = ($new_instance['number']);
		return $instance;
	}

	function form($instance) {
		$defaults = array( 'title' => esc_html__('Recent Posts' , 'nomady-core') , 'cats_id' => '0' , 'orderby' => 'date', 'style' => 'list--thumb', 'number' => 4 );
		$instance = wp_parse_args( (array) $instance, $defaults );
		$categories_obj = get_categories();
		$categories = array();

		foreach ($categories_obj as $pn_cat) {
			$categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
		} ?>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'nomady-core'); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id('title')); ?>" class="widefat" type="text" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
		</p>
		<p>
			<?php $cats_id = explode ( ',' , $instance['cats_id'] ) ; ?>
			<label for="<?php echo esc_attr($this->get_field_id( 'cats_id' )); ?>"><?php esc_html_e('Category: ', 'nomady-core'); ?></label>
			<select multiple="multiple" id="<?php echo esc_attr($this->get_field_id( 'cats_id' )); ?>[]" name="<?php echo esc_attr($this->get_field_name( 'cats_id' )); ?>[]">
				<?php foreach ($categories as $key => $option) { ?>
				<option value="<?php echo esc_attr($key); ?>" <?php if ( in_array( $key , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo esc_html($option); ?></option>
				<?php } ?>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>"><?php esc_html_e('Posts order: ', 'nomady-core'); ?></label>
			<select id="<?php echo esc_attr($this->get_field_id( 'orderby' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'orderby' )); ?>" >
				<option value="date" <?php if( $instance['orderby'] == 'date' ) echo "selected=\"selected\""; ?>><?php esc_html_e('Latest', 'nomady-core'); ?></option>
				<option value="rand" <?php if( $instance['orderby'] == 'rand' ) echo "selected=\"selected\""; ?>><?php esc_html_e('Random', 'nomady-core'); ?></option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('Number of posts:', 'nomady-core'); ?></label>
			<input id="<?php echo esc_attr($this->get_field_id('number')); ?>" type="number" name="<?php echo esc_attr($this->get_field_name('number')); ?>" value="<?php echo esc_attr($instance['number']); ?>" />
		</p>
	<?php
	}
}

function register_mnmd_posts_list_widget() {
    register_widget( 'mnmd_posts_list_widget' );
}

add_action( 'widgets_init', 'register_mnmd_posts_list_widget' );